import{b2 as a,R as p}from"./index-6jOCfdig.js";import{F as m}from"./KHR_interactivity-DRPs30Rf.js";import{b as u,l as n,R as c}from"./declarationMapper-CGPHX8aB.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class h extends m{constructor(t){super(t),this.config=t,this._easingFunctions={},this.mode=this.registerDataInput("mode",u,0),this.controlPoint1=this.registerDataInput("controlPoint1",n),this.controlPoint2=this.registerDataInput("controlPoint2",n),this.easingFunction=this.registerDataOutput("easingFunction",c)}_updateOutputs(t){const r=this.mode.getValue(t),i=this.controlPoint1.getValue(t),o=this.controlPoint2.getValue(t);if(r===void 0)return;const s=`${r}-${i.x}-${i.y}-${o.x}-${o.y}`;if(!this._easingFunctions[s]){const e=new a(i.x,i.y,o.x,o.y);e.setEasingMode(r),this._easingFunctions[s]=e}this.easingFunction.setValue(this._easingFunctions[s],t)}getClassName(){return"FlowGraphBezierCurveEasing"}}p("FlowGraphBezierCurveEasing",h);export{h as FlowGraphBezierCurveEasingBlock};
