.container.svelte-19cq9h3 img{width:100%;height:100%}.container.selected.svelte-19cq9h3{border-color:var(--border-color-accent)}.border.table.svelte-19cq9h3{border:1px solid var(--border-color-primary)}.container.table.svelte-19cq9h3{margin:0 auto;border-radius:var(--radius-lg);overflow:hidden;width:100%;height:100%;max-width:var(--size-40);max-height:var(--size-20);object-fit:cover}.container.gallery.svelte-19cq9h3{width:100%;max-width:100%;object-fit:cover;max-width:var(--size-40);max-height:var(--size-20);overflow:hidden}
