import{aY as c,aZ as l,a_ as h,a$ as p,b0 as E,b1 as w,b2 as d,R as n}from"./index-6jOCfdig.js";import{F as B}from"./KHR_interactivity-DRPs30Rf.js";import{R as i,b as C}from"./declarationMapper-CGPHX8aB.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";var u;(function(e){e[e.CircleEase=0]="CircleEase",e[e.BackEase=1]="BackEase",e[e.BounceEase=2]="BounceEase",e[e.CubicEase=3]="CubicEase",e[e.ElasticEase=4]="ElasticEase",e[e.ExponentialEase=5]="ExponentialEase",e[e.PowerEase=6]="PowerEase",e[e.QuadraticEase=7]="QuadraticEase",e[e.QuarticEase=8]="QuarticEase",e[e.QuinticEase=9]="QuinticEase",e[e.SineEase=10]="SineEase",e[e.BezierCurveEase=11]="BezierCurveEase"})(u||(u={}));function f(e,...s){switch(e){case 11:return new d(...s);case 0:return new w;case 1:return new E(...s);case 2:return new p(...s);case 3:return new h;case 4:return new l(...s);case 5:return new c(...s);default:throw new Error("Easing type not yet implemented")}}class b extends B{constructor(s){super(s),this.config=s,this._easingFunctions={},this.type=this.registerDataInput("type",i,11),this.mode=this.registerDataInput("mode",C,0),this.parameters=this.registerDataInput("parameters",i,[1,0,0,1]),this.easingFunction=this.registerDataOutput("easingFunction",i)}_updateOutputs(s){const t=this.type.getValue(s),a=this.mode.getValue(s),o=this.parameters.getValue(s);if(t===void 0||a===void 0)return;const r=`${t}-${a}-${o.join("-")}`;if(!this._easingFunctions[r]){const m=f(t,...o);m.setEasingMode(a),this._easingFunctions[r]=m}this.easingFunction.setValue(this._easingFunctions[r],s)}getClassName(){return"FlowGraphEasingBlock"}}n("FlowGraphEasingBlock",b);export{u as EasingFunctionType,b as FlowGraphEasingBlock};
