.layout.svelte-n8pych{display:flex;flex-direction:column;justify-content:center;align-items:center;width:var(--size-full);height:var(--size-full);color:var(--body-text-color)}.matplotlib.svelte-n8pych img:where(.svelte-n8pych){object-fit:contain}
