import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var o=e.from_html("<div> </div>");function f(d,r){e.push(r,!1);let t=e.prop(r,"value",12),a=e.prop(r,"type",12),p=e.prop(r,"selected",12,!1);var i={get value(){return t()},set value(l){t(l),e.flush()},get type(){return a()},set type(l){a(l),e.flush()},get selected(){return p()},set selected(l){p(l),e.flush()}};e.init();var s=o();let u;var n=e.child(s,!0);return e.reset(s),e.template_effect(l=>{u=e.set_class(s,1,"svelte-1p04unr",null,u,{table:a()==="table",gallery:a()==="gallery",selected:p()}),e.set_text(n,l)},[()=>(e.deep_read_state(t()),e.untrack(()=>t()?Array.isArray(t())?t().join(", "):t():""))]),e.append(d,s),e.pop(i)}export{f as default};
