import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var v=e.from_html("<div> </div>");function y(c,l){e.push(l,!1);let a=e.prop(l,"value",12),s=e.prop(l,"type",12),i=e.prop(l,"selected",12,!1),n=e.prop(l,"choices",12),p=a().map(t=>n().find(d=>d[1]===t)?.[0]).filter(t=>t!==void 0).join(", ");var o={get value(){return a()},set value(t){a(t),e.flush()},get type(){return s()},set type(t){s(t),e.flush()},get selected(){return i()},set selected(t){i(t),e.flush()},get choices(){return n()},set choices(t){n(t),e.flush()}};e.init();var r=v();let u;var f=e.child(r,!0);return e.reset(r),e.template_effect(()=>{u=e.set_class(r,1,"svelte-25nhtv",null,u,{table:s()==="table",gallery:s()==="gallery",selected:i()}),e.set_text(f,p)}),e.append(c,r),e.pop(o)}export{y as default};
