.options.svelte-1ou0lab{--window-padding: var(--size-8);position:fixed;z-index:var(--layer-top);margin-left:0;box-shadow:var(--shadow-drop-lg);border-radius:var(--container-radius);background:var(--background-fill-primary);min-width:fit-content;max-width:inherit;overflow:auto;color:var(--body-text-color);list-style:none}.item.svelte-1ou0lab{display:flex;cursor:pointer;padding:var(--size-2);word-break:break-word}.item.svelte-1ou0lab:hover,.active.svelte-1ou0lab{background:var(--background-fill-secondary)}.inner-item.svelte-1ou0lab{padding-right:var(--size-1)}.hide.svelte-1ou0lab{visibility:hidden}.icon-wrap.svelte-1dv2vbb{color:var(--body-text-color);margin-right:var(--size-2);width:var(--size-5)}label.svelte-1dv2vbb:not(.container),label.svelte-1dv2vbb:not(.container) .wrap:where(.svelte-1dv2vbb),label.svelte-1dv2vbb:not(.container) .wrap-inner:where(.svelte-1dv2vbb),label.svelte-1dv2vbb:not(.container) .secondary-wrap:where(.svelte-1dv2vbb),label.svelte-1dv2vbb:not(.container) .token:where(.svelte-1dv2vbb),label.svelte-1dv2vbb:not(.container) input:where(.svelte-1dv2vbb){height:100%}.container.svelte-1dv2vbb .wrap:where(.svelte-1dv2vbb){box-shadow:var(--input-shadow);border:var(--input-border-width) solid var(--border-color-primary)}.wrap.svelte-1dv2vbb{position:relative;border-radius:var(--input-radius);background:var(--input-background-fill)}.wrap.svelte-1dv2vbb:focus-within{box-shadow:var(--input-shadow-focus);border-color:var(--input-border-color-focus)}.wrap-inner.svelte-1dv2vbb{display:flex;position:relative;flex-wrap:wrap;align-items:center;gap:var(--checkbox-label-gap);padding:var(--checkbox-label-padding)}.token.svelte-1dv2vbb{display:flex;align-items:center;transition:var(--button-transition);cursor:pointer;box-shadow:var(--checkbox-label-shadow);border:var(--checkbox-label-border-width) solid var(--checkbox-label-border-color);border-radius:var(--button-small-radius);background:var(--checkbox-label-background-fill);padding:var(--checkbox-label-padding);color:var(--checkbox-label-text-color);font-weight:var(--checkbox-label-text-weight);font-size:var(--checkbox-label-text-size);line-height:var(--line-md);word-break:break-word}.token.svelte-1dv2vbb>:where(.svelte-1dv2vbb)+:where(.svelte-1dv2vbb){margin-left:var(--size-2)}.token-remove.svelte-1dv2vbb{fill:var(--body-text-color);display:flex;justify-content:center;align-items:center;cursor:pointer;border:var(--checkbox-border-width) solid var(--border-color-primary);border-radius:var(--radius-full);background:var(--background-fill-primary);padding:var(--size-0-5);width:16px;height:16px;flex-shrink:0}.secondary-wrap.svelte-1dv2vbb{display:flex;flex:1 1 0%;align-items:center;border:none;min-width:min-content}input.svelte-1dv2vbb{margin:var(--spacing-sm);outline:none;border:none;background:inherit;width:var(--size-full);color:var(--body-text-color);font-size:var(--input-text-size)}input.svelte-1dv2vbb:disabled{-webkit-text-fill-color:var(--body-text-color);-webkit-opacity:1;opacity:1;cursor:not-allowed}.remove-all.svelte-1dv2vbb{margin-left:var(--size-1);width:20px;height:20px}.subdued.svelte-1dv2vbb{color:var(--body-text-color-subdued)}input[readonly].svelte-1dv2vbb{cursor:pointer}.icon-wrap.svelte-1xfsv4t{position:absolute;top:50%;transform:translateY(-50%);right:var(--size-5);color:var(--body-text-color);width:var(--size-5);pointer-events:none}.container.svelte-1xfsv4t{height:100%}.container.svelte-1xfsv4t .wrap:where(.svelte-1xfsv4t){box-shadow:var(--input-shadow);border:var(--input-border-width) solid var(--border-color-primary)}.wrap.svelte-1xfsv4t{position:relative;border-radius:var(--input-radius);background:var(--input-background-fill)}.wrap.svelte-1xfsv4t:focus-within{box-shadow:var(--input-shadow-focus);border-color:var(--input-border-color-focus);background:var(--input-background-fill-focus)}.wrap-inner.svelte-1xfsv4t{display:flex;position:relative;flex-wrap:wrap;align-items:center;gap:var(--checkbox-label-gap);padding:var(--checkbox-label-padding);height:100%}.secondary-wrap.svelte-1xfsv4t{display:flex;flex:1 1 0%;align-items:center;border:none;min-width:min-content;height:100%}input.svelte-1xfsv4t{margin:var(--spacing-sm);outline:none;border:none;background:inherit;width:var(--size-full);color:var(--body-text-color);font-size:var(--input-text-size);height:100%}input.svelte-1xfsv4t:disabled{-webkit-text-fill-color:var(--body-text-color);-webkit-opacity:1;opacity:1;cursor:not-allowed}.subdued.svelte-1xfsv4t{color:var(--body-text-color-subdued)}input[readonly].svelte-1xfsv4t{cursor:pointer}
