import{GLTFLoader as m}from"./glTFLoader-Bx351I09.js";import{aN as c,aO as l}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./bone-DdTyU8i_.js";import"./skeleton-C0c5yg7x.js";import"./rawTexture-CpjOe2U7.js";import"./assetContainer-Drc86vic.js";import"./objectModelMapping-DT0r674A.js";const t="MSFT_sRGBFactors";class d{constructor(o){this.name=t,this._loader=o,this.enabled=this._loader.isExtensionUsed(t)}dispose(){this._loader=null}loadMaterialPropertiesAsync(o,s,e){return m.LoadExtraAsync(o,s,this.name,async(u,p)=>{if(p){const r=this._loader._getOrCreateMaterialAdapter(e),n=this._loader.loadMaterialPropertiesAsync(o,s,e),a=e.getScene().getEngine().useExactSrgbConversions;return r.baseColorTexture||r.baseColor.toLinearSpaceToRef(r.baseColor,a),r.specularColorTexture||r.specularColor.toLinearSpaceToRef(r.specularColor,a),await n}})}}c(t);l(t,!0,i=>new d(i));export{d as MSFT_sRGBFactors};
