import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var o=e.from_html("<div> </div>");function i(v,l){e.push(l,!1);let a=e.prop(l,"value",12),r=e.prop(l,"type",12),p=e.prop(l,"selected",12,!1);var d={get value(){return a()},set value(t){a(t),e.flush()},get type(){return r()},set type(t){r(t),e.flush()},get selected(){return p()},set selected(t){p(t),e.flush()}},s=o();let u;var f=e.child(s,!0);return e.reset(s),e.template_effect(()=>{u=e.set_class(s,1,"svelte-1eh6nev",null,u,{table:r()==="table",gallery:r()==="gallery",selected:p()}),e.set_text(f,a())}),e.append(v,s),e.pop(d)}export{i as default};
