import{GLTFLoader as m}from"./glTFLoader-Bx351I09.js";import{aN as u,aO as p}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./bone-DdTyU8i_.js";import"./skeleton-C0c5yg7x.js";import"./rawTexture-CpjOe2U7.js";import"./assetContainer-Drc86vic.js";import"./objectModelMapping-DT0r674A.js";const n="KHR_materials_diffuse_roughness";class h{constructor(s){this.name=n,this.order=190,this._loader=s,this.enabled=this._loader.isExtensionUsed(n)}dispose(){this._loader=null}loadMaterialPropertiesAsync(s,e,o){return m.LoadExtensionAsync(s,e,this.name,async(t,i)=>{const r=new Array;return r.push(this._loader.loadMaterialPropertiesAsync(s,e,o)),r.push(this._loadDiffuseRoughnessPropertiesAsync(t,i,o)),await Promise.all(r).then(()=>{})})}_loadDiffuseRoughnessPropertiesAsync(s,e,o){const t=this._loader._getOrCreateMaterialAdapter(o),i=new Array;return t.baseDiffuseRoughness=e.diffuseRoughnessFactor??0,e.diffuseRoughnessTexture&&i.push(this._loader.loadTextureInfoAsync(`${s}/diffuseRoughnessTexture`,e.diffuseRoughnessTexture,r=>{r.name=`${o.name} (Diffuse Roughness)`,t.baseDiffuseRoughnessTexture=r})),Promise.all(i).then(()=>{})}}u(n);p(n,!0,a=>new h(a));export{h as KHR_materials_diffuse_roughness};
