import"./svelte/svelte_internal_flags_async.js";import*as r from"./svelte/svelte_internal_client.js";import{n as o}from"./i18n-BldJSFLV.js";import{G as n}from"./utils.svelte-Ceck75cM.js";import{onMount as l}from"./svelte/svelte_svelte.js";import{get as d}from"./svelte/svelte_store.js";import"./svelte/svelte_internal_flags_legacy.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";var _=r.from_html('<div style="display: none;"></div>');function A(m,i){r.push(i,!0);const a=r.rest_props(i,["$$slots","$$events","$$legacy"]),t=new n(a);let p=r.derived(()=>({visible:t.shared.visible,main_page_name:t.props.main_page_name??"Home",value:t.props.value}));l(()=>{d(o)||o.set(r.get(p))}),r.user_effect(()=>{o.set(r.get(p))});var e=_();r.template_effect(s=>{r.set_attribute(e,"id",t.shared.elem_id),r.set_class(e,1,s)},[()=>r.clsx(t.shared.elem_classes.join(" "))]),r.append(m,e),r.pop()}export{A as default};
