div.svelte-d5xbca{display:flex;flex-direction:inherit;flex-wrap:wrap;gap:var(--form-gap-width);box-shadow:var(--block-shadow);border:var(--block-border-width) solid var(--block-border-color);border-radius:var(--block-radius);background:var(--border-color-primary);overflow-y:hidden}div.svelte-d5xbca .block{box-shadow:none!important;border-width:0px!important;border-radius:0!important}.hidden.svelte-d5xbca{display:none}.hidden-css.svelte-d5xbca{display:none!important}
