.input-model.svelte-18wa0f8{display:flex;position:relative;justify-content:center;align-items:center;width:var(--size-full);height:var(--size-full);border-radius:var(--block-radius);overflow:hidden}.input-model.svelte-18wa0f8 canvas{width:var(--size-full);height:var(--size-full);object-fit:contain;overflow:hidden}
