import{GLTFLoader as m}from"./glTFLoader-Bx351I09.js";import{aN as a,aO as d}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./bone-DdTyU8i_.js";import"./skeleton-C0c5yg7x.js";import"./rawTexture-CpjOe2U7.js";import"./assetContainer-Drc86vic.js";import"./objectModelMapping-DT0r674A.js";const e="KHR_materials_dispersion";class l{constructor(r){this.name=e,this.order=174,this._loader=r,this.enabled=this._loader.isExtensionUsed(e)}dispose(){this._loader=null}loadMaterialPropertiesAsync(r,i,s){return m.LoadExtensionAsync(r,i,this.name,async(o,t)=>{const p=new Array;return p.push(this._loader.loadMaterialPropertiesAsync(r,i,s)),p.push(this._loadDispersionPropertiesAsync(o,i,s,t)),await Promise.all(p).then(()=>{})})}_loadDispersionPropertiesAsync(r,i,s,o){const t=this._loader._getOrCreateMaterialAdapter(s);return t.transmissionWeight>0||!o.dispersion||(t.transmissionDispersionAbbeNumber=20/o.dispersion),Promise.resolve()}}a(e);d(e,!0,n=>new l(n));export{l as KHR_materials_dispersion};
