button.svelte-1dqolfz{cursor:pointer;width:var(--size-full)}.wrap.svelte-1dqolfz{display:flex;flex-direction:column;justify-content:center;align-items:center;min-height:var(--size-60);color:var(--block-label-text-color);height:100%;padding-top:var(--size-3)}.icon-wrap.svelte-1dqolfz{width:30px;margin-bottom:var(--spacing-lg)}@media(min-width:768px){.wrap.svelte-1dqolfz{font-size:var(--text-lg)}}.wrap.svelte-1tktvmr{position:relative;width:var(--size-full);height:var(--size-full)}.hide.svelte-1tktvmr{display:none}video.svelte-1tktvmr{width:var(--size-full);height:var(--size-full);object-fit:contain}.button-wrap.svelte-1tktvmr{position:absolute;background-color:var(--block-background-fill);border:1px solid var(--border-color-primary);padding:var(--size-1-5);display:flex;bottom:var(--size-2);left:50%;transform:translate(-50%);box-shadow:var(--shadow-drop-lg);border-radius:var(--radius-xl);line-height:var(--size-3);color:var(--button-secondary-text-color)}.icon-with-text.svelte-1tktvmr{width:var(--size-20);align-items:center;margin:0 var(--spacing-xl);display:flex;justify-content:space-evenly}@media(min-width:768px){button.svelte-1tktvmr{bottom:var(--size-4)}}@media(min-width:1280px){button.svelte-1tktvmr{bottom:var(--size-8)}}.icon.svelte-1tktvmr{width:18px;height:18px;display:flex;justify-content:space-between;align-items:center}.color-primary.svelte-1tktvmr{fill:var(--primary-600);stroke:var(--primary-600);color:var(--primary-600)}.flip.svelte-1tktvmr{transform:scaleX(-1)}.select-wrap.svelte-1tktvmr{-webkit-appearance:none;-moz-appearance:none;appearance:none;color:var(--button-secondary-text-color);background-color:transparent;width:95%;font-size:var(--text-md);position:absolute;bottom:var(--size-2);background-color:var(--block-background-fill);box-shadow:var(--shadow-drop-lg);border-radius:var(--radius-xl);z-index:var(--layer-top);border:1px solid var(--border-color-primary);text-align:left;line-height:var(--size-4);white-space:nowrap;text-overflow:ellipsis;left:50%;transform:translate(-50%);max-width:var(--size-52)}.select-wrap.svelte-1tktvmr>option:where(.svelte-1tktvmr){padding:.25rem .5rem;border-bottom:1px solid var(--border-color-accent);padding-right:var(--size-8);text-overflow:ellipsis;overflow:hidden}.select-wrap.svelte-1tktvmr>option:where(.svelte-1tktvmr):hover{background-color:var(--color-accent)}.select-wrap.svelte-1tktvmr>option:where(.svelte-1tktvmr):last-child{border:none}@media(min-width:768px){.wrap.svelte-1tktvmr{font-size:var(--text-lg)}}.image-frame.svelte-6uxbr3 img{width:var(--size-full);height:var(--size-full);object-fit:scale-down}.upload-container.svelte-6uxbr3{display:flex;align-items:center;justify-content:center;height:100%;flex-shrink:1;max-height:100%}.reduced-height.svelte-6uxbr3{height:calc(100% - var(--size-10))}.image-container.svelte-6uxbr3{display:flex;height:100%;flex-direction:column;justify-content:center;align-items:center;max-height:100%}.selectable.svelte-6uxbr3{cursor:crosshair}.image-frame.svelte-6uxbr3{object-fit:cover;width:100%;height:100%}
