import{_ as o,l as p,H as a,e,I as s}from"./mermaid.core-BN1TdaiK-CkX93Jpj.js";import{p as n}from"./treemap-KMMF4GRG-CvaGS1yA-NJdGYCDs.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./Index-BpHS9YhG.js";import"./i18n-BldJSFLV.js";import"./utils.svelte-Ceck75cM.js";import"./index-tFQomdd2.js";import"./dsv-DB8NKgIY.js";import"./index-CnqicUFC.js";import"./ModifyUpload-BzsLgPw2.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";import"./Index-aAgh1OXe.js";import"./StreamingBar-b2qVLPYU.js";import"./FullscreenButton-Cqzqqtq6.js";import"./Example-BRN12iqL.js";import"./_baseUniq-BCzTs16Z-BRql6QeN.js";import"./_basePickBy-BSV_1zpR-D13SnWW2.js";import"./clone-04FuOcyX-A55wydoQ.js";var g={parse:o(async r=>{const t=await n("info",r);p.debug(t)},"parse")},v={version:s.version+""},d=o(()=>v.version,"getVersion"),c={getVersion:d},l=o((r,t,m)=>{p.debug(`rendering info diagram
`+r);const i=a(t);e(i,100,400,!0),i.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${m}`)},"draw"),f={draw:l},rr={parser:g,db:c,renderer:f};export{rr as diagram};
