const a="Español",o={annotated_image:"Imagen Anotada"},e={allow_recording_access:"Por favor, permita el acceso al micrófono para grabar.",audio:"Audio",record_from_microphone:"Grabar desde el micrófono",stop_recording:"Detener grabación",no_device_support:"No se pudo acceder a los dispositivos multimedia. Compruebe que está ejecutando en un origen seguro (https) o localhost (o que ha pasado un certificado SSL válido a ssl_verify), y que ha permitido el acceso del navegador a su dispositivo.",stop:"Detener",resume:"Reanudar",record:"Grabar",no_microphone:"No se encontró micrófono",pause:"Pausar",play:"Reproducir",waiting:"Esperando",drop_to_upload:"Arrastra un archivo de audio aquí para subirlo"},r={connection_can_break:"En dispositivos móviles, la conexión puede interrumpirse si esta pestaña pierde el foco o el dispositivo entra en reposo, perdiendo su posición en la cola.",long_requests_queue:"Hay una larga cola de solicitudes pendientes. Duplique este Space para saltarse la cola.",lost_connection:"Se perdió la conexión al abandonar la página. Volviendo a la cola...",waiting_for_inputs:"Esperando a que se complete(n) la(s) carga(s) de archivo(s), por favor inténtelo de nuevo."},i={checkbox:"Casilla de verificación",checkbox_group:"Grupo de casillas"},n={code:"Código"},c={color_picker:"Selector de color"},l={built_with:"construido con",built_with_gradio:"Construido con Gradio",clear:"Limpiar",download:"Descargar",edit:"Editar",empty:"Vacío",error:"Error",flag:"Marcar",hosted_on:"Alojado en",loading:"Cargando",logo:"logo",or:"o",remove:"Eliminar",settings:"Configuración",share:"Compartir",submit:"Enviar",undo:"Deshacer",no_devices:"No se encontraron dispositivos",language:"Idioma",display_theme:"Tema de visualización",pwa:"Aplicación web progresiva"},s={incorrect_format:"Formato incorrecto, solo se admiten archivos CSV y TSV",new_column:"Agregar columna",new_row:"Nueva fila",add_row_above:"Agregar fila arriba",add_row_below:"Agregar fila abajo",add_column_left:"Agregar columna a la izquierda",add_column_right:"Agregar columna a la derecha",delete_row:"Eliminar fila",delete_column:"Eliminar columna",sort_column:"Ordenar columna",sort_ascending:"Ordenar ascendente",sort_descending:"Ordenar descendente",drop_to_upload:"Arrastra y suelta los archivos CSV o TSV aquí para importar datos al dataframe",clear_sort:"Limpiar ordenamiento"},d={dropdown:"Menú desplegable"},t={build_error:"hay un error de compilación",config_error:"hay un error de configuración",contact_page_author:"Por favor, contacte al autor de la página para informarle.",no_app_file:"no hay archivo de aplicación",runtime_error:"hay un error de ejecución",space_not_working:'"El Space no funciona porque" {0}',space_paused:"el space está pausado",use_via_api:"Usar vía API",use_via_api_or_mcp:"Usar vía API o MCP"},u={uploading:"Subiendo..."},p={highlighted_text:"Texto resaltado"},_={allow_webcam_access:"Por favor, permita el acceso a la cámara web para grabar.",brush_color:"Color del pincel",brush_radius:"Radio del pincel",image:"Imagen",remove_image:"Eliminar imagen",select_brush_color:"Seleccionar color del pincel",start_drawing:"Empezar a dibujar",use_brush:"Usar pincel",drop_to_upload:"Arrastra un archivo de imagen aquí para subirlo"},g={label:"Etiqueta"},m={enable_cookies:"Si está visitando un Space de HuggingFace en modo Incógnito, debe habilitar las cookies de terceros.",incorrect_credentials:"Credenciales incorrectas",username:"usuario",password:"contraseña",login:"Iniciar sesión"},b={number:"Número"},h={plot:"Gráfico"},v={radio:"Radio"},f={slider:"Deslizador"},q={click_to_upload:"Haga clic para cargar",drop_audio:"Coloque el audio aquí",drop_csv:"Coloque el CSV aquí",drop_file:"Coloque el archivo aquí",drop_image:"Coloque la imagen aquí",drop_video:"Coloque el video aquí",drop_gallery:"Coloque las imágenes aquí",paste_clipboard:"Pegar desde el portapapeles"},w={drop_to_upload:"Arrastra un archivo de video aquí para subirlo"},C={edit:"Editar",retry:"Reintentar",undo:"Deshacer",submit:"Enviar",cancel:"Cancelar",like:"Me gusta",dislike:"No me gusta",clear:"Limpiar chat"},y={_name:a,"3D_model":{"3d_model":"Modelo 3D",drop_to_upload:"Arrastra y suelta un archivo de modelo 3D (.obj, .glb, .stl, .gltf, .splat o .ply) aquí para cargarlo."},annotated_image:o,audio:e,blocks:r,checkbox:i,code:n,color_picker:c,common:l,dataframe:s,dropdown:d,errors:t,file:u,highlighted_text:p,image:_,label:g,login:m,number:b,plot:h,radio:v,slider:f,upload_text:q,video:w,chatbot:C};

export { a as _name, o as annotated_image, e as audio, r as blocks, C as chatbot, i as checkbox, n as code, c as color_picker, l as common, s as dataframe, y as default, d as dropdown, t as errors, u as file, p as highlighted_text, _ as image, g as label, m as login, b as number, h as plot, v as radio, f as slider, q as upload_text, w as video };
//# sourceMappingURL=es-CHrrrvnD.js.map
