const o="繁體中文",e={built_with_gradio:"使用 Gradio 建構",clear:"清除",or:"或",submit:"提交",built_with:"使用",download:"下載",edit:"編輯",empty:"空白",error:"錯誤",hosted_on:"托管於",loading:"載入中",logo:"標誌",remove:"移除",settings:"設定",share:"分享",undo:"復原",no_devices:"未找到裝置",language:"語言",display_theme:"顯示主題",pwa:"漸進式網頁應用程式"},r={click_to_upload:"點擊上傳",drop_audio:"拖放音訊至此處",drop_csv:"拖放 CSV 至此處",drop_file:"拖放檔案至此處",drop_image:"拖放圖片至此處",drop_video:"拖放影片至此處",drop_gallery:"在此處拖放媒體",paste_clipboard:"從剪貼簿貼上"},t={annotated_image:"標註圖像"},_={allow_recording_access:"請允許存取麥克風以進行錄音。",audio:"音訊",drop_to_upload:"將音訊檔案拖放到這裡上傳",record_from_microphone:"從麥克風錄音",stop_recording:"停止錄製",no_device_support:"無法存取媒體裝置。請確認您正在使用安全來源（https）或本機主機（或您已提供有效的 SSL 憑證以進行 ssl_verify），並且已允許瀏覽器存取您的裝置。",stop:"停止",resume:"繼續",record:"錄製",no_microphone:"未找到麥克風",pause:"暫停",play:"播放",waiting:"等待中"},c={connection_can_break:"在行動裝置上，如果此分頁失去焦點或裝置進入睡眠模式，連線可能會中斷，導致您在隊列中的位置遺失。",long_requests_queue:"目前有許多待處理的請求。複製此 Space 以跳過隊列。",lost_connection:"因離開頁面而失去連接。正在重新加入隊列...",waiting_for_inputs:"等待檔案上傳完成，請稍後重試。"},a={checkbox:"核取方塊",checkbox_group:"核取方塊群組"},n={code:"程式碼"},s={color_picker:"顏色選擇器"},d={incorrect_format:"格式不正確，僅支援 CSV 和 TSV 檔案",new_column:"新增欄位",new_row:"新增列",add_row_above:"在上方新增列",add_row_below:"在下方新增列",delete_row:"刪除列",delete_column:"刪除欄位",add_column_left:"在左側新增欄位",add_column_right:"在右側新增欄位",sort_column:"排序欄位",sort_ascending:"升冪排序",sort_descending:"降冪排序",drop_to_upload:"將 CSV 或 TSV 檔案拖放到這裡以匯入資料到資料框中",clear_sort:"清除排序"},i={dropdown:"下拉選單"},l={build_error:"有建置錯誤",config_error:"有設定錯誤",contact_page_author:"請聯繫頁面的作者以通知他們。",no_app_file:"沒有應用程式檔案",runtime_error:"有執行時錯誤",space_not_working:'"Space 無法運作，因為" {0}',space_paused:"Space 已暫停",use_via_api:"透過 API 使用",use_via_api_or_mcp:"透過 API 或 MCP 使用"},p={uploading:"上傳中..."},u={highlighted_text:"醒目提示的文字"},g={allow_webcam_access:"請允許存取網路攝影機以進行錄製。",brush_color:"筆刷顏色",brush_radius:"筆刷大小",image:"圖像",remove_image:"移除圖片",select_brush_color:"選擇筆刷顏色",start_drawing:"開始繪圖",use_brush:"使用筆刷",drop_to_upload:"將圖像檔案拖放到這裡上傳"},m={label:"標籤"},b={enable_cookies:"如果您在無痕模式下訪問 HuggingFace Space，您必須啟用第三方 Cookie。",incorrect_credentials:"憑證錯誤",username:"使用者名稱",password:"密碼",login:"登入"},h={number:"數字"},w={plot:"圖表"},k={radio:"單選按鈕"},f={slider:"滑桿"},v={drop_to_upload:"將影片檔案拖放到這裡上傳"},S={edit:"編輯",retry:"重試",undo:"復原",submit:"送出",cancel:"取消",like:"讚",dislike:"不讚",clear:"清空對話"},x={_name:o,common:e,upload_text:r,"3D_model":{"3d_model":"3D 模型",drop_to_upload:"將 3D 模型 (.obj、.glb、.stl、.gltf、.splat 或 .ply) 檔案拖放到這裡上傳"},annotated_image:t,audio:_,blocks:c,checkbox:a,code:n,color_picker:s,dataframe:d,dropdown:i,errors:l,file:p,highlighted_text:u,image:g,label:m,login:b,number:h,plot:w,radio:k,slider:f,video:v,chatbot:S};export{o as _name,t as annotated_image,_ as audio,c as blocks,S as chatbot,a as checkbox,n as code,s as color_picker,e as common,d as dataframe,x as default,i as dropdown,l as errors,p as file,u as highlighted_text,g as image,m as label,b as login,h as number,w as plot,k as radio,f as slider,r as upload_text,v as video};
