import{A as o}from"./webAudioBaseSubGraph-ymNBfs1g.js";class r extends o{constructor(s,t,u=2){super(s,t,u),this._outBus=null,this._onOutBusDisposed=()=>{this._outBus=null}}get outBus(){return this._outBus}set outBus(s){if(this._outBus!==s){if(this._outBus&&(this._outBus.onDisposeObservable.removeCallback(this._onOutBusDisposed),!this._disconnect(this._outBus)))throw new Error("Disconnect failed");if(this._outBus=s,this._outBus&&(this._outBus.onDisposeObservable.add(this._onOutBusDisposed),!this._connect(this._outBus)))throw new Error("Connect failed")}}dispose(){super.dispose(),this._outBus=null}}export{r as A};
