label.svelte-19qdtil{display:flex;align-items:center;transition:var(--button-transition);cursor:pointer;box-shadow:var(--checkbox-label-shadow);border:var(--checkbox-label-border-width) solid var(--checkbox-label-border-color);border-radius:var(--checkbox-border-radius);background:var(--checkbox-label-background-fill);padding:var(--checkbox-label-padding);color:var(--checkbox-label-text-color);font-weight:var(--checkbox-label-text-weight);font-size:var(--checkbox-label-text-size);line-height:var(--line-md)}label.svelte-19qdtil:hover{background:var(--checkbox-label-background-fill-hover)}label.svelte-19qdtil:focus{background:var(--checkbox-label-background-fill-focus)}label.selected.svelte-19qdtil{background:var(--checkbox-label-background-fill-selected);color:var(--checkbox-label-text-color-selected);border-color:var(--checkbox-label-border-color-selected)}label.svelte-19qdtil>:where(.svelte-19qdtil)+:where(.svelte-19qdtil){margin-left:var(--size-2)}label.rtl.svelte-19qdtil>:where(.svelte-19qdtil)+:where(.svelte-19qdtil){margin-left:0;margin-right:var(--size-2)}input.svelte-19qdtil{--ring-color: transparent;position:relative;box-shadow:var(--checkbox-shadow);border:var(--checkbox-border-width) solid var(--checkbox-border-color);border-radius:var(--radius-full);background-color:var(--checkbox-background-color);line-height:var(--line-sm)}input.svelte-19qdtil:checked,input.svelte-19qdtil:checked:hover{border-color:var(--checkbox-border-color-selected);background-image:var(--radio-circle);background-color:var(--checkbox-background-color-selected)}input.svelte-19qdtil:checked:after{content:"";position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);border-radius:50%;background-color:#fff}input.svelte-19qdtil:hover:not([disabled]){border-color:var(--checkbox-border-color-hover);background-color:var(--checkbox-background-color-hover)}input.svelte-19qdtil:focus:not([disabled]){border-color:var(--checkbox-border-color-focus);background-color:var(--checkbox-background-color-focus)}input.svelte-19qdtil:checked:focus:not([disabled]){border-color:var(--checkbox-border-color-focus);background-image:var(--radio-circle);background-color:var(--checkbox-background-color-selected)}input[disabled].svelte-19qdtil,.disabled.svelte-19qdtil{cursor:not-allowed}input[disabled].svelte-19qdtil{opacity:.75}.wrap.svelte-e4x47i{display:flex;flex-wrap:wrap;gap:var(--checkbox-label-gap)}
