:where(._jsonList.svelte-dh6g6y){list-style:none;margin:0;padding:0;padding-left:var(--jsonPaddingLeft, 1rem);border-left:var(--jsonBorderLeft, 1px dotted)}:where(._jsonBkt.svelte-dh6g6y){color:var(--jsonBracketColor, currentcolor)}.svelte-dh6g6y:where(._jsonBkt:where(.svelte-dh6g6y)):not(.empty):hover{cursor:pointer;background:var(--jsonBracketHoverBackground, #e5e7eb)}:where(._jsonSep.svelte-dh6g6y){color:var(--jsonSeparatorColor, currentcolor)}:where(._jsonKey.svelte-dh6g6y){color:var(--jsonKeyColor, currentcolor)}:where(._jsonVal.svelte-dh6g6y){color:var(--jsonValColor, #9ca3af)}:where(._jsonVal:where(.svelte-dh6g6y)).string.svelte-dh6g6y{color:var(--jsonValStringColor, #059669)}:where(._jsonVal:where(.svelte-dh6g6y)).number.svelte-dh6g6y{color:var(--jsonValNumberColor, #d97706)}:where(._jsonVal:where(.svelte-dh6g6y)).boolean.svelte-dh6g6y{color:var(--jsonValBooleanColor, #2563eb)}
