import"./svelte/svelte_internal_flags_async.js";import*as o from"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import{G as i}from"./utils.svelte-Ceck75cM.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";function b(m,r){o.push(r,!0);let p=o.rest_props(r,["$$slots","$$events","$$legacy"]);const t=new i(p);o.user_effect(()=>{t.props.value&&t.dispatch("change")}),o.pop()}export{b as default};
