import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";function s(r,a){e.push(a,!1);let t=e.prop(a,"value",12);var l={get value(){return t()},set value(u){t(u),e.flush()}};e.next();var p=e.text();return e.template_effect(()=>e.set_text(p,t()||"")),e.append(r,p),e.pop(l)}export{s as default};
