// generated during release, do not modify

/**
 * The current version, as set in package.json.
 * @type {string}
 */
const VERSION = '5.43.14';
const PUBLIC_VERSION = '5';

export { PUBLIC_VERSION as P, VERSION as V };
