import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var n=e.from_html("<div><!></div>");function c(d,l){var t=n();let i,s;var a=e.child(t);e.slot(a,l,"default",{},null),e.reset(t),e.template_effect(()=>{i=e.set_class(t,1,"form svelte-d5xbca",null,i,{hidden:l.visible===!1,"hidden-css":l.visible==="hidden"}),s=e.set_style(t,"",s,{"flex-grow":l.scale,"min-width":`calc(min(${l.min_width}px, 100%))`})}),e.append(d,t)}export{c as B};
