.image-container.svelte-12vrxzd{height:100%;position:relative;min-width:var(--size-20)}.image-container.svelte-12vrxzd button:where(.svelte-12vrxzd){width:var(--size-full);height:var(--size-full);border-radius:var(--radius-lg);display:flex;align-items:center;justify-content:center}.image-frame.svelte-12vrxzd img{width:var(--size-full);height:var(--size-full);object-fit:scale-down}.selectable.svelte-12vrxzd{cursor:crosshair}.fullscreen-controls svg{position:relative;top:0}.image-container:fullscreen{background-color:#000;display:flex;justify-content:center;align-items:center}.image-container:fullscreen img{max-width:90vw;max-height:90vh;object-fit:scale-down}.image-frame.svelte-12vrxzd{width:auto;height:100%;display:flex;align-items:center;justify-content:center}
