import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var f=e.from_html("<div><!></div>");function n(o,l){e.push(l,!1);let a=e.prop(l,"value",12),r=e.prop(l,"type",12),p=e.prop(l,"selected",12,!1);var d={get value(){return a()},set value(t){a(t),e.flush()},get type(){return r()},set type(t){r(t),e.flush()},get selected(){return p()},set selected(t){p(t),e.flush()}},s=f();let u;var v=e.child(s);return e.html(v,a),e.reset(s),e.template_effect(()=>u=e.set_class(s,1,"prose svelte-s7j0w2",null,u,{table:r()==="table",gallery:r()==="gallery",selected:p()})),e.append(o,s),e.pop(d)}export{n as default};
