div.svelte-1xjkzpp .math.inline{fill:var(--body-text-color);display:inline-block;vertical-align:middle;padding:var(--size-1-5) -var(--size-1);color:var(--body-text-color)}div.svelte-1xjkzpp .math.inline svg{display:inline;margin-bottom:.22em}div.svelte-1xjkzpp{max-width:100%}.hide.svelte-1xjkzpp{display:none}div.svelte-16ln60g{transition:.15s}.pending.svelte-16ln60g{opacity:.2}.padding.svelte-16ln60g{padding:var(--block-padding)}
