import{GLTFLoader as a}from"./glTFLoader-Bx351I09.js";import{aN as n,aO as p}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./bone-DdTyU8i_.js";import"./skeleton-C0c5yg7x.js";import"./rawTexture-CpjOe2U7.js";import"./assetContainer-Drc86vic.js";import"./objectModelMapping-DT0r674A.js";const e="KHR_materials_emissive_strength";class d{constructor(i){this.name=e,this.order=170,this._loader=i,this.enabled=this._loader.isExtensionUsed(e)}dispose(){this._loader=null}loadMaterialPropertiesAsync(i,t,r){return a.LoadExtensionAsync(i,t,this.name,async(o,m)=>(await this._loader.loadMaterialPropertiesAsync(i,t,r),this._loadEmissiveProperties(o,m,r),await Promise.resolve()))}_loadEmissiveProperties(i,t,r){if(t.emissiveStrength!==void 0){const o=this._loader._getOrCreateMaterialAdapter(r);o.emissionLuminance=t.emissiveStrength}}}n(e);p(e,!0,s=>new d(s));export{d as KHR_materials_emissive_strength};
