import{F as o,g as s,G as a}from"./KHR_interactivity-DRPs30Rf.js";import{R as e,F as m}from"./declarationMapper-CGPHX8aB.js";import{R as l}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class u extends o{constructor(t){super(t),this.config=t,this.type=this.registerDataInput("type",e,t.type),this.value=this.registerDataOutput("value",e),this.index=this.registerDataInput("index",e,new m(s(t.index??-1)))}_updateOutputs(t){const r=this.type.getValue(t),i=this.index.getValue(t),p=a(t.assetsContext,r,s(i),this.config.useIndexAsUniqueId);this.value.setValue(p,t)}getClassName(){return"FlowGraphGetAssetBlock"}}l("FlowGraphGetAssetBlock",u);export{u as FlowGraphGetAssetBlock};
