import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var v=e.from_html("<div> </div>");function g(p,l){e.push(l,!1);let s=e.prop(l,"value",12),r=e.prop(l,"type",12),u=e.prop(l,"selected",12,!1),c=e.prop(l,"choices",12),i=e.mutable_source();if(s()===null)e.set(i,"");else{let t=c().find(d=>d[1]===s());e.set(i,t?t[0]:"")}var n={get value(){return s()},set value(t){s(t),e.flush()},get type(){return r()},set type(t){r(t),e.flush()},get selected(){return u()},set selected(t){u(t),e.flush()},get choices(){return c()},set choices(t){c(t),e.flush()}};e.init();var a=v();let o;var f=e.child(a,!0);return e.reset(a),e.template_effect(()=>{o=e.set_class(a,1,"svelte-g2dls0",null,o,{table:r()==="table",gallery:r()==="gallery",selected:u()}),e.set_text(f,e.get(i))}),e.append(p,a),e.pop(n)}export{g as default};
