import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";function _(s,a){t.push(a,!1);let l=t.prop(a,"title",12),p=t.prop(a,"x",12),f=t.prop(a,"y",12);var i={get title(){return l()},set title(e){l(e),t.flush()},get x(){return p()},set x(e){p(e),t.flush()},get y(){return f()},set y(e){f(e),t.flush()}},x=t.comment(),n=t.first_child(x);{var m=e=>{var r=t.text();t.template_effect(()=>t.set_text(r,l())),t.append(e,r)},o=e=>{var r=t.text();t.template_effect(()=>t.set_text(r,`${p()??""} x ${f()??""}`)),t.append(e,r)};t.if(n,e=>{l()?e(m):e(o,!1)})}return t.append(s,x),t.pop(i)}export{_ as default};
