const i="Lietuvių",a={built_with_gradio:"Sukurta su Gradio",clear:"Išvalyti",or:"arba",submit:"Pateikti",settings:"Nustatymai",built_with:"sukurta su",download:"Atsisiųsti",edit:"Redaguoti",empty:"Tuščia",error:"Klaida",hosted_on:"Talpinama",loading:"Kraunama",logo:"logotipas",remove:"Pašalinti",share:"Dalintis",undo:"Atšaukti",no_devices:"Nerasta jokių įrenginių",language:"Kalba",display_theme:"Ekrano tema",pwa:"Progresyvi interneto programėlė"},e={click_to_upload:"Spustelėkite norėdami įkelti",drop_audio:"Įkelkite garso įrašą čia",drop_csv:"Įkelkite CSV čia",drop_file:"Įkelkite failą čia",drop_image:"Įkelkite paveikslėlį čia",drop_video:"Įkelkite vaizdo įrašą čia",drop_gallery:"Įkelkite mediją čia",paste_clipboard:"Įklijuoti iš iškarpinės"},t={annotated_image:"Pažymėtas paveikslėlis"},o={allow_recording_access:"Prašome suteikti prieigą prie mikrofono įrašymui.",audio:"Garsas",drop_to_upload:"Įkelkite garso failą čia",record_from_microphone:"Įrašyti iš mikrofono",stop_recording:"Stabdyti įrašymą",no_device_support:"Nepavyko pasiekti medijos įrenginių. Patikrinkite, ar naudojate saugią prieigą (https) arba localhost (arba perduodate galiojantį SSL sertifikatą į ssl_verify), ir leidžiate naršyklei prieiti prie jūsų įrenginio.",stop:"Stabdyti",resume:"Tęsti",record:"Įrašyti",no_microphone:"Mikrofonas nerastas",pause:"Pristabdyti",play:"Groti",waiting:"Laukiama"},r={connection_can_break:"Mobiliajame įrenginyje ryšys gali nutrūkti, jei šis skirtukas bus neaktyvus arba įrenginys užmigs, todėl galite prarasti savo vietą eilėje.",long_requests_queue:"Yra ilga laukiančių užklausų eilė. Dubliuokite šią erdvę, kad praleistumėte eilę.",lost_connection:"Ryšys nutrūko išėjus iš puslapio. Vėl jungiamasi į eilę...",waiting_for_inputs:"Laukiama, kol bus baigti įkelti failai, prašome bandyti dar kartą."},s={checkbox:"Žymimasis langelis",checkbox_group:"Žymimųjų langelių grupė"},l={code:"Kodas"},n={color_picker:"Spalvos pasirinkimas"},d={incorrect_format:"Neteisingas formatas, palaikomi tik CSV ir TSV failai",new_column:"Pridėti stulpelį",new_row:"Nauja eilutė",add_row_above:"Pridėti eilutę viršuje",add_row_below:"Pridėti eilutę žemiau",delete_row:"Ištrinti eilutę",delete_column:"Ištrinti stulpelį",add_column_left:"Pridėti stulpelį kairėje",add_column_right:"Pridėti stulpelį dešinėje",sort_column:"Rikiuoti stulpelį",sort_ascending:"Rikiuoti didėjančia tvarka",sort_descending:"Rikiuoti mažėjančia tvarka",drop_to_upload:"Įkelkite CSV arba TSV failus čia, kad importuotumėte duomenis į duomenų lentelę",clear_sort:"Išvalyti rikiavimą"},u={dropdown:"Išskleidžiamasis sąrašas"},k={build_error:"yra kompiliavimo klaida",config_error:"yra konfigūracijos klaida",contact_page_author:"Prašome susisiekti su puslapio autoriumi.",no_app_file:"nėra programos failo",runtime_error:"yra vykdymo klaida",space_not_working:'"Erdvė neveikia, nes" {0}',space_paused:"erdvė yra pristabdyta",use_via_api:"Naudoti per API",use_via_api_or_mcp:"Naudoti per API arba MCP"},p={uploading:"Įkeliama..."},_={highlighted_text:"Paryškintas tekstas"},c={allow_webcam_access:"Prašome suteikti prieigą prie internetinės kameros įrašymui.",brush_color:"Teptuko spalva",brush_radius:"Teptuko dydis",image:"Paveikslėlis",remove_image:"Pašalinti paveikslėlį",select_brush_color:"Pasirinkite teptuko spalvą",start_drawing:"Pradėti piešti",use_brush:"Naudoti teptuką",drop_to_upload:"Įkelkite paveikslėlio failą čia"},m={label:"Etiketė"},g={enable_cookies:"Jei lankotės HuggingFace erdvėje inkognito režimu, turite leisti trečiųjų šalių slapukus.",incorrect_credentials:"Neteisingi prisijungimo duomenys",username:"Vartotojo vardas",password:"Slaptažodis",login:"Prisijungti"},b={number:"Skaičius"},y={plot:"Grafikas"},v={radio:"Pasirinkimo mygtukas"},f={slider:"Slankiklis"},j={drop_to_upload:"Įkelkite vaizdo įrašo failą čia"},P={edit:"Redaguoti",retry:"Bandyti dar kartą",undo:"Atšaukti",submit:"Pateikti",cancel:"Atšaukti",like:"Patinka",dislike:"Nepatinka",clear:"Išvalyti pokalbį"},h={_name:i,common:a,upload_text:e,"3D_model":{"3d_model":"3D modelis",drop_to_upload:"Įkelkite 3D modelio failą (.obj, .glb, .stl, .gltf, .splat arba .ply) čia"},annotated_image:t,audio:o,blocks:r,checkbox:s,code:l,color_picker:n,dataframe:d,dropdown:u,errors:k,file:p,highlighted_text:_,image:c,label:m,login:g,number:b,plot:y,radio:v,slider:f,video:j,chatbot:P};export{i as _name,t as annotated_image,o as audio,r as blocks,P as chatbot,s as checkbox,l as code,n as color_picker,a as common,d as dataframe,h as default,u as dropdown,k as errors,p as file,_ as highlighted_text,c as image,m as label,g as login,b as number,y as plot,v as radio,f as slider,e as upload_text,j as video};
