import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var v=e.from_html("<pre> </pre>");function g(f,r){e.push(r,!1);let l=e.prop(r,"value",12),s=e.prop(r,"type",12),u=e.prop(r,"selected",12,!1);function o(t,c=60){if(!t)return"";const p=String(t);return p.length<=c?p:p.slice(0,c)+"..."}var d={get value(){return l()},set value(t){l(t),e.flush()},get type(){return s()},set type(t){s(t),e.flush()},get selected(){return u()},set selected(t){u(t),e.flush()}},a=v();let n;var i=e.child(a,!0);return e.reset(a),e.template_effect(t=>{n=e.set_class(a,1,"svelte-1bbj91m",null,n,{table:s()==="table",gallery:s()==="gallery",selected:u()}),e.set_text(i,t)},[()=>(e.deep_read_state(l()),e.untrack(()=>o(l())))]),e.append(f,a),e.pop(d)}export{g as default};
