import{c as e}from"./KHR_interactivity-DRPs30Rf.js";import{R as r}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./declarationMapper-CGPHX8aB.js";import"./objectModelMapping-DT0r674A.js";class o extends e{constructor(){super(...arguments),this.initPriority=-1,this.type="SceneReady"}_executeEvent(t,p){return this._execute(t),!0}_preparePendingTasks(t){}_cancelPendingTasks(t){}getClassName(){return"FlowGraphSceneReadyEventBlock"}}r("FlowGraphSceneReadyEventBlock",o);export{o as FlowGraphSceneReadyEventBlock};
