import{F as a,g as s}from"./KHR_interactivity-DRPs30Rf.js";import{R as e,F as o}from"./declarationMapper-CGPHX8aB.js";import{R as p}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class l extends a{constructor(r){super(r),this.config=r,this.array=this.registerDataInput("array",e),this.index=this.registerDataInput("index",e,new o(-1)),this.value=this.registerDataOutput("value",e)}_updateOutputs(r){const t=this.array.getValue(r),i=s(this.index.getValue(r));t&&i>=0&&i<t.length?this.value.setValue(t[i],r):this.value.setValue(null,r)}serialize(r){super.serialize(r)}getClassName(){return"FlowGraphArrayIndexBlock"}}p("FlowGraphArrayIndexBlock",l);export{l as FlowGraphArrayIndexBlock};
