import{_ as o,l as p,I as e,d as m,K as s}from"./mermaid.core-BpC-PC5Q.js";import{p as n}from"./mermaid-parser.core-BtU_vgPO.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./i18n-BldJSFLV.js";import"./step-ChYay-CR.js";import"./dispatch-kxCwF96_.js";import"./select-BigU4G0v.js";import"./_baseUniq-5LrHMaZn.js";import"./_basePickBy-BwaeXrxs.js";import"./clone-BetsKl5T.js";var g={parse:o(async r=>{const t=await n("info",r);p.debug(t)},"parse")},d={version:s.version+""},v=o(()=>d.version,"getVersion"),c={getVersion:v},l=o((r,t,a)=>{p.debug(`rendering info diagram
`+r);const i=e(t);m(i,100,400,!0),i.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${a}`)},"draw"),f={draw:l},H={parser:g,db:c,renderer:f};export{H as diagram};
