const e="Română",i={annotated_image:"Imagine adnotată"},a={allow_recording_access:"Vă rugăm să permiteți accesul la microfon pentru înregistrare.",audio:"Audio",record_from_microphone:"Înregistrare de la microfon",stop_recording:"Oprire înregistrare",no_device_support:"Nu se poate accesa dispozitivele media. Asigurați-vă că rulați pe o sursă sigură (https) sau localhost (sau ați transmis un certificat SSL valid la ssl_verify), și că ați permis browserului accesul la dispozitivul dvs.",stop:"Stop",resume:"Reluare",record:"Înregistrare",no_microphone:"Nu s-a găsit niciun microfon",pause:"Pauză",play:"Redare",waiting:"Așteptare",drop_to_upload:"Plasați un fișier audio aici pentru a-l încărca"},o={connection_can_break:"Pe mobil, conexiunea poate fi întreruptă dacă această filă își pierde focusul sau dispozitivul intră în modul de repaus, pierzându-vă poziția în coadă.",long_requests_queue:"Există o coadă lungă de cereri în așteptare. Duplicați acest Space pentru a o evita.",lost_connection:"Conexiune pierdută din cauza părăsirii paginii. Revenire la coadă...",waiting_for_inputs:"Așteptarea finalizării încărcării fișierului (fișierelor), vă rugăm să reîncercați."},r={checkbox:"Casetă de bifat",checkbox_group:"Grup de casete de bifat"},t={code:"Cod"},c={color_picker:"Selector de culoare"},n={built_with:"Construit cu",built_with_gradio:"Construit cu Gradio",clear:"Șterge",download:"Descarcă",edit:"Editează",empty:"Gol",error:"Eroare",hosted_on:"Găzduit pe",loading:"Se încarcă",logo:"Logo",or:"sau",remove:"Elimină",settings:"Setări",share:"Distribuie",submit:"Trimite",undo:"Anulează",no_devices:"Nu s-au găsit dispozitive",language:"Limbă",display_theme:"Temă de afișare",pwa:"Aplicație web progresivă"},s={incorrect_format:"Format incorect, sunt acceptate doar fișiere CSV și TSV",new_column:"Adaugă coloană",new_row:"Rând nou",add_row_above:"Adaugă rând deasupra",add_row_below:"Adaugă rând dedesubt",add_column_left:"Adaugă coloană la stânga",add_column_right:"Adaugă coloană la dreapta",delete_row:"Șterge rând",delete_column:"Șterge coloana",sort_column:"Sortează coloana",sort_ascending:"Sortează crescător",sort_descending:"Sortează descrescător",drop_to_upload:"Plasați fișiere CSV sau TSV aici pentru a importa datele în tabelul de date",clear_sort:"Șterge sortarea"},l={dropdown:"Listă derulantă"},u={build_error:"Există o eroare de compilare",config_error:"Există o eroare de configurare",contact_page_author:"Vă rugăm să contactați autorul paginii pentru a-l informa.",no_app_file:"Nu există fișier de aplicație",runtime_error:"Există o eroare de execuție",space_not_working:'"Space-ul nu funcționează deoarece" {0}',space_paused:"Space-ul este în pauză",use_via_api:"Utilizați prin API",use_via_api_or_mcp:"Utilizați prin API sau MCP"},d={uploading:"Se încarcă..."},p={highlighted_text:"Text evidențiat"},_={allow_webcam_access:"Vă rugăm să permiteți accesul la camera web pentru înregistrare.",brush_color:"Culoare pensulă",brush_radius:"Dimensiune pensulă",image:"Imagine",remove_image:"Elimină imaginea",select_brush_color:"Selectează culoarea pensulei",start_drawing:"Începe să desenezi",use_brush:"Folosește pensula",drop_to_upload:"Plasați un fișier imagine aici pentru a-l încărca"},g={label:"Etichetă"},m={enable_cookies:"Dacă vizitați un Space HuggingFace în modul incognito, trebuie să activați cookie-urile terțe.",incorrect_credentials:"Credențiale incorecte",username:"Nume de utilizator",password:"Parolă",login:"Autentificare"},b={number:"Număr"},f={plot:"Grafic"},v={radio:"Buton radio"},h={slider:"Glisor"},z={click_to_upload:"Click pentru încărcare",drop_audio:"Plasați audio aici",drop_csv:"Plasați CSV aici",drop_file:"Plasați fișierul aici",drop_image:"Plasați imaginea aici",drop_video:"Plasați video aici",drop_gallery:"Plasați media aici",paste_clipboard:"Lipește din clipboard"},w={drop_to_upload:"Plasați un fișier video aici pentru a-l încărca"},S={edit:"Editează",retry:"Încearcă din nou",undo:"Anulează",submit:"Trimite",cancel:"Anulează",like:"Îmi place",dislike:"Nu-mi place",clear:"Șterge conversația"},P={_name:e,"3D_model":{"3d_model":"Model 3D",drop_to_upload:"Plasați un fișier cu model 3D (.obj, .glb, .stl, .gltf, .splat sau .ply) aici pentru a-l încărca"},annotated_image:i,audio:a,blocks:o,checkbox:r,code:t,color_picker:c,common:n,dataframe:s,dropdown:l,errors:u,file:d,highlighted_text:p,image:_,label:g,login:m,number:b,plot:f,radio:v,slider:h,upload_text:z,video:w,chatbot:S};

export { e as _name, i as annotated_image, a as audio, o as blocks, S as chatbot, r as checkbox, t as code, c as color_picker, n as common, s as dataframe, P as default, l as dropdown, u as errors, d as file, p as highlighted_text, _ as image, g as label, m as login, b as number, f as plot, v as radio, h as slider, z as upload_text, w as video };
//# sourceMappingURL=ro-BeOmQJCE.js.map
