import"./svelte/svelte_internal_flags_async.js";import*as r from"./svelte/svelte_internal_client.js";import{onDestroy as e}from"./svelte/svelte_svelte.js";import"./i18n-BldJSFLV.js";import{G as m}from"./utils.svelte-Ceck75cM.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";function D(s,o){r.push(o,!0);const p=r.rest_props(o,["$$slots","$$events","$$legacy"]),i=new m(p);let t;r.user_effect(()=>{t&&clearInterval(t),i.props.active&&(t=setInterval(()=>{document.visibilityState==="visible"&&i.dispatch("tick")},i.props.value*1e3))}),e(()=>{t&&clearInterval(t)}),r.pop()}export{D as default};
