import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var s=e.from_html('<div style="display: none;"> </div>');function _(i,r){e.push(r,!1);let t=e.prop(r,"value",28,()=>({visible:!0,home_page_title:"Home"}));var l={get value(){return t()},set value(o){t(o),e.flush()}};e.init();var a=s(),p=e.child(a);return e.reset(a),e.template_effect(()=>e.set_text(p,`Navbar config: visible=${e.deep_read_state(t()),e.untrack(()=>t().visible)??""}, home_page_title="${e.deep_read_state(t()),e.untrack(()=>t().home_page_title)??""}"`)),e.append(i,a),e.pop(l)}export{_ as default};
