import { e, s } from './dev-fallback-Bc5Ork7Y.js';
import { n as noop, w as writable } from './async-DSsyBdZ5.js';
import { t, d as f } from './exports-BWb4C4M4.js';

function b(e){const r=writable(e);let t=true;function n(){t=true,r.update(o=>o);}function a(o){t=false,r.set(o);}function s(o){let c;return r.subscribe(l=>{(c===void 0||t&&l!==c)&&o(c=l);})}return {notify:n,set:a,subscribe:s}}const y={v:()=>{}};function E(){const{set:e$1,subscribe:r}=writable(false);if(e||!s)return {subscribe:r,check:async()=>false};let t$1;async function n(){clearTimeout(t$1);try{const a=await fetch(`${t}/_app/version.json`,{headers:{pragma:"no-cache","cache-control":"no-cache"}});if(!a.ok)return !1;const o=(await a.json()).version!==f;return o&&(e$1(!0),y.v(),clearTimeout(t$1)),o}catch{return  false}}return {subscribe:r,check:n}}let m,d;const R=noop.toString().includes("$$")||/function \w+\(\) \{\}/.test(noop.toString());R?(m={data:{},form:null,error:null,params:{},route:{id:null},state:{},status:-1,url:new URL("https://example.com")},d={current:false}):(m=new class{data={};form=null;error=null;params={};route={id:null};state={};status=-1;url=new URL("https://example.com")},d=new class{current=false},y.v=()=>d.current=true);let $=0;const w=s?window.fetch:(()=>{});if(e&&s){let e=false;(async()=>{e=new Error().stack.includes("check_stack_trace");})(),window.fetch=(t,n)=>{const a=t instanceof Request?t.url:t.toString(),s=new Error().stack.split(`
`),o=s.findIndex(h=>h.includes("load@")||h.includes("at load")),c=s.slice(0,o+2).join(`
`),l=e?c.includes("src/runtime/client/client.js"):$,v=n?.__sveltekit_fetch__;return l&&!v&&console.warn(`Loading ${a} using \`window.fetch\`. For best results, use the \`fetch\` that is passed to your \`load\` function: https://svelte.dev/docs/kit/load#making-fetch-requests`),(t instanceof Request?t.method:n?.method||"GET")!=="GET"&&_.delete(k(t)),w(t,n)};}else s&&(window.fetch=(e,r)=>((e instanceof Request?e.method:r?.method||"GET")!=="GET"&&_.delete(k(e)),w(e,r)));const _=new Map;function k(e,r){return `script[data-sveltekit-fetched][data-url=${JSON.stringify(e instanceof Request?e.url:e)}]`}if(e&&s){let e=false;const r=import.meta.url.split("?")[0],t=()=>{if(e)return;let s=new Error().stack?.split(`
`);s&&(!s[0].includes("https:")&&!s[0].includes("http:")&&(s=s.slice(1)),s=s.slice(2),!s[0]?.includes(r)&&(e=true,console.warn("Avoid using `history.pushState(...)` and `history.replaceState(...)` as these will conflict with SvelteKit's router. Use the `pushState` and `replaceState` imports from `$app/navigation` instead.")));},n=history.pushState;history.pushState=(...s)=>(t(),n.apply(history,s));const a=history.replaceState;history.replaceState=(...s)=>(t(),a.apply(history,s));}const A={page:b({}),navigating:writable(null),updated:E()};if(e){const e=console.warn;console.warn=function(...t){t.length===1&&/<(Layout|Page|Error)(_[\w$]+)?> was created (with unknown|without expected) prop '(data|form)'/.test(t[0])||e(...t);};}

export { A, m };
//# sourceMappingURL=client3-CHaxWNm_.js.map
