import{s as r,b as i,a as o,S as m}from"./chunk-DI55MBZ5-C-CDjOU5-rzUNo3Bc.js";import{_ as p}from"./mermaid.core-BN1TdaiK-CkX93Jpj.js";import"./chunk-55IACEB6-Bjr89SOO-BiBDWwt8.js";import"./chunk-QN33PNHL-C0Bh0NCF-8ZUEc1Mt.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./Index-BpHS9YhG.js";import"./i18n-BldJSFLV.js";import"./utils.svelte-Ceck75cM.js";import"./index-tFQomdd2.js";import"./dsv-DB8NKgIY.js";import"./index-CnqicUFC.js";import"./ModifyUpload-BzsLgPw2.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";import"./Index-aAgh1OXe.js";import"./StreamingBar-b2qVLPYU.js";import"./FullscreenButton-Cqzqqtq6.js";import"./Example-BRN12iqL.js";var O={parser:o,get db(){return new m(2)},renderer:i,styles:r,init:p(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{O as diagram};
