label.svelte-1hguek3{display:block;width:100%}input[type=text].svelte-1hguek3,input[type=password].svelte-1hguek3,input[type=email].svelte-1hguek3,textarea.svelte-1hguek3{flex-grow:1;margin-top:0;margin-bottom:0;resize:none;z-index:1;display:block;position:relative;outline:none!important;background:var(--input-background-fill);padding:var(--input-padding);width:100%;color:var(--body-text-color);font-weight:var(--input-text-weight);font-size:var(--input-text-size);line-height:var(--line-sm);border:none}textarea.no-label.svelte-1hguek3{padding-top:5px;padding-bottom:5px}label.show_textbox_border.svelte-1hguek3 input:where(.svelte-1hguek3),label.show_textbox_border.svelte-1hguek3 textarea:where(.svelte-1hguek3){box-shadow:var(--input-shadow)}label.svelte-1hguek3:not(.container),label.svelte-1hguek3:not(.container) input:where(.svelte-1hguek3),label.svelte-1hguek3:not(.container) textarea:where(.svelte-1hguek3){height:100%}label.container.show_textbox_border.svelte-1hguek3 input:where(.svelte-1hguek3),label.container.show_textbox_border.svelte-1hguek3 textarea:where(.svelte-1hguek3){border:var(--input-border-width) solid var(--input-border-color);border-radius:var(--input-radius)}input.svelte-1hguek3:disabled,textarea.svelte-1hguek3:disabled{-webkit-opacity:1;opacity:1}label.container.show_textbox_border.svelte-1hguek3 input:where(.svelte-1hguek3):focus,label.container.show_textbox_border.svelte-1hguek3 textarea:where(.svelte-1hguek3):focus{box-shadow:var(--input-shadow-focus);border-color:var(--input-border-color-focus);background:var(--input-background-fill-focus)}input.svelte-1hguek3::placeholder,textarea.svelte-1hguek3::placeholder{color:var(--input-placeholder-color)}.input-container.svelte-1hguek3{display:flex;position:relative;align-items:flex-end}.submit-button.svelte-1hguek3,.stop-button.svelte-1hguek3{border:none;text-align:center;text-decoration:none;font-size:14px;cursor:pointer;border-radius:15px;min-width:30px;height:30px;flex-shrink:0;display:flex;justify-content:center;align-items:center;z-index:var(--layer-1)}.stop-button.svelte-1hguek3,.submit-button.svelte-1hguek3{background:var(--button-secondary-background-fill);color:var(--button-secondary-text-color)}.stop-button.svelte-1hguek3:hover,.submit-button.svelte-1hguek3:hover{background:var(--button-secondary-background-fill-hover)}.stop-button.svelte-1hguek3:disabled,.submit-button.svelte-1hguek3:disabled{background:var(--button-secondary-background-fill);cursor:pointer}.stop-button.svelte-1hguek3:active,.submit-button.svelte-1hguek3:active{box-shadow:var(--button-shadow-active)}.submit-button.svelte-1hguek3 svg{height:22px;width:22px}.stop-button.svelte-1hguek3 svg{height:16px;width:16px}.padded-button.svelte-1hguek3{padding:0 10px}div.validation-error.svelte-1hguek3{color:var(--error-icon-color);font-size:var(--font-sans);margin-top:var(--spacing-sm);font-weight:var(--weight-semibold)}label.container.svelte-1hguek3 input.validation-error:where(.svelte-1hguek3),label.container.svelte-1hguek3 textarea.validation-error:where(.svelte-1hguek3){border-color:transparent!important;box-shadow:0 0 3px 1px var(--error-icon-color),var(--shadow-inset)!important}
