import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";var n=t.from_html("<img/>");function r(s,e){t.push(e,!0);var a=n();t.attribute_effect(a,i=>({src:e.src,class:i,"data-testid":e.data_testid,...e.restProps}),[()=>(e.class_names||[]).join(" ")],void 0,void 0,"svelte-1jk6tax"),t.replay_events(a),t.event("load",a,function(i){t.bubble_event.call(this,e,i)}),t.append(s,a),t.pop()}export{r as I};
