import{R as e}from"./index-6jOCfdig.js";import{e as o}from"./KHR_interactivity-DRPs30Rf.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./declarationMapper-CGPHX8aB.js";import"./objectModelMapping-DT0r674A.js";class r extends o{constructor(t){super(t),this.config=t,this.executionSignals=[],this.setNumberOfOutputSignals(this.config.outputSignalCount)}_execute(t){for(let i=0;i<this.executionSignals.length;i++)this.executionSignals[i]._activateSignal(t)}setNumberOfOutputSignals(t=1){for(;this.executionSignals.length>t;){const i=this.executionSignals.pop();i&&(i.disconnectFromAll(),this._unregisterSignalOutput(i.name))}for(;this.executionSignals.length<t;)this.executionSignals.push(this._registerSignalOutput(`out_${this.executionSignals.length}`))}getClassName(){return"FlowGraphSequenceBlock"}}e("FlowGraphSequenceBlock",r);export{r as FlowGraphSequenceBlock};
