const o="Русский",e={annotated_image:"Изображение с аннотациями"},t={allow_recording_access:"Пожалуйста, разрешите доступ к микрофону для записи.",audio:"Аудио",record_from_microphone:"Запись с микрофона",stop_recording:"Остановить запись",no_device_support:"Невозможно получить доступ к медиа-устройствам. Убедитесь, что вы работаете с безопасного источника (https) или localhost (или передали действительный SSL-сертификат в ssl_verify), и что вы разрешили браузеру доступ к вашему устройству.",stop:"Стоп",resume:"Продолжить",record:"Запись",no_microphone:"Микрофон не найден",pause:"Пауза",play:"Воспроизвести",waiting:"Ожидание",drop_to_upload:"Перетащите аудиофайл сюда для загрузки"},r={connection_can_break:"На мобильном устройстве соединение может прерваться, если эта вкладка потеряет фокус или устройство перейдет в спящий режим, что приведет к потере вашего места в очереди.",long_requests_queue:"Существует длинная очередь ожидающих запросов. Создайте дубликат этого Space, чтобы пропустить очередь.",lost_connection:"Соединение потеряно из-за ухода со страницы. Возвращение в очередь...",waiting_for_inputs:"Ожидание завершения загрузки файла(ов), пожалуйста, повторите попытку."},c={checkbox:"Флажок",checkbox_group:"Группа флажков"},a={code:"Код"},_={color_picker:"Выбор цвета"},n={built_with:"Создано с помощью",built_with_gradio:"Создано с помощью Gradio",clear:"Очистить",download:"Скачать",edit:"Редактировать",empty:"Пусто",error:"Ошибка",hosted_on:"Размещено на",loading:"Загрузка",logo:"Логотип",or:"или",remove:"Удалить",settings:"Настройки",share:"Поделиться",submit:"Отправить",undo:"Отменить",no_devices:"Устройства не найдены",language:"Язык",display_theme:"Тема оформления",pwa:"Прогрессивное веб-приложение"},s={incorrect_format:"Неверный формат, поддерживаются только файлы CSV и TSV",new_column:"Добавить столбец",new_row:"Новая строка",add_row_above:"Добавить строку выше",add_row_below:"Добавить строку ниже",add_column_left:"Добавить столбец слева",add_column_right:"Добавить столбец справа",delete_row:"Удалить строку",delete_column:"Удалить столбец",sort_column:"Сортировать столбец",sort_ascending:"Сортировать по возрастанию",sort_descending:"Сортировать по убыванию",drop_to_upload:"Перетащите файлы CSV или TSV сюда для импорта данных в таблицу данных",clear_sort:"Очистить сортировку"},d={dropdown:"Выпадающий список"},i={build_error:"Произошла ошибка сборки",config_error:"Произошла ошибка конфигурации",contact_page_author:"Пожалуйста, свяжитесь с автором страницы, чтобы сообщить об этом.",no_app_file:"Отсутствует файл приложения",runtime_error:"Произошла ошибка выполнения",space_not_working:'"Space не работает, потому что" {0}',space_paused:"Space приостановлен",use_via_api:"Использовать через API",use_via_api_or_mcp:"Использовать через API или MCP"},l={uploading:"Загрузка..."},p={highlighted_text:"Выделенный текст"},u={allow_webcam_access:"Пожалуйста, разрешите доступ к веб-камере для записи.",brush_color:"Цвет кисти",brush_radius:"Размер кисти",image:"Изображение",remove_image:"Удалить изображение",select_brush_color:"Выбрать цвет кисти",start_drawing:"Начать рисование",use_brush:"Использовать кисть",drop_to_upload:"Перетащите изображение сюда для загрузки"},g={label:"Метка"},m={enable_cookies:"Если вы посещаете Space HuggingFace в режиме инкогнито, вам необходимо включить сторонние куки.",incorrect_credentials:"Неверные учетные данные",username:"Имя пользователя",password:"Пароль",login:"Войти"},h={number:"Число"},b={plot:"График"},w={radio:"Переключатель"},f={slider:"Ползунок"},k={click_to_upload:"Нажмите для загрузки",drop_audio:"Перетащите аудио сюда",drop_csv:"Перетащите CSV сюда",drop_file:"Перетащите файл сюда",drop_image:"Перетащите изображение сюда",drop_video:"Перетащите видео сюда",drop_gallery:"Перетащите медиа сюда",paste_clipboard:"Вставить из буфера обмена"},v={drop_to_upload:"Перетащите видеофайл сюда для загрузки"},S={edit:"Редактировать",retry:"Повторить",undo:"Отменить",submit:"Отправить",cancel:"Отмена",like:"Нравится",dislike:"Не нравится",clear:"Очистить чат",copy_message:"Копировать сообщение",copied_message:"Сообщение скопировано"},y={new_chat:"Новый чат",message_placeholder:"Введите сообщение...",additional_inputs:"Дополнительные поля",chatbot:"Чат-бот",conversation:"Разговор"},x={_name:o,"3D_model":{"3d_model":"3D-модель",drop_to_upload:"Перетащите сюда 3D-модель (.obj, .glb, .stl, .gltf, .splat или .ply) для загрузки"},annotated_image:e,audio:t,blocks:r,checkbox:c,code:a,color_picker:_,common:n,dataframe:s,dropdown:d,errors:i,file:l,highlighted_text:p,image:u,label:g,login:m,number:h,plot:b,radio:w,slider:f,upload_text:k,video:v,chatbot:S,chat_interface:y};

export { o as _name, e as annotated_image, t as audio, r as blocks, y as chat_interface, S as chatbot, c as checkbox, a as code, _ as color_picker, n as common, s as dataframe, x as default, d as dropdown, i as errors, l as file, p as highlighted_text, u as image, g as label, m as login, h as number, b as plot, w as radio, f as slider, k as upload_text, v as video };
//# sourceMappingURL=ru-D4j7Vj8W.js.map
