.error.svelte-15izthb{position:relative;padding:var(--size-4);color:var(--body-text-color);text-align:center}.error.svelte-15izthb>:where(.svelte-15izthb){margin-top:var(--size-4)}a.svelte-15izthb{color:var(--link-text-color)}a.svelte-15izthb:hover{color:var(--link-text-color-hover);text-decoration:underline}a.svelte-15izthb:visited{color:var(--link-text-color-visited)}a.svelte-15izthb:active{color:var(--link-text-color-active)}
