.container.svelte-1nl1glk{flex:none;max-width:none}.container.svelte-1nl1glk video{width:var(--size-full);height:var(--size-full);object-fit:cover}.container.svelte-1nl1glk:hover,.container.selected.svelte-1nl1glk{border-color:var(--border-color-accent)}.container.table.svelte-1nl1glk{margin:0 auto;border:2px solid var(--border-color-primary);border-radius:var(--radius-lg);overflow:hidden;width:var(--size-20);height:var(--size-20);object-fit:cover}.container.gallery.svelte-1nl1glk{height:var(--size-20);max-height:var(--size-20);object-fit:cover}
