import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import{createEventDispatcher as m}from"./svelte/svelte_svelte.js";import{I as c,M as p,a as v}from"./IconButtonWrapper-Cljb5D-5.js";import"./i18n-BldJSFLV.js";function F(i,l){e.push(l,!1);const n=m();let t=e.prop(l,"fullscreen",12);var a={get fullscreen(){return t()},set fullscreen(r){t(r),e.flush()}};e.init();var s=e.comment(),o=e.first_child(s);{var f=r=>{c(r,{get Icon(){return p},label:"Exit fullscreen mode",$$events:{click:()=>n("fullscreen",!1)}})},u=r=>{c(r,{get Icon(){return v},label:"Fullscreen",$$events:{click:()=>n("fullscreen",!0)}})};e.if(o,r=>{t()?r(f):r(u,!1)})}return e.append(i,s),e.pop(a)}export{F};
