const a="O'zbek",i={built_with_gradio:"Gradio bilan yaratilgan",clear:"Tozalash",submit:"Yuborish",built_with:"Bilan yaratilgan",download:"Yuklab olish",edit:"Tahrirlash",empty:"Bo'sh",error:"Xato",hosted_on:"Joylashtirilgan",loading:"Yuklanmoqda",logo:"Logo",or:"yoki",remove:"O'chirish",settings:"Sozlamalar",share:"Ulashish",undo:"Bekor qilish",no_devices:"Hech qanday qurilma topilmadi",language:"Til",display_theme:"Ko'rinish mavzusi",pwa:"Progressive web-ilova"},o={click_to_upload:"Yuklash uchun bosing",drop_audio:"Audioni shu yerga tashlang",drop_csv:"CSV faylni shu yerga tashlang",drop_file:"Faylni shu yerga tashlang",drop_image:"Rasmni shu yerga tashlang",drop_video:"Videoni shu yerga tashlang",drop_gallery:"Mediafaylni shu yerga tashlang",paste_clipboard:"Klipboarddan qo'yish"},n={annotated_image:"Izohli rasm"},s={allow_recording_access:"Iltimos, yozib olish uchun mikrofonga ruxsat bering.",audio:"Audio",drop_to_upload:"Audio faylni yuklash uchun shu yerga tashlang",record_from_microphone:"Mikrofondan yozib olish",stop_recording:"Yozib olishni to'xtatish",no_device_support:"Media qurilmalariga kira olmadik. Xavfsiz manbada (https) yoki localhost-da ishlayotganingizni tekshiring (yoki to'g'ri SSL sertifikatini ssl_verify-ga berganingizni) va brauzer qurilmangizga kirishiga ruxsat berganingizni tekshiring.",stop:"To'xtatish",resume:"Davom ettirish",record:"Yozib olish",no_microphone:"Mikrofon topilmadi",pause:"Pauza",play:"Ijro etish",waiting:"Kutilmoqda"},r={connection_can_break:"Mobil qurilmada, agar bu yorliq fokusdan chiqsa yoki qurilma uyqu rejimiga o'tsa, aloqa uzilib, navbatdagi o'rningizni yo'qotishingiz mumkin.",long_requests_queue:"So'rovlar navbati juda uzun. Navbatni chetlab o'tish uchun bu Space-ni nusxalang.",lost_connection:"Sahifadan chiqib ketganligi sababli aloqa uzildi. Navbatga qayta qo'shilmoqda...",waiting_for_inputs:"Fayl(lar) yuklanib bo'lishini kutish, iltimos, qayta urinib ko'ring."},l={checkbox:"Belgilash katagi",checkbox_group:"Belgilash kataklari guruhi"},t={code:"Kod"},e={color_picker:"Rang tanlagich"},h={incorrect_format:"Noto'g'ri format, faqat CSV va TSV fayllari qo'llab-quvvatlanadi",new_column:"Ustun qo'shish",new_row:"Yangi qator",add_row_above:"Yuqoriga qator qo'shish",add_row_below:"Pastga qator qo'shish",delete_row:"Qatorni o'chirish",delete_column:"Ustunni o'chirish",add_column_left:"Chapga ustun qo'shish",add_column_right:"O'ngga ustun qo'shish",sort_column:"Ustunni saralash",sort_ascending:"O'sish tartibida saralash",sort_descending:"Kamayish tartibida saralash",drop_to_upload:"Ma'lumotlarni ma'lumotlar jadvaliga import qilish uchun CSV yoki TSV fayllarini shu yerga tashlang",clear_sort:"Saralashni tozalash"},u={dropdown:"Ochiluvchi ro'yxat"},g={build_error:"Tuzilish xatosi mavjud",config_error:"Konfiguratsiya xatosi mavjud",contact_page_author:"Iltimos, sahifa muallifiga bog'laning va ularga xabar bering.",no_app_file:"Ilova fayli yo'q",runtime_error:"Bajarilish vaqti xatosi mavjud",space_not_working:'"Space ishlamayapti, chunki" {0}',space_paused:"Space to'xtatilgan",use_via_api:"API orqali foydalaning",use_via_api_or_mcp:"API yoki MCP orqali foydalaning"},d={uploading:"Yuklanmoqda..."},c={highlighted_text:"Ajratilgan matn"},_={allow_webcam_access:"Iltimos, yozib olish uchun veb-kameraga ruxsat bering.",brush_color:"Cho'tka rangi",brush_radius:"Cho'tka o'lchami",image:"Rasm",remove_image:"Rasmni o'chirish",select_brush_color:"Cho'tka rangini tanlang",start_drawing:"Chizishni boshlang",use_brush:"Cho'tkadan foydalaning",drop_to_upload:"Rasm faylini yuklash uchun shu yerga tashlang"},m={label:"Yorliq"},b={enable_cookies:"Agar HuggingFace Space-ni Inkognito rejimida ko'rayotgan bo'lsangiz, uchinchi tomon kukilarini yoqishingiz kerak.",incorrect_credentials:"Noto'g'ri kirish ma'lumotlari",username:"Foydalanuvchi nomi",password:"Parol",login:"Kirish"},y={number:"Raqam"},p={plot:"Grafik"},k={radio:"Radio tugma"},q={slider:"Slayder"},f={drop_to_upload:"Video faylni yuklash uchun shu yerga tashlang"},v={edit:"Tahrirlash",retry:"Qayta urinish",undo:"Bekor qilish",submit:"Yuborish",cancel:"Bekor qilish",like:"Yoqdi",dislike:"Yoqmadi",clear:"Suhbatni tozalash"},z={_name:a,common:i,upload_text:o,"3D_model":{"3d_model":"3D model",drop_to_upload:"3D model (.obj, .glb, .stl, .gltf, .splat yoki .ply) faylni yuklash uchun shu yerga tashlang"},annotated_image:n,audio:s,blocks:r,checkbox:l,code:t,color_picker:e,dataframe:h,dropdown:u,errors:g,file:d,highlighted_text:c,image:_,label:m,login:b,number:y,plot:p,radio:k,slider:q,video:f,chatbot:v};

export { a as _name, n as annotated_image, s as audio, r as blocks, v as chatbot, l as checkbox, t as code, e as color_picker, i as common, h as dataframe, z as default, u as dropdown, g as errors, d as file, c as highlighted_text, _ as image, m as label, b as login, y as number, p as plot, k as radio, q as slider, o as upload_text, f as video };
//# sourceMappingURL=uz-D7FUtAO1.js.map
