import{F as t}from"./KHR_interactivity-DRPs30Rf.js";import{R as a}from"./declarationMapper-CGPHX8aB.js";import{R as o}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class e extends t{constructor(r){super(r),this.config=r,this.value=this.registerDataOutput("value",a,r.initialValue)}_updateOutputs(r){const i=this.config.variable;r.hasVariable(i)&&this.value.setValue(r.getVariable(i),r)}serialize(r){super.serialize(r),r.config.variable=this.config.variable}getClassName(){return"FlowGraphGetVariableBlock"}}o("FlowGraphGetVariableBlock",e);export{e as FlowGraphGetVariableBlock};
