import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import{S as u}from"./StreamingBar-b2qVLPYU.js";import"./i18n-BldJSFLV.js";import{G as c}from"./utils.svelte-Ceck75cM.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_motion.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./prism-python-CpYAgONt.js";var f=e.from_html("<div><!> <!></div>");function L(n,i){e.push(i,!0);const a=r=>{if(r!==void 0){if(typeof r=="number")return r+"px";if(typeof r=="string")return r}};let h=e.rest_props(i,["$$slots","$$events","$$legacy"]),t=new c(h);var s=f();let p,l;var d=e.child(s);{var m=r=>{{let o=e.derived(()=>t.shared.loading_status?t.shared.loading_status.status=="pending"?"generating":t.shared.loading_status.status:null);u(r,e.spread_props({get autoscroll(){return t.shared.autoscroll},get i18n(){return t.i18n}},()=>t.shared.loading_status,{get status(){return e.get(o)}}))}};e.if(d,r=>{t.shared.loading_status&&t.shared.loading_status.show_progress&&t&&r(m)})}var g=e.sibling(d,2);e.slot(g,i,"default",{},null),e.reset(s),e.template_effect((r,o)=>{e.set_attribute(s,"id",t.shared.elem_id),p=e.set_class(s,1,`row ${r??""}`,"svelte-7xavid",p,{compact:t.props.variant==="compact",panel:t.props.variant==="panel","unequal-height":t.props.equal_height===!1,stretch:t.props.equal_height,hide:!t.shared.visible,"grow-children":t.shared.scale&&t.shared.scale>=1}),l=e.set_style(s,"",l,o)},[()=>t.shared.elem_classes?.join(" "),()=>({height:a(t.props.height),"max-height":a(t.props.max_height),"min-height":a(t.props.min_height),"flex-grow":t.shared.scale})]),e.append(n,s),e.pop()}export{L as default};
