import{b as t,c as o}from"./index-6jOCfdig.js";import{G as i}from"./geometryBufferRenderer-DoMoHHt8.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./engine.multiRender-QnOAzSmL.js";import"./bumpFragment-DOrWyWCF.js";import"./helperFunctions-C8obpaoJ.js";import"./sceneUboDeclaration-CBM--qyH.js";import"./bumpVertex-CXH2mSLh.js";Object.defineProperty(o.prototype,"geometryBufferRenderer",{get:function(){return this._geometryBufferRenderer},set:function(e){e&&e.isSupported&&(this._geometryBufferRenderer=e)},enumerable:!0,configurable:!0});o.prototype.enableGeometryBufferRenderer=function(e=1,r=15,n){return this._geometryBufferRenderer?this._geometryBufferRenderer:(this._geometryBufferRenderer=new i(this,e,r,n),this._geometryBufferRenderer.isSupported||(this._geometryBufferRenderer=null),this._geometryBufferRenderer)};o.prototype.disableGeometryBufferRenderer=function(){this._geometryBufferRenderer&&(this._geometryBufferRenderer.dispose(),this._geometryBufferRenderer=null)};class m{constructor(r){this.name=t.NAME_GEOMETRYBUFFERRENDERER,this.scene=r}register(){this.scene._gatherRenderTargetsStage.registerStep(t.STEP_GATHERRENDERTARGETS_GEOMETRYBUFFERRENDERER,this,this._gatherRenderTargets)}rebuild(){}dispose(){}_gatherRenderTargets(r){this.scene._geometryBufferRenderer&&r.push(this.scene._geometryBufferRenderer.getGBuffer())}}i._SceneComponentInitialization=e=>{let r=e._getComponent(t.NAME_GEOMETRYBUFFERRENDERER);r||(r=new m(e),e._addComponent(r))};export{m as GeometryBufferRendererSceneComponent};
