.hide.svelte-26mp0t{display:none}.error-container.svelte-26mp0t{padding:12px;background-color:#fee;border:1px solid #fcc;border-radius:4px;color:#c33;font-family:monospace;font-size:13px}.error-title.svelte-26mp0t{display:block;margin-bottom:8px}.error-component-name.svelte-26mp0t{background-color:#fdd;padding:2px 4px;border-radius:2px}.error-message.svelte-26mp0t{white-space:pre-wrap;word-break:break-word}.padding.svelte-1jts93g{padding:var(--block-padding)}div.svelte-1jts93g{transition:.15s}.pending.svelte-1jts93g{opacity:.2}
