const S="日本語",o={annotated_image:"注釈付き画像"},e={allow_recording_access:"録音のためにマイクへのアクセスを許可してください",audio:"音声",record_from_microphone:"マイクから録音",stop_recording:"録音を停止",no_device_support:"メディアデバイスにアクセスできません。安全なソース（https）またはlocalhostで実行していること（またはssl_verifyに有効なSSL証明書を渡していること）、ブラウザにデバイスへのアクセスを許可していることを確認してください",stop:"停止",resume:"再開",record:"録音",no_microphone:"マイクが見つかりません",pause:"一時停止",play:"再生",waiting:"待機中",drop_to_upload:"ここにオーディオファイルをドロップしてアップロードしてください"},r={connection_can_break:"モバイルでは、このタブがフォーカスを失うかデバイスがスリープモードになると接続が切断され、キュー内の位置が失われる可能性があります",long_requests_queue:"保留中のリクエストの長いキューがあります。このSpaceを複製してスキップしてください",lost_connection:"ページを離れたため接続が切断されました。キューに戻ります...",waiting_for_inputs:"ファイルのアップロードが完了するのを待っています。再度お試しください"},t={checkbox:"チェックボックス",checkbox_group:"チェックボックスグループ"},_={code:"コード"},c={color_picker:"カラーピッカー"},a={built_with:"で作成",built_with_gradio:"Gradioで作成",clear:"クリア",download:"ダウンロード",edit:"編集",empty:"空",error:"エラー",hosted_on:"でホスト",loading:"読み込み中",logo:"ロゴ",or:"または",remove:"削除",settings:"設定",share:"共有",submit:"送信",undo:"元に戻す",no_devices:"デバイスが見つかりません",language:"言語",display_theme:"表示テーマ",pwa:"プログレッシブウェブアプリ"},n={incorrect_format:"不正なフォーマット、CSVとTSVファイルのみサポートされています",new_column:"列を追加",new_row:"新しい行",add_row_above:"上に行を追加",add_row_below:"下に行を追加",add_column_left:"左に列を追加",add_column_right:"右に列を追加",delete_row:"行を削除",delete_column:"列を削除",sort_column:"列をソート",sort_ascending:"昇順に並べ替え",sort_descending:"降順に並べ替え",drop_to_upload:"CSVまたはTSVファイルをここにドロップして、データをデータフレームにインポートします",clear_sort:"ソートをクリア"},s={dropdown:"ドロップダウン"},d={build_error:"ビルドエラーがあります",config_error:"設定エラーがあります",contact_page_author:"ページの作者に連絡して知らせてください",no_app_file:"アプリファイルがありません",runtime_error:"ランタイムエラーがあります",space_not_working:'"Spaceが動作していません。理由：" {0}',space_paused:"Spaceが一時停止されています",use_via_api:"APIを介して使用",use_via_api_or_mcp:"APIまたはMCP経由で使用"},i={uploading:"アップロード中..."},l={highlighted_text:"ハイライトされたテキスト"},p={allow_webcam_access:"録画のためにウェブカメラへのアクセスを許可してください",brush_color:"ブラシの色",brush_radius:"ブラシのサイズ",image:"画像",remove_image:"画像を削除",select_brush_color:"ブラシの色を選択",start_drawing:"描画を開始",use_brush:"ブラシを使用",drop_to_upload:"ここに画像ファイルをドロップしてアップロードしてください"},u={label:"ラベル"},g={enable_cookies:"シークレットモードでHuggingFace Spaceを訪問している場合、サードパーティのCookieを有効にする必要があります",incorrect_credentials:"認証情報が正しくありません",username:"ユーザー名",password:"パスワード",login:"ログイン"},m={number:"数値"},b={plot:"プロット"},h={radio:"ラジオボタン"},w={slider:"スライダー"},k={click_to_upload:"クリックしてアップロード",drop_audio:"音声をここにドロップ",drop_csv:"CSVファイルをここにドロップ",drop_file:"ファイルをここにドロップ",drop_image:"画像をここにドロップ",drop_video:"動画をここにドロップ",drop_gallery:"メディアをここにドロップ",paste_clipboard:"クリップボードから貼り付け"},f={drop_to_upload:"ビデオファイルをここにドロップしてアップロードしてください"},v={edit:"編集",retry:"再試行",undo:"元に戻す",submit:"送信",cancel:"キャンセル",like:"いいね",dislike:"よくないね",clear:"会話をクリア"},x={_name:"日本語","3D_model":{"3d_model":"3Dモデル",drop_to_upload:"3D モデル (.obj, .glb, .stl, .gltf, .splat, .ply) ファイルをここにドロップしてアップロードしてください"},annotated_image:o,audio:e,blocks:r,checkbox:t,code:_,color_picker:c,common:a,dataframe:n,dropdown:s,errors:d,file:i,highlighted_text:l,image:p,label:u,login:g,number:m,plot:b,radio:h,slider:w,upload_text:k,video:f,chatbot:v};

export { S as _name, o as annotated_image, e as audio, r as blocks, v as chatbot, t as checkbox, _ as code, c as color_picker, a as common, n as dataframe, x as default, s as dropdown, d as errors, i as file, l as highlighted_text, p as image, u as label, g as login, m as number, b as plot, h as radio, w as slider, k as upload_text, f as video };
//# sourceMappingURL=ja-v-GO49IA.js.map
