import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var n=e.from_html('<div><img class="svelte-ulqlw7"/> <img class="svelte-ulqlw7"/> <span class="svelte-ulqlw7"></span></div>');function g(_,a){e.push(a,!1);let l=e.prop(a,"value",12),s=e.prop(a,"samples_dir",12),r=e.prop(a,"type",12),u=e.prop(a,"selected",12,!1);var c={get value(){return l()},set value(t){l(t),e.flush()},get samples_dir(){return s()},set samples_dir(t){s(t),e.flush()},get type(){return r()},set type(t){r(t),e.flush()},get selected(){return u()},set selected(t){u(t),e.flush()}};e.init();var p=n();let d;var i=e.child(p),m=e.sibling(i,2);return e.next(2),e.reset(p),e.template_effect(()=>{d=e.set_class(p,1,"wrap svelte-ulqlw7",null,d,{table:r()==="table",gallery:r()==="gallery",selected:u()}),e.set_attribute(i,"src",(e.deep_read_state(s()),e.deep_read_state(l()),e.untrack(()=>s()+l()[0]))),e.set_attribute(m,"src",(e.deep_read_state(s()),e.deep_read_state(l()),e.untrack(()=>s()+l()[1])))}),e.append(_,p),e.pop(c)}export{g as default};
