const o="Українська",e={built_with_gradio:"Зроблено на основі Gradio",clear:"Очистити",or:"або",submit:"Надіслати",settings:"Налаштування",built_with:"Зроблено з",download:"Завантажити",edit:"Редагувати",empty:"Порожній",error:"Помилка",hosted_on:"Розміщено на",loading:"Завантаження",logo:"Логотип",remove:"Видалити",share:"Поділитися",undo:"Скасувати",no_devices:"Пристроїв не знайдено",language:"Мова",display_theme:"Тема оформлення",pwa:"Прогресивний веб-додаток"},r={click_to_upload:"Натисніть, щоб завантажити",drop_audio:"Перетягніть аудіо сюди",drop_csv:"Перетягніть CSV-файл сюди",drop_file:"Перетягніть файл сюди",drop_image:"Перетягніть зображення сюди",drop_video:"Перетягніть відео сюди",drop_gallery:"Перетягніть медіа сюди",paste_clipboard:"Вставити з буфера обміну"},t={annotated_image:"Анотоване зображення"},_={allow_recording_access:"Будь ласка, дайте доступ до мікрофона для запису.",audio:"Аудіо",drop_to_upload:"Перетягніть аудіофайл сюди, щоб завантажити",record_from_microphone:"Записати з мікрофона",stop_recording:"Зупинити запис",no_device_support:"Медійні пристрої не можуть бути доступні. Переконайтеся, що ви запускаєте з захищеного джерела (https) або localhost (або ви передали дійсний SSL-сертифікат до ssl_verify), і ви дозволили браузеру доступ до вашого пристрою.",stop:"Зупинити",resume:"Відновити",record:"Записати",no_microphone:"Мікрофон не виявлено",pause:"Пауза",play:"Відтворити",waiting:"Очікування"},c={connection_can_break:"На мобільному пристрої з'єднання може перерватися, якщо ця вкладка втрачає фокус або пристрій увійде в режим сну, в результаті чого ви втратите своє місце в черзі.",long_requests_queue:"У черзі залишилось багато запитів. Скопіюйте цей Space, щоб пропустити чергу.",lost_connection:"З'єднання втрачено через вихід зі сторінки. Переміщення до кінця черги...",waiting_for_inputs:"Чекаємо завершення завантаження файлу(ів), будь ласка, спробуйте ще раз."},a={checkbox:"Прапорець",checkbox_group:"Група прапорців"},n={code:"Код"},s={color_picker:"Вибір кольору"},d={incorrect_format:"Неправильний формат, підтримуються лише файли CSV та TSV",new_column:"Додати стовпець",new_row:"Новий рядок",add_row_above:"Додати рядок вище",add_row_below:"Додати рядок нижче",delete_row:"Видалити рядок",delete_column:"Видалити стовпець",add_column_left:"Додати стовпець зліва",add_column_right:"Додати стовпець справа",sort_column:"Сортувати стовпець",sort_ascending:"Сортувати за зростанням",sort_descending:"Сортувати за спаданням",drop_to_upload:"Перетягніть CSV або TSV файли сюди, щоб імпортувати дані в таблицю даних",clear_sort:"Очистити сортування"},i={dropdown:"Випадне меню"},l={build_error:"Є помилка побудови",config_error:"Є помилка конфігурації",contact_page_author:"Будь ласка, зв'яжіться з автором сторінки, щоб повідомити.",no_app_file:"Немає файлу додатку",runtime_error:"Є помилка виконання",space_not_working:'"Space не працює, оскільки" {0}',space_paused:"Space призупинено",use_via_api:"Використовувати через API",use_via_api_or_mcp:"Використовувати через API або MCP"},p={uploading:"Завантаження..."},u={highlighted_text:"Виділений текст"},g={allow_webcam_access:"Будь ласка, дайте доступ до веб-камери для запису.",brush_color:"Колір пензля",brush_radius:"Розмір пензля",image:"Зображення",remove_image:"Видалити зображення",select_brush_color:"Виберіть колір пензля",start_drawing:"Почніть малювати",use_brush:"Використовуйте пензель",drop_to_upload:"Перетягніть файл зображення сюди, щоб завантажити"},m={label:"Мітка"},b={enable_cookies:"Якщо ви відвідуєте HuggingFace Space у режимі Інкогніто, вам потрібно увімкнути сторонні куки.",incorrect_credentials:"Неправильні облікові дані",username:"Ім'я користувача",password:"Пароль",login:"Увійти"},h={number:"Число"},w={plot:"Діаграма"},k={radio:"Перемикач"},f={slider:"Повзунок"},v={drop_to_upload:"Перетягніть відеофайл сюди, щоб завантажити"},S={edit:"Редагувати",retry:"Повторити",undo:"Скасувати",submit:"Надіслати",cancel:"Скасувати",like:"Подобається",dislike:"Не подобається",clear:"Очистити чат"},x={_name:o,common:e,upload_text:r,"3D_model":{"3d_model":"3D-модель",drop_to_upload:"Перетягніть файл 3D-моделі (.obj, .glb, .stl, .gltf, .splat або .ply) сюди, щоб завантажити"},annotated_image:t,audio:_,blocks:c,checkbox:a,code:n,color_picker:s,dataframe:d,dropdown:i,errors:l,file:p,highlighted_text:u,image:g,label:m,login:b,number:h,plot:w,radio:k,slider:f,video:v,chatbot:S};export{o as _name,t as annotated_image,_ as audio,c as blocks,S as chatbot,a as checkbox,n as code,s as color_picker,e as common,d as dataframe,x as default,i as dropdown,l as errors,p as file,u as highlighted_text,g as image,m as label,b as login,h as number,w as plot,k as radio,f as slider,r as upload_text,v as video};
