import{F as t}from"./flowGraphUnaryOperationBlock-Mpr5Q1uH.js";import{b as p,i as n,F as e,c as s}from"./declarationMapper-CGPHX8aB.js";import{R as a}from"./index-6jOCfdig.js";import"./flowGraphCachedOperationBlock-DGfksfbT.js";import"./KHR_interactivity-DRPs30Rf.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class F extends t{constructor(r){super(s,p,o=>+o,"FlowGraphBooleanToFloat",r)}}a("FlowGraphBooleanToFloat",F);class i extends t{constructor(r){super(s,n,o=>e.FromValue(+o),"FlowGraphBooleanToInt",r)}}a("FlowGraphBooleanToInt",i);class m extends t{constructor(r){super(p,s,o=>!!o,"FlowGraphFloatToBoolean",r)}}a("FlowGraphFloatToBoolean",m);class u extends t{constructor(r){super(n,s,o=>!!o.value,"FlowGraphIntToBoolean",r)}}a("FlowGraphIntToBoolean",u);class c extends t{constructor(r){super(n,p,o=>o.value,"FlowGraphIntToFloat",r)}}a("FlowGraphIntToFloat",c);class h extends t{constructor(r){super(p,n,o=>{switch(r?.roundingMode){case"floor":return e.FromValue(Math.floor(o));case"ceil":return e.FromValue(Math.ceil(o));case"round":return e.FromValue(Math.round(o));default:return e.FromValue(o)}},"FlowGraphFloatToInt",r)}}a("FlowGraphFloatToInt",h);export{F as FlowGraphBooleanToFloat,i as FlowGraphBooleanToInt,m as FlowGraphFloatToBoolean,h as FlowGraphFloatToInt,u as FlowGraphIntToBoolean,c as FlowGraphIntToFloat};
