const o="العربية",e={annotated_image:"صورة مشروحة"},r={allow_recording_access:"يرجى السماح بالوصول إلى الميكروفون للتسجيل",audio:"صوتي",record_from_microphone:"تسجيل من الميكروفون",stop_recording:"إيقاف التسجيل",no_device_support:"لا يمكن الوصول إلى أجهزة الوسائط. تأكد من أنك تعمل على مصدر آمن (https) أو localhost (أو قمت بتمرير شهادة SSL صالحة إلى ssl_verify)، وأنك سمحت للمتصفح بالوصول إلى جهازك.",stop:"إيقاف",resume:"استئناف",record:"تسجيل",no_microphone:"لم يتم العثور على ميكروفون",pause:"إيقاف مؤقت",play:"تشغيل",waiting:"جاري الانتظار",drop_to_upload:"اسقط ملف صوت هنا للتحميل"},t={connection_can_break:"على الهاتف المحمول، يمكن أن ينقطع الاتصال إذا تم تغيير التبويب لهذه الصفحةة أو دخل الجهاز في وضع السكون، مما يؤدي إلى فقدان موقعك في قائمة الانتظار.",long_requests_queue:"هناك قائمة انتظار طويلة من الطلبات المعلقة. قم بنسخ هذه المساحة للتخطي.",lost_connection:"تم فقدان الاتصال بسبب مغادرة الصفحة. جارٍ إعادة الانضمام إلى قائمة الانتظار...",waiting_for_inputs:"إنتظر انتهاء رفع الملف(ات)، يرجى إعادة المحاولة."},_={checkbox:"خانة اختيار",checkbox_group:"مجموعة خانات الاختيار"},c={code:"الكود"},a={color_picker:"منتقي الألوان"},n={built_with:"بُني باستخدام",built_with_gradio:"بني بإستخدام Gradio",clear:"أمسح",download:"تنزيل",edit:"تعديل",empty:"فارغ",error:"خطأ",hosted_on:"مستضاف على",loading:"جاري التحميل",logo:"شعار",or:"أو",remove:"إزالة",settings:"الإعدادات",share:"مشاركة",submit:"أرسل",undo:"تراجع",no_devices:"لم يتم العثور على أجهزة",language:"اللغة",display_theme:"مظهر العرض",pwa:"تطبيق ويب تقدمي",record:"تسجيل",stop_recording:"إيقاف التسجيل",screen_studio:"شاشة الأستوديو",share_gradio_tab:"مشاركة تبويبة صفحة Gradio",run:"تشغيل"},s={incorrect_format:"تنسيق غير صحيح، يتم دعم ملفات CSV و TSV فقط",new_column:"إضافة عمود",new_row:"صف جديد",add_row_above:"إضافة صف فوق",add_row_below:"إضافة صف تحت",add_column_left:"إضافة عمود لليسار",add_column_right:"إضافة عمود لليمين",delete_row:"حذف الصف",delete_column:"حذف العمود",sort_column:"فرز العمود",sort_ascending:"فرز تصاعدي",sort_descending:"فرز تنازلي",drop_to_upload:"اسقط ملفات CSV أو TSV هنا لاستيراد البيانات إلى الإطر الجدولية",clear_sort:"مسح الترتيب",filter:"مرشح",clear_filter:"مسح المرشحات"},d={dropdown:"قائمة منسدلة"},i={build_error:"هناك خطأ في البناء",config_error:"هناك خطأ في التكوين",contact_page_author:"يرجى التواصل مع مبرمج الصفحة",no_app_file:"لا يوجد ملف تطبيق",runtime_error:"هناك خطأ أثناء التشغيل",space_not_working:"المساحة لا تعمل لأن {0}",space_paused:"المساحة متوقفة مؤقتًا",use_via_api:"إستخدام عبر API",use_via_api_or_mcp:"إستخدام عبر واجهة برمجة التطبيقات API أو خادم MCP"},l={uploading:"جاري الرفع..."},p={highlighted_text:"نص محدد"},u={allow_webcam_access:"يرجى السماح بالوصول إلى كاميرا الويب للتسجيل.",brush_color:"لون الفرشاة",brush_radius:"حجم الفرشاة",image:"صورة",remove_image:"إزالة الصورة",select_brush_color:"اختر لون الفرشاة",start_drawing:"ابدأ الرسم",use_brush:"استخدم الفرشاة",drop_to_upload:"اسقط ملف الصورة هنا لتحميله"},g={label:"ملصق"},m={enable_cookies:"إذا كنت تزور مساحة HuggingFace في وضع التصفح المتخفي، يجب عليك تمكين ملفات تعريف الارتباط من الجهات الخارجية.",incorrect_credentials:"بيانات الاعتماد غير صحيحة",username:"اسم المستخدم",password:"كلمة المرور",login:"تسجيل الدخول"},b={number:"رقم"},h={plot:"رسم بياني"},w={radio:"زر راديو"},f={slider:"شريط التمرير"},k={click_to_upload:"انقر للتحميل",drop_audio:"أسقط الملف الصوتي هنا",drop_csv:"أسقط ملف البيانات هنا",drop_file:"أسقط الملف هنا",drop_image:"أسقط الصورة هنا",drop_video:"أسقط الفيديو هنا",drop_gallery:"أسقط الوسائط هنا",paste_clipboard:"لصق من الحافظة"},v={drop_to_upload:"اسقط ملف الفيديو هنا للتحميل"},x={edit:"تعديل",retry:"إعادة المحاولة",undo:"تراجع",submit:"إرسال",cancel:"إلغاء",like:"إعجاب",dislike:"عدم الإعجاب",clear:"مسح المحادثة"},y={_name:o,"3D_model":{"3d_model":"نموذج ثلاثي الأبعاد",drop_to_upload:"اسقط ملف نموذج ثلاثي الأبعاد 3D (.obj، .glb، .stl، .gltf، .splat، أو .ply) هنا للتحميل"},annotated_image:e,audio:r,blocks:t,checkbox:_,code:c,color_picker:a,common:n,dataframe:s,dropdown:d,errors:i,file:l,highlighted_text:p,image:u,label:g,login:m,number:b,plot:h,radio:w,slider:f,upload_text:k,video:v,chatbot:x};

export { o as _name, e as annotated_image, r as audio, t as blocks, x as chatbot, _ as checkbox, c as code, a as color_picker, n as common, s as dataframe, y as default, d as dropdown, i as errors, l as file, p as highlighted_text, u as image, g as label, m as login, b as number, h as plot, w as radio, f as slider, k as upload_text, v as video };
//# sourceMappingURL=ar-oZrlju6V.js.map
