import{c as p,_ as i}from"./KHR_interactivity-DRPs30Rf.js";import{b as n,R as s}from"./declarationMapper-CGPHX8aB.js";import{R as m}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class h extends p{constructor(t){super(t),this.type="PointerOver",this.pointerId=this.registerDataOutput("pointerId",n),this.targetMesh=this.registerDataInput("targetMesh",s,t?.targetMesh),this.meshUnderPointer=this.registerDataOutput("meshUnderPointer",s)}_executeEvent(t,e){const r=this.targetMesh.getValue(t);this.meshUnderPointer.setValue(e.mesh,t);const o=e.out&&i(e.out,r);return this.pointerId.setValue(e.pointerId,t),!o&&(e.mesh===r||i(e.mesh,r))?(this._execute(t),!this.config?.stopPropagation):!0}_preparePendingTasks(t){}_cancelPendingTasks(t){}getClassName(){return"FlowGraphPointerOverEventBlock"}}m("FlowGraphPointerOverEventBlock",h);export{h as FlowGraphPointerOverEventBlock};
