.container.svelte-ous74z img{width:100%;height:100%}.container.selected.svelte-ous74z{border-color:var(--border-color-accent)}.container.table.svelte-ous74z{margin:0 auto;border:2px solid var(--border-color-primary);border-radius:var(--radius-lg);width:var(--size-20);height:var(--size-20);object-fit:cover}.container.gallery.svelte-ous74z{border:2px solid var(--border-color-primary);height:var(--size-20);max-height:var(--size-20);object-fit:cover}
