import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import{G as n}from"./utils.svelte-Ceck75cM.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";var u=t.from_html('<div><div class="styler svelte-1p9262q"><!></div></div>');function E(s,e){t.push(e,!0);const d=t.rest_props(e,["$$slots","$$events","$$legacy"]);new n(d);const l=t.derived(()=>e.elem_id||""),m=t.derived(()=>e.elem_classes||[]),p=t.derived(()=>e.visible===void 0?!0:e.visible);var i=u();let o;var r=t.child(i);t.set_style(r,"",{},{"--block-radius":"0px","--block-border-width":"0px","--layout-gap":"1px","--form-gap-width":"1px","--button-border-width":"0px","--button-large-radius":"0px","--button-small-radius":"0px"});var a=t.child(r);t.slot(a,e,"default",{},null),t.reset(r),t.reset(i),t.template_effect(v=>{t.set_attribute(i,"id",t.get(l)),o=t.set_class(i,1,`gr-group ${v??""}`,"svelte-1p9262q",o,{hide:!t.get(p)})},[()=>t.get(m).join(" ")]),t.append(s,i),t.pop()}export{E as default};
