import { cu as escape_html, ch as getContext } from './async-DSsyBdZ5.js';
import { m, A } from './client3-CHaxWNm_.js';
import { s as s$2, e } from './dev-fallback-Bc5Ork7Y.js';
import './exports-BWb4C4M4.js';

const s$1={get error(){return m.error},get status(){return m.status}};A.updated.check;

function t(){return getContext("__request__")}function n(e){try{return t()}catch{throw new Error(`Can only read '${e}' on the server during rendering (not in e.g. \`load\` functions), as it is bound to the current request via component context. This prevents state from leaking between users.For more information, see https://svelte.dev/docs/kit/state-management#avoid-shared-state-on-the-server`)}}const c={get error(){return (e?n("page.error"):t()).page.error},get status(){return (e?n("page.status"):t()).page.status}},s=s$2?s$1:c;function $(e,m){e.component(a=>{a.push(`<h1>${escape_html(s.status)}</h1> <p>${escape_html(s.error?.message)}</p>`);});}

export { $ as default };
//# sourceMappingURL=error.svelte-CQ8EhGYi.js.map
