import{p as i,s as n,f as p,c as s,S as l,t as m}from"./Index-CiNTmN03.js";import{yaml as f}from"./yaml-DsCXHVTH.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./utils.svelte-Ceck75cM.js";import"./StreamingBar-b2qVLPYU.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";import"./Example-C8-r9viM.js";const a=/^---\s*$/m,C={defineNodes:[{name:"Frontmatter",block:!0},"FrontmatterMark"],props:[n({Frontmatter:[m.documentMeta,m.monospace],FrontmatterMark:m.processingInstruction}),p.add({Frontmatter:s,FrontmatterMark:()=>null})],wrap:i(t=>{const{parser:o}=l.define(f);return t.type.name==="Frontmatter"?{parser:o,overlay:[{from:t.from+4,to:t.to-4}]}:null}),parseBlock:[{name:"Frontmatter",before:"HorizontalRule",parse:(t,o)=>{let r;const e=new Array;if(t.lineStart===0&&a.test(o.text)){for(e.push(t.elt("FrontmatterMark",0,4));t.nextLine();)if(a.test(o.text)){r=t.lineStart+4;break}return r!==void 0&&(e.push(t.elt("FrontmatterMark",r-4,r)),t.addElement(t.elt("Frontmatter",0,r,e))),!0}return!1}}]};export{C as frontmatter};
