.checkbox-container.svelte-1q8xtp9{display:flex;align-items:center;gap:var(--spacing-lg);cursor:pointer}.label-text.svelte-1q8xtp9{color:var(--body-text-color);font-size:var(--checkbox-label-text-size);line-height:var(--line-sm)}input.svelte-1q8xtp9{--ring-color: transparent;position:relative;box-shadow:var(--checkbox-shadow);border:1px solid var(--checkbox-border-color);border-radius:var(--checkbox-border-radius);background-color:var(--checkbox-background-color);line-height:var(--line-sm);flex-shrink:0}input.svelte-1q8xtp9:checked,input.svelte-1q8xtp9:checked:hover,input.svelte-1q8xtp9:checked:focus{background-image:var(--checkbox-check);background-color:var(--checkbox-background-color-selected);border-color:var(--checkbox-border-color-focus)}input.svelte-1q8xtp9:checked:focus{background-image:var(--checkbox-check);background-color:var(--checkbox-background-color-selected);border-color:var(--checkbox-border-color-focus)}input.svelte-1q8xtp9:hover{border-color:var(--checkbox-border-color-hover);background-color:var(--checkbox-background-color-hover)}input.svelte-1q8xtp9:focus{border-color:var(--checkbox-border-color-focus);background-color:var(--checkbox-background-color-focus)}input.svelte-1q8xtp9:indeterminate{background-image:none;background-color:var(--checkbox-background-color-selected);border-color:var(--checkbox-border-color-focus);position:relative}input.svelte-1q8xtp9:indeterminate:after{content:"";position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);width:8px;height:2px;background-color:#fff}input.svelte-1q8xtp9:indeterminate:hover{background-color:var(--checkbox-background-color-selected);border-color:var(--checkbox-border-color-hover)}input.svelte-1q8xtp9:indeterminate:focus{background-color:var(--checkbox-background-color-selected);border-color:var(--checkbox-border-color-focus)}input[disabled].svelte-1q8xtp9{cursor:not-allowed;opacity:.75}label.disabled.svelte-1q8xtp9{cursor:not-allowed}input.svelte-1q8xtp9:not([disabled]):hover{cursor:pointer}
