import"./svelte/svelte_internal_flags_async.js";import*as o from"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import{G as a}from"./utils.svelte-Ceck75cM.js";import{B as l}from"./Index.svelte_svelte_type_style_lang-Bv_DpXXD.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./StreamingBar-b2qVLPYU.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";function E(p,r){o.push(r,!0);let m=o.rest_props(r,["$$slots","$$events","$$legacy"]);const i=new a(m);l(p,o.spread_props(()=>i.shared,{children:(e,n)=>{var t=o.comment(),s=o.first_child(t);o.slot(s,r,"default",{},null),o.append(e,t)},$$slots:{default:!0}})),o.pop()}export{l as BaseColumn,E as default};
