.container.svelte-7i12tt{display:flex;flex-direction:column;gap:var(--spacing-sm);padding:var(--block-padding)}.hl.svelte-7i12tt+.hl:where(.svelte-7i12tt){margin-left:var(--size-1)}.textspan.svelte-7i12tt:last-child>.label:where(.svelte-7i12tt){margin-right:0}.category-legend.svelte-7i12tt{display:flex;flex-wrap:wrap;gap:var(--spacing-sm);color:#000}.category-label.svelte-7i12tt{cursor:pointer;border-radius:var(--radius-xs);padding-right:var(--size-2);padding-left:var(--size-2);font-weight:var(--weight-semibold)}.color-legend.svelte-7i12tt{display:flex;justify-content:space-between;border-radius:var(--radius-xs);background:linear-gradient(to right,var(--color-purple),rgba(255,255,255,0),var(--color-red));padding:var(--size-1) var(--size-2);font-weight:var(--weight-semibold)}.textfield.svelte-7i12tt{box-sizing:border-box;border-radius:var(--radius-xs);background:var(--background-fill-primary);background-color:transparent;max-width:var(--size-full);line-height:var(--scale-4);word-break:break-all}.textspan.svelte-7i12tt{transition:.15s;border-radius:var(--radius-xs);padding-top:2.5px;padding-right:var(--size-1);padding-bottom:3.5px;padding-left:var(--size-1);color:#000}.label.svelte-7i12tt{transition:.15s;margin-top:1px;border-radius:var(--radius-xs);padding:1px 5px;color:var(--body-text-color);color:#fff;font-weight:var(--weight-bold);font-size:var(--text-sm);text-transform:uppercase}.text.svelte-7i12tt{color:#000;white-space:pre-wrap}.score-text.svelte-7i12tt .text:where(.svelte-7i12tt){color:var(--body-text-color)}.score-text.svelte-7i12tt{margin-right:var(--size-1);padding:var(--size-1)}.no-cat.svelte-7i12tt,.no-label.svelte-7i12tt{color:var(--body-text-color)}.selectable.svelte-7i12tt{cursor:pointer}.label-input.svelte-14ic1z3{transition:.15s;margin-top:1px;margin-right:calc(var(--size-1));border-radius:var(--radius-xs);padding:1px 5px;color:#000;font-weight:var(--weight-bold);font-size:var(--text-sm);text-transform:uppercase;line-height:1;color:#fff}.label-input.svelte-14ic1z3::placeholder{color:#01010180}.label-clear-button.svelte-7z1kwz{display:none;border-radius:var(--radius-xs);padding-top:2.5px;padding-right:var(--size-1);padding-bottom:3.5px;padding-left:var(--size-1);color:#000;background-color:var(--background-fill-secondary);user-select:none;position:relative;left:-3px;border-radius:0 var(--radius-xs) var(--radius-xs) 0;color:var(--block-label-text-color)}.text-class_or_confidence-container.svelte-7z1kwz:hover .label-clear-button:where(.svelte-7z1kwz),.text-class_or_confidence-container.svelte-7z1kwz:focus-within .label-clear-button:where(.svelte-7z1kwz),.score-text-container.svelte-7z1kwz:hover .label-clear-button:where(.svelte-7z1kwz),.score-text-container.svelte-7z1kwz:focus-within .label-clear-button:where(.svelte-7z1kwz){display:inline}.text-class_or_confidence-container.svelte-7z1kwz:hover .textspan.hl:where(.svelte-7z1kwz),.text-class_or_confidence-container.svelte-7z1kwz:focus-within .textspan.hl:where(.svelte-7z1kwz),.score-text.svelte-7z1kwz:hover{border-radius:var(--radius-xs) 0 0 var(--radius-xs)}.container.svelte-7z1kwz{display:flex;flex-direction:column;gap:var(--spacing-sm);padding:var(--block-padding)}.hl.svelte-7z1kwz{margin-left:var(--size-1);transition:background-color .3s;user-select:none}.textspan.svelte-7z1kwz:last-child>.label:where(.svelte-7z1kwz){margin-right:0}.class_or_confidence-legend.svelte-7z1kwz{display:flex;flex-wrap:wrap;gap:var(--spacing-sm);color:#000}.class_or_confidence-label.svelte-7z1kwz{cursor:pointer;border-radius:var(--radius-xs);padding-right:var(--size-2);padding-left:var(--size-2);font-weight:var(--weight-semibold)}.color-legend.svelte-7z1kwz{display:flex;justify-content:space-between;border-radius:var(--radius-xs);background:linear-gradient(to right,var(--color-purple),rgba(255,255,255,0),var(--color-red));padding:var(--size-1) var(--size-2);font-weight:var(--weight-semibold)}.textfield.svelte-7z1kwz{box-sizing:border-box;border-radius:var(--radius-xs);background:var(--background-fill-primary);background-color:transparent;max-width:var(--size-full);line-height:var(--scale-4);word-break:break-all}.textspan.svelte-7z1kwz{transition:.15s;border-radius:var(--radius-xs);padding-top:2.5px;padding-right:var(--size-1);padding-bottom:3.5px;padding-left:var(--size-1);color:#000;cursor:text}.label.svelte-7z1kwz{transition:.15s;margin-top:1px;border-radius:var(--radius-xs);padding:1px 5px;color:var(--body-text-color);color:#fff;font-weight:var(--weight-bold);font-size:var(--text-sm);text-transform:uppercase;user-select:none}.text.svelte-7z1kwz{color:#000;white-space:pre-wrap}.textspan.hl.svelte-7z1kwz{user-select:none}.score-text-container.svelte-7z1kwz{margin-right:var(--size-1)}.score-text.svelte-7z1kwz .text:where(.svelte-7z1kwz){color:var(--body-text-color)}.no-cat.svelte-7z1kwz{color:var(--body-text-color)}.no-label.svelte-7z1kwz{color:var(--body-text-color);user-select:text}.selectable.svelte-7z1kwz{cursor:text;user-select:text}
