const index = 1;
let component_cache;
const component = async () => component_cache ??= (await import('./error.svelte-CQ8EhGYi.js')).default;
const imports = ["_app/immutable/nodes/1.BRNHPTcQ.js","_app/immutable/chunks/tab-Zvqo.js","_app/immutable/chunks/CCr6UdYm.js"];
const stylesheets = [];
const fonts = [];

export { component, fonts, imports, index, stylesheets };
//# sourceMappingURL=1-CTgTJai2.js.map
