.api-name.svelte-1kdww8a{font-size:var(--text-sm);font-family:var(--font-mono);color:#fd7b00}.loading-dot.svelte-1kdww8a{position:relative;left:-9999px;width:10px;height:10px;border-radius:5px;background-color:#fd7b00;color:#fd7b00;box-shadow:9999px 0 0 -1px;animation:svelte-1kdww8a-loading-dot 2s infinite linear;animation-delay:.25s;margin-left:.25rem;margin-right:.5rem}.docs-wrap .sm.secondary{padding-top:1px;padding-bottom:1px}.self-baseline.svelte-1kdww8a{align-self:baseline}@keyframes svelte-1kdww8a-loading-dot{0%{box-shadow:9999px 0 0 -1px}50%{box-shadow:9999px 0 0 2px}to{box-shadow:9999px 0 0 -1px}}.api-count.svelte-1kdww8a{font-weight:700;color:#fd7b00;align-self:baseline;font-family:var(--font-mono);font-size:var(--text-sm)}.api-section.svelte-1kdww8a{margin-left:4px}
