import"./svelte/svelte_internal_flags_async.js";import*as r from"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import{G as a}from"./utils.svelte-Ceck75cM.js";import{B as l}from"./Button-D-Ky-vOi.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./Image-Bdf4wQSw.js";import"./ImagePreview-Cx854cRW.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";import"./ShareButton-DCJS4lh5.js";import"./FullscreenButton-Cqzqqtq6.js";function K(o,e){r.push(e,!0);let p=r.rest_props(e,["$$slots","$$events","$$legacy"]);const t=new a(p);function s(){t.dispatch("click")}{let m=r.derived(()=>!t.shared.interactive);l(o,{get value(){return t.props.value},get variant(){return t.props.variant},get elem_id(){return t.shared.elem_id},get elem_classes(){return t.shared.elem_classes},get size(){return t.props.size},get scale(){return t.props.scale},get link(){return t.props.link},get icon(){return t.props.icon},get min_width(){return t.shared.min_width},get visible(){return t.shared.visible},get disabled(){return r.get(m)},get link_target(){return t.props.link_target},onclick:s,children:(n,u)=>{r.next();var i=r.text();r.template_effect(()=>r.set_text(i,t.props.value??"")),r.append(n,i)},$$slots:{default:!0}})}r.pop()}export{l as BaseButton,K as default};
