import{F as l}from"./KHR_interactivity-DRPs30Rf.js";import{R as s,e as i}from"./declarationMapper-CGPHX8aB.js";import{d as e,V as c,R as h}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class y extends l{constructor(t){super(t),this.sourceSystem=this.registerDataInput("sourceSystem",s),this.destinationSystem=this.registerDataInput("destinationSystem",s),this.inputCoordinates=this.registerDataInput("inputCoordinates",i),this.outputCoordinates=this.registerDataOutput("outputCoordinates",i)}_updateOutputs(t){const a=this.sourceSystem.getValue(t),n=this.destinationSystem.getValue(t),p=this.inputCoordinates.getValue(t),m=a.getWorldMatrix(),u=n.getWorldMatrix(),o=e.Matrix[0].copyFrom(u);o.invert();const r=e.Matrix[1];o.multiplyToRef(m,r);const d=this.outputCoordinates.getValue(t);c.TransformCoordinatesToRef(p,r,d)}getClassName(){return"FlowGraphTransformCoordinatesSystemBlock"}}h("FlowGraphTransformCoordinatesSystemBlock",y);export{y as FlowGraphTransformCoordinatesSystemBlock};
