import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import{G as a}from"./utils.svelte-Ceck75cM.js";import{B as l}from"./BaseForm-C8gZwaiu.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";function q(e,r){t.push(r,!0);let m=t.rest_props(r,["$$slots","$$events","$$legacy"]);const o=new a(m);l(e,{get visible(){return o.shared.visible},get scale(){return o.shared.scale},get min_width(){return o.shared.min_width},children:(p,n)=>{var i=t.comment(),s=t.first_child(i);t.slot(s,r,"default",{},null),t.append(p,i)},$$slots:{default:!0}}),t.pop()}export{l as BaseForm,q as default};
