import{S as e}from"./index-6jOCfdig.js";const t="logDepthDeclaration",a=`#ifdef LOGARITHMICDEPTH
uniform float logarithmicDepthConstant;varying float vFragmentDepth;
#endif
`;e.IncludesShadersStore[t]||(e.IncludesShadersStore[t]=a);
