import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import{I as n}from"./Image-Bdf4wQSw.js";var c=e.from_html("<div><!></div>");function h(o,r){e.push(r,!1);let l=e.prop(r,"value",12),a=e.prop(r,"type",12),u=e.prop(r,"selected",12,!1);var d={get value(){return l()},set value(t){l(t),e.flush()},get type(){return a()},set type(t){a(t),e.flush()},get selected(){return u()},set selected(t){u(t),e.flush()}};e.init();var s=c();let p;var f=e.child(s);{var i=t=>{n(t,{get src(){return e.deep_read_state(l()),e.untrack(()=>l().url)},alt:""})};e.if(f,t=>{l()&&t(i)})}return e.reset(s),e.template_effect(()=>p=e.set_class(s,1,"container svelte-bs74gu",null,p,{table:a()==="table",gallery:a()==="gallery",selected:u(),border:l()})),e.append(o,s),e.pop(d)}export{h as default};
