import{c as i}from"./KHR_interactivity-DRPs30Rf.js";import{R as o}from"./index-6jOCfdig.js";import{b as r}from"./declarationMapper-CGPHX8aB.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class m extends i{constructor(){super(),this.type="SceneBeforeRender",this.timeSinceStart=this.registerDataOutput("timeSinceStart",r),this.deltaTime=this.registerDataOutput("deltaTime",r)}_preparePendingTasks(t){}_executeEvent(t,e){return this.timeSinceStart.setValue(e.timeSinceStart,t),this.deltaTime.setValue(e.deltaTime,t),this._execute(t),!0}_cancelPendingTasks(t){}getClassName(){return"FlowGraphSceneTickEventBlock"}}o("FlowGraphSceneTickEventBlock",m);export{m as FlowGraphSceneTickEventBlock};
