import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var v=e.from_html("<div> </div>");function _(n,r){e.push(r,!1);let l=e.prop(r,"value",12),a=e.prop(r,"type",12),u=e.prop(r,"selected",12,!1),i=e.prop(r,"choices",12),p=(l()?Array.isArray(l())?l():[l()]:[]).map(t=>i().find(d=>d[1]===t)?.[0]).filter(t=>t!==void 0).join(", ");var o={get value(){return l()},set value(t){l(t),e.flush()},get type(){return a()},set type(t){a(t),e.flush()},get selected(){return u()},set selected(t){u(t),e.flush()},get choices(){return i()},set choices(t){i(t),e.flush()}};e.init();var s=v();let c;var f=e.child(s,!0);return e.reset(s),e.template_effect(()=>{c=e.set_class(s,1,"svelte-1by696e",null,c,{table:a()==="table",gallery:a()==="gallery",selected:u()}),e.set_text(f,p)}),e.append(n,s),e.pop(o)}export{_ as default};
