import{E,c as y,d as L,g as T,a as j,i as q,l as v,e as w,m as z,p as B,b as C,s as D,t as F}from"./i18n-BldJSFLV.js";import{A as H}from"./init.svelte-1j0vhaZC.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./index-tFQomdd2.js";import"./utils.svelte-Ceck75cM.js";export{H as AppTree,E as Embed,y as all_common_keys,L as changeLocale,T as get_initial_locale,j as i18n_marker,q as is_translation_metadata,v as language_choices,w as load_translations,z as mount_css,B as prefix_css,C as process_langs,D as setupi18n,F as translate_if_needed};
