const o="Polski",a={annotated_image:"Obraz z adnotacjami"},e={allow_recording_access:"Proszę zezwolić na dostęp do mikrofonu w celu nagrywania.",audio:"Audio",record_from_microphone:"Nagraj z mikrofonu",stop_recording:"Zatrzymaj nagrywanie",no_device_support:"Nie można uzyskać dostępu do urządzeń multimedialnych. Upewnij się, że działasz na bezpiecznym źródle (https) lub localhost (lub przekazałeś prawidłowy certyfikat SSL do ssl_verify), i że zezwoliłeś przeglądarce na dostęp do twojego urządzenia.",stop:"Stop",resume:"Wznów",record:"Nagrywaj",no_microphone:"Nie znaleziono mikrofonu",pause:"Pauza",play:"Odtwórz",waiting:"Oczekiwanie",drop_to_upload:"Upuść plik audio tutaj, aby go przesłać"},i={connection_can_break:"Na urządzeniu mobilnym połączenie może zostać przerwane, jeśli ta karta straci fokus lub urządzenie przejdzie w tryb uśpienia, tracąc twoje miejsce w kolejce.",long_requests_queue:"Istnieje długa kolejka oczekujących żądań. Zduplikuj ten Space, aby ją pominąć.",lost_connection:"Utracono połączenie z powodu opuszczenia strony. Powrót do kolejki...",waiting_for_inputs:"Oczekiwanie na zakończenie przesyłania pliku(ów), proszę spróbować ponownie."},r={checkbox:"Pole wyboru",checkbox_group:"Grupa pól wyboru"},t={code:"Kod"},n={color_picker:"Wybór koloru"},l={built_with:"Zbudowane z",built_with_gradio:"Zbudowane z Gradio",clear:"Wyczyść",download:"Pobierz",edit:"Edytuj",empty:"Pusty",error:"Błąd",hosted_on:"Hostowane na",loading:"Ładowanie",logo:"Logo",or:"lub",remove:"Usuń",settings:"Ustawienia",share:"Udostępnij",submit:"Wyślij",undo:"Cofnij",no_devices:"Nie znaleziono urządzeń",language:"Język",display_theme:"Motyw wyświetlania",pwa:"Progresywna aplikacja webowa"},s={incorrect_format:"Nieprawidłowy format, obsługiwane są tylko pliki CSV i TSV",new_column:"Dodaj kolumnę",new_row:"Nowy wiersz",add_row_above:"Dodaj wiersz powyżej",add_row_below:"Dodaj wiersz poniżej",add_column_left:"Dodaj kolumnę po lewej",add_column_right:"Dodaj kolumnę po prawej",delete_row:"Usuń wiersz",delete_column:"Usuń kolumnę",sort_column:"Sortuj kolumnę",sort_ascending:"Sortuj rosnąco",sort_descending:"Sortuj malejąco",drop_to_upload:"Upuść pliki CSV lub TSV tutaj, aby zaimportować dane do ramki danych",clear_sort:"Wyczyść sortowanie"},d={dropdown:"Lista rozwijana"},p={build_error:"Wystąpił błąd kompilacji",config_error:"Wystąpił błąd konfiguracji",contact_page_author:"Proszę skontaktować się z autorem strony, aby go poinformować.",no_app_file:"Brak pliku aplikacji",runtime_error:"Wystąpił błąd wykonania",space_not_working:'"Space nie działa, ponieważ" {0}',space_paused:"Space jest wstrzymany",use_via_api:"Użyj przez API",use_via_api_or_mcp:"Użyj przez API lub MCP"},u={uploading:"Przesyłanie..."},c={highlighted_text:"Wyróżniony tekst"},z={allow_webcam_access:"Proszę zezwolić na dostęp do kamery internetowej w celu nagrywania.",brush_color:"Kolor pędzla",brush_radius:"Rozmiar pędzla",image:"Obraz",remove_image:"Usuń obraz",select_brush_color:"Wybierz kolor pędzla",start_drawing:"Rozpocznij rysowanie",use_brush:"Użyj pędzla",drop_to_upload:"Upuść plik obrazu tutaj, aby go przesłać"},_={label:"Etykieta"},w={enable_cookies:"Jeśli odwiedzasz HuggingFace Space w trybie incognito, musisz włączyć pliki cookie stron trzecich.",incorrect_credentials:"Nieprawidłowe dane logowania",username:"Nazwa użytkownika",password:"Hasło",login:"Zaloguj się"},y={number:"Liczba"},k={plot:"Wykres"},b={radio:"Przycisk opcji"},j={slider:"Suwak"},m={click_to_upload:"Kliknij, aby przesłać",drop_audio:"Upuść plik audio tutaj",drop_csv:"Upuść plik CSV tutaj",drop_file:"Upuść plik tutaj",drop_image:"Upuść obraz tutaj",drop_video:"Upuść plik wideo tutaj",drop_gallery:"Upuść media tutaj",paste_clipboard:"Wklej ze schowka"},g={drop_to_upload:"Upuść plik wideo tutaj, aby go przesłać"},h={edit:"Edytuj",retry:"Spróbuj ponownie",undo:"Cofnij",submit:"Wyślij",cancel:"Anuluj",like:"Lubię to",dislike:"Nie lubię tego",clear:"Wyczyść czat"},f={_name:o,"3D_model":{"3d_model":"Model 3D",drop_to_upload:"Upuść plik modelu 3D (.obj, .glb, .stl, .gltf, .splat lub .ply) tutaj, aby go przesłać"},annotated_image:a,audio:e,blocks:i,checkbox:r,code:t,color_picker:n,common:l,dataframe:s,dropdown:d,errors:p,file:u,highlighted_text:c,image:z,label:_,login:w,number:y,plot:k,radio:b,slider:j,upload_text:m,video:g,chatbot:h};

export { o as _name, a as annotated_image, e as audio, i as blocks, h as chatbot, r as checkbox, t as code, n as color_picker, l as common, s as dataframe, f as default, d as dropdown, p as errors, u as file, c as highlighted_text, z as image, _ as label, w as login, y as number, k as plot, b as radio, j as slider, m as upload_text, g as video };
//# sourceMappingURL=pl-BGo_kgCP.js.map
