import { t } from './index5-BoOEKc6P.js';
import './dev-fallback-Bc5Ork7Y.js';

async function g({request:e}){const o=e.headers.get("x-gradio-server")||"http://127.0.0.1:7860",a=e.headers.get("x-gradio-port")||"7860",r=e.headers.get("x-gradio-local-dev-mode")||t?"true":void 0,t$1=e.headers.get("accept-language")||"en";return {server:o,port:a,local_dev_mode:r,accept_language:t$1}}

var _page_server_ts = /*#__PURE__*/Object.freeze({
  __proto__: null,
  load: g
});

const index = 2;
let component_cache;
const component = async () => component_cache ??= (await import('./_page.svelte-C9dqMx6c.js')).default;
const universal = {
  "ssr": false,
  "load": null
};
const universal_id = "src/routes/[...catchall]/+page.ts";
const server_id = "src/routes/[...catchall]/+page.server.ts";
const imports = ["_app/immutable/nodes/2.CwYYHXAO.js","_app/immutable/chunks/DDb4FK6Q.js","_app/immutable/chunks/PPVm8Dsz.js","_app/immutable/chunks/tab-Zvqo.js","_app/immutable/chunks/CCr6UdYm.js"];
const stylesheets = ["_app/immutable/assets/2.Wr6IMO4a.css","_app/immutable/assets/Index.DHz84ApK.css","_app/immutable/assets/Index.DIMxqS5W.css","_app/immutable/assets/Example.PnzFsODt.css","_app/immutable/assets/ModifyUpload.C2I0h_eD.css","_app/immutable/assets/Index.GQZxeo40.css","_app/immutable/assets/Index.h7FHnzgS.css","_app/immutable/assets/Example.Cpi22WGa.css","_app/immutable/assets/Index.B2BpVHOS.css","_app/immutable/assets/Example.QWdMqwA5.css","_app/immutable/assets/Index.Czv6Lgei.css","_app/immutable/assets/Example.BK-tWmkG.css","_app/immutable/assets/Example.bHSd0VUC.css","_app/immutable/assets/Index.Ci-0XPiC.css","_app/immutable/assets/Example.jts6u4zx.css","_app/immutable/assets/Index.DpH7sR6h.css","_app/immutable/assets/Index.EYuwUe6R.css","_app/immutable/assets/Example.BUUMH8K0.css","_app/immutable/assets/Example.BeU1J4ps.css","_app/immutable/assets/Index.CRhvQE-V.css","_app/immutable/assets/Index.YiZqZSMk.css","_app/immutable/assets/Index.3FqI08xq.css","_app/immutable/assets/Index.CioP8lnm.css","_app/immutable/assets/Example.CbN4r5yx.css","_app/immutable/assets/Index.BDarcd0p.css","_app/immutable/assets/Example.-V2chS2k.css","_app/immutable/assets/Index.CEhk7M0s.css","_app/immutable/assets/Video.emdvV6JL.css","_app/immutable/assets/Gallery.DJhld1Jx.css","_app/immutable/assets/Example.CA1DPrcM.css","_app/immutable/assets/Index.BPmhhU8b.css","_app/immutable/assets/Index.CWjJyaUi.css","_app/immutable/assets/Example.BG5zdIqX.css","_app/immutable/assets/Index.DJn8IRw4.css","_app/immutable/assets/Example.CZSJmqDf.css","_app/immutable/assets/Index.Dpdel1G9.css","_app/immutable/assets/Example.C7vkYQeg.css","_app/immutable/assets/Example.CD_WZEqN.css","_app/immutable/assets/Index.BpcA6Nec.css","_app/immutable/assets/JSON.BXT8NU56.css","_app/immutable/assets/Example.BlpJt4zj.css","_app/immutable/assets/Index.-e-Yppt2.css","_app/immutable/assets/Example.CgIc4GLa.css","_app/immutable/assets/Index.cY7HT1Ac.css","_app/immutable/assets/Model3D.CvGLqGnb.css","_app/immutable/assets/Example.RXDI_Ar6.css","_app/immutable/assets/Index.CvyxbOJU.css","_app/immutable/assets/Example.BIrWl-Kd.css","_app/immutable/assets/Index.Cq0rPgbs.css","_app/immutable/assets/Index.fPjHowzi.css","_app/immutable/assets/Example.guFL0Sj1.css","_app/immutable/assets/Index.CTDY4JGM.css","_app/immutable/assets/Example.Do5iR6B9.css","_app/immutable/assets/Index.BvtIGgFd.css","_app/immutable/assets/Example.DWDv4qx4.css","_app/immutable/assets/Index.BL_HMluy.css","_app/immutable/assets/Index.BijVyRsD.css","_app/immutable/assets/Index.DMaj38-p.css","_app/immutable/assets/Example.DSMNiXnn.css","_app/immutable/assets/Index.CwinLc1f.css","_app/immutable/assets/Walkthrough.CJf9hODv.css","_app/immutable/assets/Index.Ds3FAhOq.css","_app/immutable/assets/Index.Xhg3Ucw_.css","_app/immutable/assets/Index.DP8ihX8q.css","_app/immutable/assets/Example.4NTZ2aku.css","_app/immutable/assets/index.uLojFN0n.css","_app/immutable/assets/Example.D2nbjfVb.css","_app/immutable/assets/Index.C_KfUPPH.css"];
const fonts = [];

export { component, fonts, imports, index, _page_server_ts as server, server_id, stylesheets, universal, universal_id };
//# sourceMappingURL=2-B_-s2cNJ.js.map
