const o="Português",a={annotated_image:"Imagem anotada"},e={allow_recording_access:"Por favor, permita o acesso ao microfone para gravação.",audio:"Áudio",record_from_microphone:"Gravar do microfone",stop_recording:"Parar gravação",no_device_support:"Não é possível aceder a dispositivos de média. Certifique-se de que está a executar numa fonte segura (https) ou localhost (ou passou um certificado SSL válido para ssl_verify), e que permitiu o acesso do navegador ao seu dispositivo.",stop:"Parar",resume:"Retomar",record:"Gravar",no_microphone:"Nenhum microfone encontrado",pause:"Pausar",play:"Reproduzir",waiting:"Aguardando",drop_to_upload:"Solte um arquivo de áudio aqui para fazer upload"},r={connection_can_break:"No telemóvel, a ligação pode ser interrompida se este separador perder o foco ou o dispositivo entrar em modo de suspensão, perdendo a sua posição na fila.",long_requests_queue:"Há uma longa fila de solicitações pendentes. Duplique este Space para saltar a fila.",lost_connection:"Ligação perdida devido à saída da página. A voltar à fila...",waiting_for_inputs:"A aguardar o término do carregamento do(s) ficheiro(s), por favor, tente novamente."},i={checkbox:"Caixa de seleção",checkbox_group:"Grupo de caixas de seleção"},d={code:"Código"},t={color_picker:"Seletor de cor"},s={built_with:"Construído com",built_with_gradio:"Construído com Gradio",clear:"Limpar",download:"Descarregar",edit:"Editar",empty:"Vazio",error:"Erro",hosted_on:"Alojado em",loading:"A carregar",logo:"Logótipo",or:"ou",remove:"Remover",settings:"Configurações",share:"Partilhar",submit:"Enviar",undo:"Desfazer",no_devices:"Nenhum dispositivo encontrado",language:"Idioma",display_theme:"Tema de exibição",pwa:"Aplicação web progressiva"},n={incorrect_format:"Formato incorreto, apenas ficheiros CSV e TSV são suportados",new_column:"Adicionar coluna",new_row:"Nova linha",add_row_above:"Adicionar linha acima",add_row_below:"Adicionar linha abaixo",add_column_left:"Adicionar coluna à esquerda",add_column_right:"Adicionar coluna à direita",delete_row:"Eliminar linha",delete_column:"Eliminar coluna",sort_column:"Ordenar coluna",sort_ascending:"Ordenar por ordem crescente",sort_descending:"Ordenar por ordem decrescente",drop_to_upload:"Solte ficheiros CSV ou TSV aqui para importar dados para o dataframe",clear_sort:"Limpar ordenação",filter:"Filtrar",clear_filter:"Limpar filtros"},c={dropdown:"Lista suspensa"},l={build_error:"Há um erro de compilação",config_error:"Há um erro de configuração",contact_page_author:"Por favor, entre em contacto com o autor da página para informá-lo.",no_app_file:"Não há ficheiro de aplicação",runtime_error:"Há um erro de execução",space_not_working:'"O Space não está a funcionar porque" {0}',space_paused:"O Space está em pausa",use_via_api:"Usar via API",use_via_api_or_mcp:"Usar via API ou MCP"},u={uploading:"A carregar..."},p={highlighted_text:"Texto destacado"},m={allow_webcam_access:"Por favor, permita o acesso à webcam para gravação.",brush_color:"Cor do pincel",brush_radius:"Tamanho do pincel",image:"Imagem",remove_image:"Remover imagem",select_brush_color:"Selecionar cor do pincel",start_drawing:"Começar a desenhar",use_brush:"Usar pincel",drop_to_upload:"Solte um ficheiro de imagem aqui para fazer upload"},_={label:"Rótulo"},g={enable_cookies:"Se estiver a visitar um Space HuggingFace no modo anónimo, precisa de ativar cookies de terceiros.",incorrect_credentials:"Credenciais incorretas",username:"Nome de utilizador",password:"Palavra-passe",login:"Iniciar sessão"},f={number:"Número"},v={plot:"Gráfico"},h={radio:"Botão de opção"},b={slider:"Controlo deslizante"},S={click_to_upload:"Clique para carregar",drop_audio:"Solte o áudio aqui",drop_csv:"Solte o CSV aqui",drop_file:"Solte o ficheiro aqui",drop_image:"Solte a imagem aqui",drop_video:"Solte o vídeo aqui",drop_gallery:"Solte a média aqui",paste_clipboard:"Colar da área de transferência"},w={drop_to_upload:"Solte um ficheiro de vídeo aqui para fazer upload"},q={edit:"Editar",retry:"Tentar novamente",undo:"Desfazer",submit:"Enviar",cancel:"Cancelar",like:"Gosto",dislike:"Não gosto",clear:"Limpar conversa"},C={_name:o,"3D_model":{"3d_model":"Modelo 3D",drop_to_upload:"Solte um arquivo de modelo 3D (.obj, .glb, .stl, .gltf, .splat ou .ply) aqui para fazer upload"},annotated_image:a,audio:e,blocks:r,checkbox:i,code:d,color_picker:t,common:s,dataframe:n,dropdown:c,errors:l,file:u,highlighted_text:p,image:m,label:_,login:g,number:f,plot:v,radio:h,slider:b,upload_text:S,video:w,chatbot:q};export{o as _name,a as annotated_image,e as audio,r as blocks,q as chatbot,i as checkbox,d as code,t as color_picker,s as common,n as dataframe,C as default,c as dropdown,l as errors,u as file,p as highlighted_text,m as image,_ as label,g as login,f as number,v as plot,h as radio,b as slider,S as upload_text,w as video};
