import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import{J as c}from"./JSON-DH989FIX.js";import"./svelte/svelte_svelte.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./prism-python-CpYAgONt.js";import"./i18n-BldJSFLV.js";var v=e.from_html("<div><!></div>");function I(a,r){e.push(r,!1);let o=e.prop(r,"value",12),p=e.prop(r,"theme_mode",12,"system"),u=!1,d=0,l=e.prop(r,"type",12),i=e.prop(r,"selected",12,!1);var f={get value(){return o()},set value(t){o(t),e.flush()},get theme_mode(){return p()},set theme_mode(t){p(t),e.flush()},get type(){return l()},set type(t){l(t),e.flush()},get selected(){return i()},set selected(t){i(t),e.flush()}},m=v();let s;var n=e.child(m);{var h=t=>{c(t,{get value(){return o()},open:!0,get theme_mode(){return p()},show_indices:u,label_height:d,interactive:!1,show_copy_button:!1})};e.if(n,t=>{o()&&t(h)})}return e.reset(m),e.template_effect(()=>s=e.set_class(m,1,"container svelte-19cq9h3",null,s,{table:l()==="table",gallery:l()==="gallery",selected:i(),border:o()})),e.append(a,m),e.pop(f)}export{I as default};
