import{R as i}from"./declarationMapper-CGPHX8aB.js";import{R as s}from"./index-6jOCfdig.js";import{F as a}from"./flowGraphCachedOperationBlock-DGfksfbT.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./KHR_interactivity-DRPs30Rf.js";import"./objectModelMapping-DT0r674A.js";class m extends a{constructor(t){super(i,t),this.config=t,this.object=this.registerDataInput("object",i,t.object),this.propertyName=this.registerDataInput("propertyName",i,t.propertyName),this.customGetFunction=this.registerDataInput("customGetFunction",i)}_doOperation(t){const o=this.customGetFunction.getValue(t);let e;if(o)e=o(this.object.getValue(t),this.propertyName.getValue(t),t);else{const r=this.object.getValue(t),p=this.propertyName.getValue(t);e=r&&p?this._getPropertyValue(r,p):void 0}return e}_getPropertyValue(t,o){const e=o.split(".");let r=t;for(const p of e)if(r=r[p],r===void 0)return;return r}getClassName(){return"FlowGraphGetPropertyBlock"}}s("FlowGraphGetPropertyBlock",m);export{m as FlowGraphGetPropertyBlock};
