div.svelte-siq5d6{display:flex;position:relative;flex-direction:column;gap:var(--layout-gap)}div.svelte-siq5d6>*,div.svelte-siq5d6>.form>*{width:var(--size-full)}.hide.svelte-siq5d6{display:none}.compact.svelte-siq5d6>*,.compact.svelte-siq5d6 .box{border-radius:0}.compact.svelte-siq5d6,.panel.svelte-siq5d6{border:solid var(--panel-border-width) var(--panel-border-color);border-radius:var(--container-radius);background:var(--panel-background-fill);padding:var(--spacing-lg)}
