import{s as r,b as i,a as o,S as m}from"./chunk-DI55MBZ5-CrdRI6SD.js";import{_ as e}from"./mermaid.core-BpC-PC5Q.js";import"./chunk-55IACEB6-DLc0dBUx.js";import"./select-BigU4G0v.js";import"./chunk-QN33PNHL-8fVR_Luc.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./i18n-BldJSFLV.js";import"./step-ChYay-CR.js";import"./dispatch-kxCwF96_.js";var C={parser:o,get db(){return new m(2)},renderer:i,styles:r,init:e(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{C as diagram};
