import{b as o}from"./declarationMapper-CGPHX8aB.js";import{b as u}from"./KHR_interactivity-DRPs30Rf.js";import{R as s}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class n extends u{constructor(t){super(t),this.count=this.registerDataInput("count",o),this.reset=this._registerSignalInput("reset"),this.currentCount=this.registerDataOutput("currentCount",o)}_execute(t,e){if(e===this.reset){t._setExecutionVariable(this,"debounceCount",0);return}const i=this.count.getValue(t),r=t._getExecutionVariable(this,"debounceCount",0)+1;this.currentCount.setValue(r,t),t._setExecutionVariable(this,"debounceCount",r),r>=i&&(this.out._activateSignal(t),t._setExecutionVariable(this,"debounceCount",0))}getClassName(){return"FlowGraphDebounceBlock"}}s("FlowGraphDebounceBlock",n);export{n as FlowGraphDebounceBlock};
