import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var o=e.from_html("<div> </div>");function i(v,l){e.push(l,!1);let r=e.prop(l,"value",12),s=e.prop(l,"type",12),u=e.prop(l,"selected",12,!1);var d={get value(){return r()},set value(t){r(t),e.flush()},get type(){return s()},set type(t){s(t),e.flush()},get selected(){return u()},set selected(t){u(t),e.flush()}},a=o();let p;var f=e.child(a,!0);return e.reset(a),e.template_effect(()=>{p=e.set_class(a,1,"svelte-3guu7e",null,p,{table:s()==="table",gallery:s()==="gallery",selected:u()}),e.set_text(f,r()!==null?r():"")}),e.append(v,a),e.pop(d)}export{i as default};
