import{b as o}from"./declarationMapper-CGPHX8aB.js";import{b as e}from"./KHR_interactivity-DRPs30Rf.js";import{R as s}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class p extends e{constructor(t){super(t),this.count=this.registerDataOutput("count",o),this.reset=this._registerSignalInput("reset")}_execute(t,i){if(i===this.reset){t._setExecutionVariable(this,"count",0),this.count.setValue(0,t);return}const r=t._getExecutionVariable(this,"count",0)+1;t._setExecutionVariable(this,"count",r),this.count.setValue(r,t),this.out._activateSignal(t)}getClassName(){return"FlowGraphCallCounterBlock"}}s("FlowGraphCallCounterBlock",p);export{p as FlowGraphCallCounterBlock};
