import{F as t}from"./KHR_interactivity-DRPs30Rf.js";import{R as i,b as e}from"./declarationMapper-CGPHX8aB.js";import{R as o}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class s extends t{constructor(r){super(r),this.userVariables=this.registerDataOutput("userVariables",i),this.executionId=this.registerDataOutput("executionId",e)}_updateOutputs(r){this.userVariables.setValue(r.userVariables,r),this.executionId.setValue(r.executionId,r)}serialize(r){super.serialize(r)}getClassName(){return"FlowGraphContextBlock"}}o("FlowGraphContextBlock",s);export{s as FlowGraphContextBlock};
