import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var i=e.from_html("<div><pre> </pre></div>");function m(v,l){e.push(l,!1);let r=e.prop(l,"value",12),a=e.prop(l,"type",12),p=e.prop(l,"selected",12,!1);var c={get value(){return r()},set value(t){r(t),e.flush()},get type(){return a()},set type(t){a(t),e.flush()},get selected(){return p()},set selected(t){p(t),e.flush()}},s=i();let u;var d=e.child(s),f=e.child(d,!0);return e.reset(d),e.reset(s),e.template_effect(t=>{u=e.set_class(s,1,"svelte-pj4oi8",null,u,{table:a()==="table",gallery:a()==="gallery",selected:p()}),e.set_text(f,t)},[()=>(e.deep_read_state(r()),e.untrack(()=>JSON.stringify(r(),null,2)))]),e.append(v,s),e.pop(c)}export{m as default};
