import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var O=e.from_html('<table class="svelte-wcwkqi"><tbody><tr class="svelte-wcwkqi"><td class="svelte-wcwkqi">Empty</td></tr></tbody></table>'),P=e.from_html('<td class="svelte-wcwkqi"> </td>'),Q=e.from_html('<td class="svelte-wcwkqi">…</td>'),R=e.from_html('<tr class="svelte-wcwkqi"><!><!></tr>'),S=e.from_html("<div></div>"),T=e.from_html('<table class="svelte-wcwkqi"><tbody></tbody></table> <!>',1),U=e.from_html("<div><!></div>");function X(A,i){e.push(i,!1);let t=e.prop(i,"value",12),n=e.prop(i,"type",12),m=e.prop(i,"selected",12,!1),_=e.prop(i,"index",12),y=e.mutable_source(!1),b=Array.isArray(t()),E=b&&(t().length===0||t()[0].length===0);var j={get value(){return t()},set value(a){t(a),e.flush()},get type(){return n()},set type(a){n(a),e.flush()},get selected(){return m()},set selected(a){m(a),e.flush()},get index(){return _()},set index(a){_(a),e.flush()}};e.init();var w=e.comment(),z=e.first_child(w);{var B=a=>{var r=U();let x;var C=e.child(r);{var D=s=>{var c=e.text();e.template_effect(()=>e.set_text(c,t())),e.append(s,c)},F=s=>{var c=e.comment(),G=e.first_child(c);{var H=d=>{var p=O();e.append(d,p)},I=d=>{var p=T(),u=e.first_child(p),k=e.child(u);e.each(k,5,()=>(e.deep_read_state(t()),e.untrack(()=>t().slice(0,3))),e.index,(o,l)=>{var v=R(),q=e.child(v);e.each(q,1,()=>(e.get(l),e.untrack(()=>e.get(l).slice(0,3))),e.index,(f,h)=>{var g=P(),N=e.child(g,!0);e.reset(g),e.template_effect(()=>e.set_text(N,e.get(h))),e.append(f,g)});var L=e.sibling(q);{var M=f=>{var h=Q();e.append(f,h)};e.if(L,f=>{e.get(l),e.untrack(()=>e.get(l).length>3)&&f(M)})}e.reset(v),e.append(o,v)}),e.reset(k),e.reset(u);var J=e.sibling(u,2);{var K=o=>{var l=S();let v;e.template_effect(()=>v=e.set_class(l,1,"overlay svelte-wcwkqi",null,v,{odd:_()%2!=0,even:_()%2==0,button:n()==="gallery"})),e.append(o,l)};e.if(J,o=>{e.deep_read_state(t()),e.untrack(()=>t().length>3)&&o(K)})}e.append(d,p)};e.if(G,d=>{E?d(H):d(I,!1)},!0)}e.append(s,c)};e.if(C,s=>{typeof t()=="string"?s(D):s(F,!1)})}e.reset(r),e.template_effect(()=>x=e.set_class(r,1,"svelte-wcwkqi",null,x,{table:n()==="table",gallery:n()==="gallery",selected:m()})),e.event("mouseenter",r,()=>e.set(y,!0)),e.event("mouseleave",r,()=>e.set(y,!1)),e.append(a,r)};e.if(z,a=>{b&&a(B)})}return e.append(A,w),e.pop(j)}export{X as default};
