import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var c=e.from_html("<div> </div>");function f(d,r){e.push(r,!1);let l=e.prop(r,"value",12),a=e.prop(r,"type",12),u=e.prop(r,"selected",12,!1);var n={get value(){return l()},set value(t){l(t),e.flush()},get type(){return a()},set type(t){a(t),e.flush()},get selected(){return u()},set selected(t){u(t),e.flush()}};e.init();var s=c();let p;var o=e.child(s,!0);return e.reset(s),e.template_effect(t=>{p=e.set_class(s,1,"svelte-164n2qi",null,p,{table:a()==="table",gallery:a()==="gallery",selected:u()}),e.set_text(o,t)},[()=>(e.deep_read_state(l()),e.untrack(()=>l()!==null?l().toLocaleString():""))]),e.append(d,s),e.pop(n)}export{f as default};
