import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var o=e.from_html("<div> </div>");function m(f,l){e.push(l,!1);let r=e.prop(l,"value",12),s=e.prop(l,"type",12),p=e.prop(l,"selected",12,!1);var v={get value(){return r()},set value(t){r(t),e.flush()},get type(){return s()},set type(t){s(t),e.flush()},get selected(){return p()},set selected(t){p(t),e.flush()}},a=o();let u;var d=e.child(a,!0);return e.reset(a),e.template_effect(()=>{u=e.set_class(a,1,"svelte-9pg6fh",null,u,{table:s()==="table",gallery:s()==="gallery",selected:p()}),e.set_text(d,r()?r():"")}),e.append(f,a),e.pop(v)}export{m as default};
