import{b as t}from"./KHR_interactivity-DRPs30Rf.js";import{R as i}from"./declarationMapper-CGPHX8aB.js";import{R as a}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class r extends t{constructor(o){super(o),this.animationToPause=this.registerDataInput("animationToPause",i)}_execute(o){this.animationToPause.getValue(o).pause(),this.out._activateSignal(o)}getClassName(){return"FlowGraphPauseAnimationBlock"}}a("FlowGraphPauseAnimationBlock",r);export{r as FlowGraphPauseAnimationBlock};
