import{F as e}from"./KHR_interactivity-DRPs30Rf.js";import{R as i}from"./declarationMapper-CGPHX8aB.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./index-6jOCfdig.js";import"./objectModelMapping-DT0r674A.js";class E extends e{constructor(t){super(t),this.config=t,this.executionFunction=this.registerDataInput("function",i),this.value=this.registerDataInput("value",i),this.result=this.registerDataOutput("result",i)}_updateOutputs(t){const r=this.executionFunction.getValue(t),o=this.value.getValue(t);r&&this.result.setValue(r(o,t),t)}getClassName(){return"FlowGraphCodeExecutionBlock"}}export{E as FlowGraphCodeExecutionBlock};
