import{F as s}from"./KHR_interactivity-DRPs30Rf.js";import{q as n,R as i}from"./declarationMapper-CGPHX8aB.js";import{R as u}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class a extends s{constructor(t){super(t),this.functionName=this.registerDataInput("functionName",n),this.object=this.registerDataInput("object",i),this.context=this.registerDataInput("context",i,null),this.output=this.registerDataOutput("output",i)}_updateOutputs(t){const e=this.functionName.getValue(t),r=this.object.getValue(t),p=this.context.getValue(t);if(r&&e){const o=r[e];o&&typeof o=="function"&&this.output.setValue(o.bind(p),t)}}getClassName(){return"FlowGraphFunctionReference"}}u("FlowGraphFunctionReference",a);export{a as FlowGraphFunctionReferenceBlock};
