import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";import"./Index-Ctf4lamg.js";import{I as d}from"./Image-Bdf4wQSw.js";import"./svelte/svelte_svelte.js";import"./i18n-BldJSFLV.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./utils.svelte-Ceck75cM.js";import"./ImagePreview-Cx854cRW.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";import"./ShareButton-DCJS4lh5.js";import"./FullscreenButton-Cqzqqtq6.js";import"./StreamingBar-b2qVLPYU.js";import"./ModifyUpload-BzsLgPw2.js";import"./Example-1lv5JGKJ.js";var c=t.from_html("<div><!></div>");function Q(a,o){t.push(o,!1);let r=t.prop(o,"value",12),p=t.prop(o,"type",12),l=t.prop(o,"selected",12,!1);var s={get value(){return r()},set value(e){r(e),t.flush()},get type(){return p()},set type(e){p(e),t.flush()},get selected(){return l()},set selected(e){l(e),t.flush()}};t.init();var i=c();let m;var u=t.child(i);{let e=t.derived_safe_equal(()=>(t.deep_read_state(r()),t.untrack(()=>r().composite?.url||r().background?.url)));d(u,{get src(){return t.get(e)},alt:""})}return t.reset(i),t.template_effect(()=>m=t.set_class(i,1,"container svelte-ous74z",null,m,{table:p()==="table",gallery:p()==="gallery",selected:l()})),t.append(a,i),t.pop(s)}export{Q as default};
