.gallery.svelte-xz0m7l{padding:var(--size-1) var(--size-2);display:flex;align-items:center;gap:20px;overflow-x:auto}div.svelte-xz0m7l{overflow:hidden;min-width:var(--local-text-width);white-space:nowrap}.container.svelte-xz0m7l img,.container.svelte-xz0m7l video{object-fit:contain;width:100px;height:100px}.container.selected.svelte-xz0m7l{border-color:var(--border-color-accent)}.border.table.svelte-xz0m7l{border:2px solid var(--border-color-primary)}.container.table.svelte-xz0m7l{margin:0 auto;border-radius:var(--radius-lg);overflow-x:auto;width:max-content;height:max-content;object-fit:cover;padding:var(--size-2)}.container.gallery.svelte-xz0m7l{object-fit:cover}div.svelte-xz0m7l>p{font-size:var(--text-lg);white-space:normal}
