import{GLTFLoader as m}from"./glTFLoader-Bx351I09.js";import{aN as d,aO as l}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./bone-DdTyU8i_.js";import"./skeleton-C0c5yg7x.js";import"./rawTexture-CpjOe2U7.js";import"./assetContainer-Drc86vic.js";import"./objectModelMapping-DT0r674A.js";const i="KHR_materials_ior";class e{constructor(r){this.name=i,this.order=180,this._loader=r,this.enabled=this._loader.isExtensionUsed(i)}dispose(){this._loader=null}loadMaterialPropertiesAsync(r,o,t){return m.LoadExtensionAsync(r,o,this.name,async(s,p)=>{const a=new Array;return a.push(this._loader.loadMaterialPropertiesAsync(r,o,t)),a.push(this._loadIorPropertiesAsync(s,p,t)),await Promise.all(a).then(()=>{})})}_loadIorPropertiesAsync(r,o,t){const s=this._loader._getOrCreateMaterialAdapter(t),p=o.ior!==void 0?o.ior:e._DEFAULT_IOR;return s.specularIor=p,Promise.resolve()}}e._DEFAULT_IOR=1.5;d(i);l(i,!0,n=>new e(n));export{e as KHR_materials_ior};
