import{_ as r}from"./mermaid.core-BN1TdaiK-CkX93Jpj.js";var t,e=(t=class{constructor(i){this.init=i,this.records=this.init()}reset(){this.records=this.init()}},r(t,"ImperativeState"),t);export{e as I};
