import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var d=e.from_html("<div></div>");function n(o,l){e.push(l,!1);let s=e.prop(l,"value",12),a=e.prop(l,"type",12),r=e.prop(l,"selected",12,!1);var c={get value(){return s()},set value(t){s(t),e.flush()},get type(){return a()},set type(t){a(t),e.flush()},get selected(){return r()},set selected(t){r(t),e.flush()}},u=d();let p;return e.template_effect(()=>{e.set_style(u,`background-color: ${(s()?s():"black")??""}`),p=e.set_class(u,1,"svelte-1k1s8qu",null,p,{table:a()==="table",gallery:a()==="gallery",selected:r()})}),e.append(o,u),e.pop(c)}export{n as default};
