import{G as e,U as n,a as m}from"./environmentTextureTools-CmnD6g13.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./index-6jOCfdig.js";import"./dumpTools-DaCMxSuy.js";class R{constructor(){this.supportCascades=!1}loadCubeData(r,o,l,a,t){if(Array.isArray(r))return;const i=e(r);if(i){o.width=i.width,o.height=i.width;try{n(o,i),m(o,r,i).then(()=>{o.isReady=!0,o.onLoadedObservable.notifyObservers(o),o.onLoadedObservable.clear(),a&&a()},p=>{t?.("Can not upload environment levels",p)})}catch(p){t?.("Can not upload environment file",p)}}else t&&t("Can not parse the environment file",null)}loadData(){throw".env not supported in 2d."}}export{R as _ENVTextureLoader};
