import{R as e}from"./index-6jOCfdig.js";import{b as o,g as a}from"./KHR_interactivity-DRPs30Rf.js";import{i as l}from"./declarationMapper-CGPHX8aB.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class p extends o{constructor(i){super(i),this.delayIndex=this.registerDataInput("delayIndex",l)}_execute(i,s){const t=a(this.delayIndex.getValue(i));if(t<=0||isNaN(t)||!isFinite(t))return this._reportError(i,"Invalid delay index");const r=i._getGlobalContextVariable("pendingDelays",[])[t];r&&r.dispose(),this.out._activateSignal(i)}getClassName(){return"FlowGraphCancelDelayBlock"}}e("FlowGraphCancelDelayBlock",p);export{p as FlowGraphCancelDelayBlock};
