import{a as f,aN as e,aO as d}from"./index-6jOCfdig.js";import{GLTFLoader as c}from"./glTFLoader-Bx351I09.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./bone-DdTyU8i_.js";import"./skeleton-C0c5yg7x.js";import"./rawTexture-CpjOe2U7.js";import"./assetContainer-Drc86vic.js";import"./objectModelMapping-DT0r674A.js";const i="KHR_texture_transform";class n{constructor(o){this.name=i,this._loader=o,this.enabled=this._loader.isExtensionUsed(i)}dispose(){this._loader=null}loadTextureInfoAsync(o,m,p){return c.LoadExtensionAsync(o,m,this.name,async(a,t)=>await this._loader.loadTextureInfoAsync(o,m,r=>{if(!(r instanceof f))throw new Error(`${a}: Texture type not supported`);t.offset&&(r.uOffset=t.offset[0],r.vOffset=t.offset[1]),r.uRotationCenter=0,r.vRotationCenter=0,t.rotation&&(r.wAng=-t.rotation),t.scale&&(r.uScale=t.scale[0],r.vScale=t.scale[1]),t.texCoord!=null&&(r.coordinatesIndex=t.texCoord),p(r)}))}}e(i);d(i,!0,s=>new n(s));export{n as KHR_texture_transform};
