const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./PlotlyPlot-DKi1wL4-.js","./i18n-BldJSFLV.js","./index-Ds2meNS5.js","./index-W6UN98iO.css","./i18n-taskS9xY.css","./BokehPlot-CQwc2eUt.js","./BokehPlot-DTqQzqHn.css","./MatplotlibPlot-DssSmJBB.js","./MatplotlibPlot-DvS6m0KD.css","./AltairPlot-3RRJDXTo.js","./color-_dydYF3w.js","./mollweide-BhZ4OpW6.js","./ordinal-BeghXfj9.js","./init-Dmth1JHB.js","./linear-CM32Lqs5.js","./step-ChYay-CR.js","./defaultLocale-CNpUPyHh.js","./time-CCMAgbNn.js","./dispatch-kxCwF96_.js","./range-OtVwhkKS.js","./index-BU4IRnz1.js","./colors-Cc3OSVma.js","./dsv-DB8NKgIY.js","./arc-CSo4ybba.js","./AltairPlot-Dp2S7wtT.css"])))=>i.map(i=>d[i]);
import{_ as i}from"./index-Ds2meNS5.js";import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";import{E as k,P as T}from"./IconButtonWrapper-Cljb5D-5.js";import"./svelte/svelte_internal_flags_legacy.js";import{untrack as x}from"./svelte/svelte_svelte.js";import"./i18n-BldJSFLV.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";function U(f,o){t.push(o,!0);let r=t.state(null),n=t.state(!1),a=t.state(0);const u={plotly:()=>i(()=>import("./PlotlyPlot-DKi1wL4-.js"),__vite__mapDeps([0,1,2,3,4]),import.meta.url),bokeh:()=>i(()=>import("./BokehPlot-CQwc2eUt.js"),__vite__mapDeps([5,6]),import.meta.url),matplotlib:()=>i(()=>import("./MatplotlibPlot-DssSmJBB.js"),__vite__mapDeps([7,8]),import.meta.url),altair:()=>i(()=>import("./AltairPlot-3RRJDXTo.js"),__vite__mapDeps([9,1,2,3,4,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24]),import.meta.url)};let m={};const g=typeof window<"u";let s=t.state(null);t.user_effect(()=>{let e=o.value?.type;x(()=>{t.set(a,t.get(a)+1),e!==t.get(s)&&t.set(r,null),e&&e in u&&g&&(m[e]?t.set(r,m[e],!0):u[e]().then(l=>{t.set(r,l.default,!0),m[e]=t.get(r)})),t.set(s,e,!0)}),o.on_change()});var p=t.comment(),v=t.first_child(p);{var h=e=>{var l=t.comment(),d=t.first_child(l);t.key(d,()=>t.get(a),y=>{var c=t.comment(),P=t.first_child(c);t.component(P,()=>t.get(r),(E,w)=>{w(E,{get value(){return o.value},colors:[],get theme_mode(){return o.theme_mode},get show_label(){return o.show_label},get caption(){return o.caption},get bokeh_version(){return o.bokeh_version},get show_actions_button(){return o.show_actions_button},get _selectable(){return o._selectable},get x_lim(){return o.x_lim},get loaded_plotly_css(){return t.get(n)},set loaded_plotly_css(_){t.set(n,_,!0)},$$events:{select(_){t.bubble_event.call(this,o,_)}}})}),t.append(y,c)}),t.append(e,l)},b=e=>{k(e,{unpadded_box:!0,size:"large",children:(l,d)=>{T(l)},$$slots:{default:!0}})};t.if(v,e=>{o.value&&t.get(r)?e(h):e(b,!1)})}t.append(f,p),t.pop()}export{U as default};
