import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import{G as w}from"./utils.svelte-Ceck75cM.js";import k from"./Plot-pymRqmhz.js";import{B,b as P,P as x,c as I}from"./IconButtonWrapper-Cljb5D-5.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_svelte.js";import{F}from"./FullscreenButton-Cqzqqtq6.js";import{S as G}from"./StreamingBar-b2qVLPYU.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";var S=t.from_html("<!> <!> <!> <!>",1);function oe(c,a){t.push(a,!0);let d=t.rest_props(a,["$$slots","$$events","$$legacy"]);const e=new w(d);let o=t.state(!1);B(c,{padding:!1,get elem_id(){return e.shared.elem_id},get elem_classes(){return e.shared.elem_classes},get visible(){return e.shared.visible},get container(){return e.shared.container},get scale(){return e.shared.scale},get min_width(){return e.shared.min_width},allow_overflow:!1,get fullscreen(){return t.get(o)},set fullscreen(s){t.set(o,s,!0)},children:(s,y)=>{var i=S(),p=t.first_child(i);{let r=t.derived(()=>e.shared.label||e.i18n("plot.plot"));P(p,{get show_label(){return e.shared.show_label},get label(){return t.get(r)},get Icon(){return x}})}var u=t.sibling(p,2);{var g=r=>{{let f=t.derived(()=>e.props.buttons??[]);I(r,{get buttons(){return t.get(f)},on_custom_button_click:l=>{e.dispatch("custom_button_click",{id:l})},children:(l,L)=>{var m=t.comment(),b=t.first_child(m);{var v=n=>{F(n,{get fullscreen(){return t.get(o)},$$events:{fullscreen:({detail:$})=>{t.set(o,$,!0)}}})};t.if(b,n=>{e.props.show_fullscreen_button&&n(v)})}t.append(l,m)},$$slots:{default:!0}})}};t.if(u,r=>{(e.props.buttons&&e.props.buttons.length>0||e.props.show_fullscreen_button)&&r(g)})}var _=t.sibling(u,2);G(_,t.spread_props({get autoscroll(){return e.shared.autoscroll},get i18n(){return e.i18n}},()=>e.shared.loading_status,{on_clear_status:()=>e.dispatch("clear_status",e.shared.loading_status)}));var h=t.sibling(_,2);k(h,{get value(){return e.props.value},get theme_mode(){return e.props.theme_mode},get show_label(){return e.shared.show_label},get caption(){return e.props.caption},get bokeh_version(){return e.props.bokeh_version},get show_actions_button(){return e.props.show_actions_button},get _selectable(){return e.props._selectable},get x_lim(){return e.props.x_lim},get show_fullscreen_button(){return e.props.show_fullscreen_button},on_change:()=>e.dispatch("change")}),t.append(s,i)},$$slots:{default:!0}}),t.pop()}export{k as BasePlot,oe as default};
