label.svelte-16ty2ow:not(.container),label.svelte-16ty2ow:not(.container)>input:where(.svelte-16ty2ow){height:100%;border:none}.container.svelte-16ty2ow>input:where(.svelte-16ty2ow){border:var(--input-border-width) solid var(--input-border-color);border-radius:var(--input-radius)}input[type=number].svelte-16ty2ow{display:block;position:relative;outline:none!important;box-shadow:var(--input-shadow);background:var(--input-background-fill);padding:var(--input-padding);width:100%;color:var(--body-text-color);font-size:var(--input-text-size);line-height:var(--line-sm)}input.svelte-16ty2ow:disabled{-webkit-text-fill-color:var(--body-text-color);-webkit-opacity:1;opacity:1}input.svelte-16ty2ow:focus{box-shadow:var(--input-shadow-focus);border-color:var(--input-border-color-focus);background:var(--input-background-fill-focus)}input.svelte-16ty2ow::placeholder{color:var(--input-placeholder-color)}input.svelte-16ty2ow:out-of-range{border:var(--input-border-width) solid var(--error-border-color)}div.validation-error.svelte-16ty2ow{color:var(--error-icon-color);font-size:var(--font-sans);margin-top:var(--spacing-sm);font-weight:var(--weight-semibold)}label.container.svelte-16ty2ow input.validation-error:where(.svelte-16ty2ow){border-color:transparent!important;box-shadow:0 0 3px 1px var(--error-icon-color),var(--shadow-inset)!important}
