h2.svelte-xaoy31{display:flex;color:var(--body-text-color);font-weight:var(--weight-semibold);font-size:var(--text-xl);gap:var(--size-3)}h2.svelte-xaoy31 img:where(.svelte-xaoy31){width:var(--size-4);display:inline-block;margin-top:.1rem}.url.svelte-xaoy31{color:var(--color-accent);font-weight:400}button.svelte-xaoy31{position:absolute;top:var(--size-5);right:var(--size-6);width:var(--size-4);color:var(--body-text-color)}button.svelte-xaoy31:hover{color:var(--color-accent)}@media(min-width:768px){button.svelte-xaoy31{top:var(--size-6)}h2.svelte-xaoy31 img:where(.svelte-xaoy31){width:var(--size-5)}}.title.svelte-xaoy31{display:flex;flex-direction:row;gap:.5rem}.banner-wrap.svelte-1t60wb3{position:relative;border-bottom:1px solid var(--border-color-primary);padding:var(--size-4) var(--size-6);font-size:var(--text-md)}.banner-wrap.svelte-1t60wb3 h2:where(.svelte-1t60wb3){font-size:var(--text-xl)}a.svelte-1t60wb3{text-decoration:underline}p.padded.svelte-1t60wb3{padding:15px 0}.theme-buttons.svelte-1t60wb3{display:flex;align-items:center}.theme-buttons.svelte-1t60wb3>:where(.svelte-1t60wb3)+:where(.svelte-1t60wb3){margin-left:var(--size-2)}.theme-button.svelte-1t60wb3,.record-button.svelte-1t60wb3{display:flex;align-items:center;border:1px solid var(--border-color-primary);border-radius:var(--radius-md);padding:var(--size-2) var(--size-2-5);line-height:1;user-select:none;text-transform:capitalize;cursor:pointer}.record-button.svelte-1t60wb3 img:where(.svelte-1t60wb3){margin-right:var(--size-1);margin-left:var(--size-1);width:var(--size-3)}.record-button.svelte-1t60wb3:hover{border-color:red}.current-theme.svelte-1t60wb3{border:1px solid var(--body-text-color-subdued);color:var(--body-text-color)}.inactive-theme.svelte-1t60wb3{color:var(--body-text-color-subdued)}.inactive-theme.svelte-1t60wb3:hover,.inactive-theme.svelte-1t60wb3:focus{box-shadow:var(--shadow-drop);color:var(--body-text-color)}.theme-button.svelte-1t60wb3 button:where(.svelte-1t60wb3){all:unset;cursor:pointer}.beta-tag.svelte-1t60wb3{position:relative;top:-5px;font-size:var(--text-xs);background-color:var(--color-accent);color:#fff;padding:2px 6px;border-radius:10px;margin-left:5px;font-weight:400;text-transform:uppercase}
