import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import{B as a}from"./IconButtonWrapper-Cljb5D-5.js";import"./svelte/svelte_svelte.js";import"./i18n-BldJSFLV.js";import"./MarkdownCode-C2b9iIxl.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./prism-python-CpYAgONt.js";function E(s,r){e.push(r,!1);let i=e.prop(r,"elem_id",12),l=e.prop(r,"elem_classes",12),m=e.prop(r,"visible",12,!0);var p={get elem_id(){return i()},set elem_id(t){i(t),e.flush()},get elem_classes(){return l()},set elem_classes(t){l(t),e.flush()},get visible(){return m()},set visible(t){m(t),e.flush()}};return a(s,{get elem_id(){return i()},get elem_classes(){return l()},get visible(){return m()},explicit_call:!0,children:(t,n)=>{var o=e.comment(),u=e.first_child(o);e.slot(u,r,"default",{},null),e.append(t,o)},$$slots:{default:!0}}),e.pop(p)}export{E as default};
