import{F as e,i as o}from"./declarationMapper-CGPHX8aB.js";import{b as s}from"./KHR_interactivity-DRPs30Rf.js";import{R as a}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class p extends s{constructor(t={}){super(t),this.config=t,this.config.startIndex=t.startIndex??new e(0),this.reset=this._registerSignalInput("reset"),this.maxExecutions=this.registerDataInput("maxExecutions",o),this.executionCount=this.registerDataOutput("executionCount",o,new e(0))}_execute(t,r){if(r===this.reset)this.executionCount.setValue(this.config.startIndex,t);else{const i=this.executionCount.getValue(t);i.value<this.maxExecutions.getValue(t).value&&(this.executionCount.setValue(new e(i.value+1),t),this.out._activateSignal(t))}}getClassName(){return"FlowGraphDoNBlock"}}a("FlowGraphDoNBlock",p);export{p as FlowGraphDoNBlock};
