div.svelte-1p04unr{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.gallery.svelte-1p04unr{display:flex;align-items:center;cursor:pointer;padding:var(--size-1) var(--size-2);text-align:left}
