.wrap.svelte-ulqlw7{position:relative;height:var(--size-64);width:var(--size-40);overflow:hidden;border-radius:var(--radius-lg)}img.svelte-ulqlw7{height:var(--size-64);width:var(--size-40);position:absolute;object-fit:cover}.wrap.selected.svelte-ulqlw7{border-color:var(--color-accent)}.wrap.svelte-ulqlw7 img:where(.svelte-ulqlw7):first-child{clip-path:inset(0 50% 0 0%)}.wrap.svelte-ulqlw7 img:where(.svelte-ulqlw7):nth-of-type(2){clip-path:inset(0 0 0 50%)}span.svelte-ulqlw7{position:absolute;top:0;left:calc(50% - .75px);height:var(--size-64);width:1.5px;background:var(--border-color-primary)}.table.svelte-ulqlw7{margin:0 auto;border:2px solid var(--border-color-primary);border-radius:var(--radius-lg)}.gallery.svelte-ulqlw7{border:2px solid var(--border-color-primary);object-fit:cover}
