.model3D.svelte-pnaihf{display:flex;position:relative;width:var(--size-full);height:var(--size-full);border-radius:var(--block-radius);overflow:hidden}.model3D.svelte-pnaihf canvas{width:var(--size-full);height:var(--size-full);object-fit:contain;overflow:hidden}
