import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import{M as h}from"./MarkdownCode-C2b9iIxl.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./prism-python-CpYAgONt.js";import"./i18n-BldJSFLV.js";var v=e.from_html("<div><!></div>");function K(_,r){e.push(r,!1);let l=e.prop(r,"value",12),i=e.prop(r,"type",12),a=e.prop(r,"selected",12,!1),m=e.prop(r,"sanitize_html",12),o=e.prop(r,"line_breaks",12),n=e.prop(r,"latex_delimiters",12);function f(t,d=60){if(!t)return"";const p=String(t);return p.length<=d?p:p.slice(0,d)+"..."}var c={get value(){return l()},set value(t){l(t),e.flush()},get type(){return i()},set type(t){i(t),e.flush()},get selected(){return a()},set selected(t){a(t),e.flush()},get sanitize_html(){return m()},set sanitize_html(t){m(t),e.flush()},get line_breaks(){return o()},set line_breaks(t){o(t),e.flush()},get latex_delimiters(){return n()},set latex_delimiters(t){n(t),e.flush()}},s=v();let u;var g=e.child(s);{let t=e.derived_safe_equal(()=>(e.deep_read_state(l()),e.untrack(()=>f(l()))));h(g,{get message(){return e.get(t)},get latex_delimiters(){return n()},get sanitize_html(){return m()},get line_breaks(){return o()},chatbot:!1})}return e.reset(s),e.template_effect(()=>u=e.set_class(s,1,"prose svelte-11ua876",null,u,{table:i()==="table",gallery:i()==="gallery",selected:a()})),e.append(_,s),e.pop(c)}export{K as default};
