import"./svelte/svelte_internal_flags_async.js";import*as t from"./svelte/svelte_internal_client.js";var r=t.from_html('<div class="matplotlib layout svelte-n8pych"><img class="svelte-n8pych"/></div>');function p(i,a){t.push(a,!0);let o=t.derived(()=>a.value?.plot);var e=r();t.set_attribute(e,"data-testid","matplotlib");var l=t.child(e);t.reset(e),t.template_effect(()=>{t.set_attribute(l,"src",t.get(o)),t.set_attribute(l,"alt",`${a.value.chart} plot visualising provided data`)}),t.append(i,e),t.pop()}export{p as default};
