import{_ as a,e as w,l as u}from"./mermaid.core-BN1TdaiK-CkX93Jpj.js";var B=a((e,t,o,i)=>{e.attr("class",o);const{width:r,height:h,x:s,y:c}=x(e,t);w(e,h,r,i);const n=l(s,c,r,h,t);e.attr("viewBox",n),u.debug(`viewBox configured: ${n} with padding: ${t}`)},"setupViewPortForSVG"),x=a((e,t)=>{var o;const i=((o=e.node())==null?void 0:o.getBBox())||{width:0,height:0,x:0,y:0};return{width:i.width+t*2,height:i.height+t*2,x:i.x,y:i.y}},"calculateDimensionsWithPadding"),l=a((e,t,o,i,r)=>`${e-r} ${t-r} ${o} ${i}`,"createViewBox");export{B as s};
