import{aN as i,aO as a}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";const o="KHR_xmp_json_ld";class n{constructor(t){this.name=o,this.order=100,this._loader=t,this.enabled=this._loader.isExtensionUsed(o)}dispose(){this._loader=null}onLoading(){if(this._loader.rootBabylonMesh===null)return;const t=this._loader.gltf.extensions?.KHR_xmp_json_ld,e=this._loader.gltf.asset?.extensions?.KHR_xmp_json_ld;if(t&&e){const r=+e.packet;t.packets&&r<t.packets.length&&(this._loader.rootBabylonMesh.metadata=this._loader.rootBabylonMesh.metadata||{},this._loader.rootBabylonMesh.metadata.xmp=t.packets[r])}}}i(o);a(o,!0,s=>new n(s));export{n as KHR_xmp_json_ld};
