button.svelte-xzq5jh,a.svelte-xzq5jh{display:inline-flex;justify-content:center;align-items:center;transition:var(--button-transition);padding:var(--size-0-5) var(--size-2);text-align:center}button.svelte-xzq5jh:hover{transform:var(--button-transform-hover)}button.svelte-xzq5jh:active,a.svelte-xzq5jh:active{transform:var(--button-transform-active)}button[disabled].svelte-xzq5jh,a.disabled.svelte-xzq5jh{opacity:.5;filter:grayscale(30%);cursor:not-allowed;transform:none}.hidden.svelte-xzq5jh{display:none}.primary.svelte-xzq5jh{border:var(--button-border-width) solid var(--button-primary-border-color);background:var(--button-primary-background-fill);color:var(--button-primary-text-color);box-shadow:var(--button-primary-shadow)}.primary.svelte-xzq5jh:hover,.primary[disabled].svelte-xzq5jh{background:var(--button-primary-background-fill-hover);color:var(--button-primary-text-color-hover)}.primary.svelte-xzq5jh:hover{border-color:var(--button-primary-border-color-hover);box-shadow:var(--button-primary-shadow-hover)}.primary.svelte-xzq5jh:active{box-shadow:var(--button-primary-shadow-active)}.primary[disabled].svelte-xzq5jh{border-color:var(--button-primary-border-color)}.secondary.svelte-xzq5jh{border:var(--button-border-width) solid var(--button-secondary-border-color);background:var(--button-secondary-background-fill);color:var(--button-secondary-text-color);box-shadow:var(--button-secondary-shadow)}.secondary.svelte-xzq5jh:hover,.secondary[disabled].svelte-xzq5jh{background:var(--button-secondary-background-fill-hover);color:var(--button-secondary-text-color-hover)}.secondary.svelte-xzq5jh:hover{border-color:var(--button-secondary-border-color-hover);box-shadow:var(--button-secondary-shadow-hover)}.secondary.svelte-xzq5jh:active{box-shadow:var(--button-secondary-shadow-active)}.secondary[disabled].svelte-xzq5jh{border-color:var(--button-secondary-border-color)}.stop.svelte-xzq5jh{background:var(--button-cancel-background-fill);color:var(--button-cancel-text-color);border:var(--button-border-width) solid var(--button-cancel-border-color);box-shadow:var(--button-cancel-shadow)}.stop.svelte-xzq5jh:hover,.stop[disabled].svelte-xzq5jh{background:var(--button-cancel-background-fill-hover)}.stop.svelte-xzq5jh:hover{border-color:var(--button-cancel-border-color-hover);box-shadow:var(--button-cancel-shadow-hover)}.stop.svelte-xzq5jh:active{box-shadow:var(--button-cancel-shadow-active)}.stop[disabled].svelte-xzq5jh{border-color:var(--button-cancel-border-color)}.sm.svelte-xzq5jh{border-radius:var(--button-small-radius);padding:var(--button-small-padding);font-weight:var(--button-small-text-weight);font-size:var(--button-small-text-size)}.md.svelte-xzq5jh{border-radius:var(--button-medium-radius);padding:var(--button-medium-padding);font-weight:var(--button-medium-text-weight);font-size:var(--button-medium-text-size)}.lg.svelte-xzq5jh{border-radius:var(--button-large-radius);padding:var(--button-large-padding);font-weight:var(--button-large-text-weight);font-size:var(--button-large-text-size)}.button-icon{width:var(--text-xl);height:var(--text-xl)}.button-icon.right-padded{margin-right:var(--spacing-md)}.huggingface.svelte-xzq5jh{background:#141c2e;color:#fff}.huggingface.svelte-xzq5jh:hover{background:#283042;color:#fff}
