const o="हिंदी",e={annotated_image:"एनोटेट की गई छवि"},r={allow_recording_access:"कृपया रिकॉर्डिंग के लिए माइक्रोफ़ोन एक्सेस की अनुमति दें।",audio:"ऑडियो",record_from_microphone:"माइक्रोफ़ोन से रिकॉर्ड करें",stop_recording:"रिकॉर्डिंग रोकें",no_device_support:"मीडिया डिवाइस तक पहुंच नहीं हो सकी। सुनिश्चित करें कि आप एक सुरक्षित स्रोत (https) या localhost पर चल रहे हैं (या ssl_verify को एक वैध SSL प्रमाणपत्र दिया है), और आपने अपने ब्राउज़र को अपने डिवाइस तक पहुंच की अनुमति दी है।",stop:"रोकें",resume:"जारी रखें",record:"रिकॉर्ड",no_microphone:"कोई माइक्रोफ़ोन नहीं मिला",pause:"रोकें",play:"चलाएं",waiting:"प्रतीक्षा कर रहा है",drop_to_upload:"यहाँ एक ऑडियो फाइल डालें अपलोड करने के लिए"},t={connection_can_break:"मोबाइल पर, यदि यह टैब फोकस खो देता है या डिवाइस स्लीप मोड में चला जाता है, तो कनेक्शन टूट सकता है, जिससे कतार में आपका स्थान खो जाएगा।",long_requests_queue:"लंबित अनुरोधों की एक लंबी कतार है। इसे छोड़ने के लिए इस Space को डुप्लिकेट करें।",lost_connection:"पेज छोड़ने के कारण कनेक्शन टूट गया। कतार में वापस जा रहा है...",waiting_for_inputs:"फाइलें अपलोड होने का इंतजार कर रहे हैं, कृपया पुन: प्रयास करें।"},c={checkbox:"चेकबॉक्स",checkbox_group:"चेकबॉक्स समूह"},_={code:"कोड"},a={color_picker:"रंग चयनकर्ता"},n={built_with:"के साथ बनाया गया",built_with_gradio:"Gradio के साथ बनाया गया",clear:"साफ़ करें",download:"डाउनलोड",edit:"संपादित करें",empty:"खाली",error:"त्रुटि",hosted_on:"पर होस्ट किया गया",loading:"लोड हो रहा है",logo:"लोगो",or:"या",remove:"हटाएं",settings:"सेटिंग्स",share:"साझा करें",submit:"सबमिट करें",undo:"पूर्ववत करें",no_devices:"कोई डिवाइस नहीं मिला",language:"भाषा",display_theme:"प्रदर्शन थीम",pwa:"प्रोग्रेसिव वेब ऐप"},s={incorrect_format:"गलत प्रारूप, केवल CSV और TSV फ़ाइलें समर्थित हैं",new_column:"कॉलम जोड़ें",new_row:"नई पंक्ति",add_row_above:"ऊपर पंक्ति जोड़ें",add_row_below:"नीचे पंक्ति जोड़ें",add_column_left:"बाएं कॉलम जोड़ें",add_column_right:"दाएं कॉलम जोड़ें",delete_row:"पंक्ति हटाएं",delete_column:"कॉलम हटाएं",sort_column:"कॉलम को क्रमबद्ध करें",sort_ascending:"आरोही क्रम में क्रमबद्ध करें",sort_descending:"अवरोही क्रम में क्रमबद्ध करें",drop_to_upload:"यहाँ CSV या TSV फाइलें ड्रॉप करें ताकि डेटा डेटाफ़्रेम में आयात किया जा सके",clear_sort:"क्रमबद्धता हटाएं"},d={dropdown:"ड्रॉपडाउन"},i={build_error:"एक बिल्ड त्रुटि है",config_error:"एक कॉन्फ़िगरेशन त्रुटि है",contact_page_author:"कृपया पेज के लेखक को सूचित करने के लिए संपर्क करें।",no_app_file:"कोई ऐप फ़ाइल नहीं है",runtime_error:"एक रनटाइम त्रुटि है",space_not_working:'"Space काम नहीं कर रहा है क्योंकि" {0}',space_paused:"Space रोका गया है",use_via_api:"API के माध्यम से उपयोग करें"},l={uploading:"अपलोड हो रहा है..."},p={highlighted_text:"हाइलाइट किया गया टेक्स्ट"},u={allow_webcam_access:"कृपया रिकॉर्डिंग के लिए वेबकैम एक्सेस की अनुमति दें।",brush_color:"ब्रश का रंग",brush_radius:"ब्रश का आकार",image:"छवि",remove_image:"छवि हटाएं",select_brush_color:"ब्रश का रंग चुनें",start_drawing:"चित्रकारी शुरू करें",use_brush:"ब्रश का उपयोग करें",drop_to_upload:"यहाँ एक छवि फाइल डालें अपलोड करने के लिए"},g={label:"लेबल"},m={enable_cookies:"यदि आप इनकॉग्निटो मोड में HuggingFace Space का दौरा कर रहे हैं, तो आपको थर्ड-पार्टी कुकीज़ को सक्षम करना होगा।",incorrect_credentials:"गलत क्रेडेंशियल्स",username:"उपयोगकर्ता नाम",password:"पासवर्ड",login:"लॉग इन करें"},b={number:"संख्या"},h={plot:"प्लॉट"},w={radio:"रेडियो बटन"},f={slider:"स्लाइडर"},k={click_to_upload:"अपलोड करने के लिए क्लिक करें",drop_audio:"ऑडियो यहाँ छोड़ें",drop_csv:"CSV फाइल यहाँ छोड़ें",drop_file:"फ़ाइल यहाँ छोड़ें",drop_image:"छवि यहाँ छोड़ें",drop_video:"वीडियो यहाँ छोड़ें",drop_gallery:"मीडिया यहाँ छोड़ें",paste_clipboard:"क्लिपबोर्ड से पेस्ट करें"},S={drop_to_upload:"यहाँ एक वीडियो फाइल डालें अपलोड करने के लिए"},v={edit:"संपादित करें",retry:"पुनः प्रयास करें",undo:"वापस लें",submit:"भेजें",cancel:"रद्द करें",like:"पसंद",dislike:"नापसंद",clear:"चैट साफ़ करें"},x={_name:o,"3D_model":{"3d_model":"3D मॉडल",drop_to_upload:"यहाँ 3D मॉडल (.obj, .glb, .stl, .gltf, .splat, या .ply) फ़ाइल ड्रॉप करें अपलोड करने के लिए"},annotated_image:e,audio:r,blocks:t,checkbox:c,code:_,color_picker:a,common:n,dataframe:s,dropdown:d,errors:i,file:l,highlighted_text:p,image:u,label:g,login:m,number:b,plot:h,radio:w,slider:f,upload_text:k,video:S,chatbot:v};export{o as _name,e as annotated_image,r as audio,t as blocks,v as chatbot,c as checkbox,_ as code,a as color_picker,n as common,s as dataframe,x as default,d as dropdown,i as errors,l as file,p as highlighted_text,u as image,g as label,m as login,b as number,h as plot,w as radio,f as slider,k as upload_text,S as video};
