import{b as r}from"./KHR_interactivity-DRPs30Rf.js";import{R as p}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./declarationMapper-CGPHX8aB.js";import"./objectModelMapping-DT0r674A.js";class a extends r{constructor(t){super(t),this.config=t;for(const o in this.config.eventData)this.registerDataInput(o,this.config.eventData[o].type,this.config.eventData[o].value)}_execute(t){const o=this.config.eventId,i={};for(const e of this.dataInputs)i[e.name]=e.getValue(t);t.configuration.coordinator.notifyCustomEvent(o,i),this.out._activateSignal(t)}getClassName(){return"FlowGraphReceiveCustomEventBlock"}}p("FlowGraphReceiveCustomEventBlock",a);export{a as FlowGraphSendCustomEventBlock};
