import{GLTFLoader as e,ArrayItem as s}from"./glTFLoader-Bx351I09.js";import{aN as u,aO as _}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./bone-DdTyU8i_.js";import"./skeleton-C0c5yg7x.js";import"./rawTexture-CpjOe2U7.js";import"./assetContainer-Drc86vic.js";import"./objectModelMapping-DT0r674A.js";const o="EXT_texture_avif";class c{constructor(r){this.name=o,this._loader=r,this.enabled=r.isExtensionUsed(o)}dispose(){this._loader=null}_loadTextureAsync(r,t,m){return e.LoadExtensionAsync(r,t,this.name,async(a,p)=>{const n=t.sampler==null?e.DefaultSampler:s.Get(`${r}/sampler`,this._loader.gltf.samplers,t.sampler),l=s.Get(`${a}/source`,this._loader.gltf.images,p.source);return await this._loader._createTextureAsync(r,n,l,d=>{m(d)},void 0,!t._textureInfo.nonColorData)})}}u(o);_(o,!0,i=>new c(i));export{c as EXT_texture_avif};
