import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";var A=e.from_html("<li><code> </code></li>"),b=e.from_html('<li class="extra svelte-14aa7hi">...</li>'),k=e.from_html("<!> <!>",1),E=e.from_html("<ul><!></ul>");function w(u,l){e.push(l,!1);let t=e.prop(l,"value",12),s=e.prop(l,"type",12),o=e.prop(l,"selected",12,!1);var _={get value(){return t()},set value(r){t(r),e.flush()},get type(){return s()},set type(r){s(r),e.flush()},get selected(){return o()},set selected(r){o(r),e.flush()}};e.init();var i=E();let c;var h=e.child(i);{var m=r=>{var f=k(),v=e.first_child(f);e.each(v,1,()=>(e.deep_read_state(t()),e.untrack(()=>Array.isArray(t())?t().slice(0,3):[t()])),e.index,(a,d)=>{var p=A(),n=e.child(p),x=e.child(n);e.reset(n),e.reset(p),e.template_effect(()=>e.set_text(x,`./${e.get(d)??""}`)),e.append(a,p)});var y=e.sibling(v,2);{var g=a=>{var d=b();e.append(a,d)};e.if(y,a=>{e.deep_read_state(t()),e.untrack(()=>Array.isArray(t())&&t().length>3)&&a(g)})}e.append(r,f)};e.if(h,r=>{t()&&r(m)})}return e.reset(i),e.template_effect(()=>c=e.set_class(i,1,"svelte-14aa7hi",null,c,{table:s()==="table",gallery:s()==="gallery",selected:o()})),e.append(u,i),e.pop(_)}export{w as default};
