import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import"./i18n-BldJSFLV.js";import"./svelte/svelte_svelte.js";import{B as w}from"./Button-D-Ky-vOi.js";import"./svelte/svelte_store.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./Image-Bdf4wQSw.js";import"./ImagePreview-Cx854cRW.js";import"./utils.svelte-Ceck75cM.js";import"./IconButtonWrapper-Cljb5D-5.js";import"./MarkdownCode-C2b9iIxl.js";import"./prism-python-CpYAgONt.js";import"./ShareButton-DCJS4lh5.js";import"./FullscreenButton-Cqzqqtq6.js";var g=e.from_html('<span class="api-name svelte-1kdww8a"> </span>'),k=e.from_html('<div class="loading-dot self-baseline svelte-1kdww8a"></div> <p class="self-baseline svelte-1kdww8a">Recording API Calls:</p> <p class="self-baseline api-section svelte-1kdww8a"><span class="api-count svelte-1kdww8a"> </span> <!></p>',1),x=e.from_html('<div id="api-recorder" class="svelte-1kdww8a"><!></div>');function W(m,i){e.push(i,!1);let t=e.prop(i,"api_calls",28,()=>[]),a=e.prop(i,"dependencies",12);var c={get api_calls(){return t()},set api_calls(r){t(r),e.flush()},get dependencies(){return a()},set dependencies(r){a(r),e.flush()}};e.init();var p=x(),_=e.child(p);return w(_,{size:"sm",variant:"secondary",children:(r,b)=>{var n=k(),d=e.sibling(e.first_child(n),4),s=e.child(d),v=e.child(s);e.reset(s);var f=e.sibling(s,2);{var h=o=>{var l=g(),u=e.child(l);e.reset(l),e.template_effect(()=>e.set_text(u,`/${e.deep_read_state(a()),e.deep_read_state(t()),e.untrack(()=>a()[t()[t().length-1].fn_index].api_name)??""}`)),e.append(o,l)};e.if(f,o=>{e.deep_read_state(t()),e.untrack(()=>t().length>0)&&o(h)})}e.reset(d),e.template_effect(()=>e.set_text(v,`[${e.deep_read_state(t()),e.untrack(()=>t().length)??""}]`)),e.append(r,n)},$$slots:{default:!0}}),e.reset(p),e.append(m,p),e.pop(c)}export{W as default};
