import{F as p}from"./KHR_interactivity-DRPs30Rf.js";import{R as i,i as a,F as e}from"./declarationMapper-CGPHX8aB.js";import{R as s}from"./index-6jOCfdig.js";import"./index-Ds2meNS5.js";import"./svelte/svelte_svelte.js";import"./svelte/svelte_animate.js";import"./svelte/svelte_attachments.js";import"./svelte/svelte_easing.js";import"./svelte/svelte_internal_client.js";import"./svelte/svelte_internal_flags_async.js";import"./svelte/svelte_internal_flags_legacy.js";import"./svelte/svelte_internal_flags_tracing.js";import"./svelte/svelte_internal_server.js";import"./svelte/svelte_legacy.js";import"./svelte/svelte_motion.js";import"./svelte/svelte_reactivity.js";import"./svelte/svelte_reactivity_window.js";import"./svelte/svelte_server.js";import"./svelte/svelte_store.js";import"./svelte/svelte_transition.js";import"./svelte/svelte_events.js";import"./objectModelMapping-DT0r674A.js";class m extends p{constructor(t){super(t),this.config=t,this.object=this.registerDataInput("object",i),this.array=this.registerDataInput("array",i),this.index=this.registerDataOutput("index",a,new e(-1))}_updateOutputs(t){const o=this.object.getValue(t),r=this.array.getValue(t);r&&this.index.setValue(new e(r.indexOf(o)),t)}serialize(t){super.serialize(t)}getClassName(){return"FlowGraphIndexOfBlock"}}s("FlowGraphIndexOfBlock",m);export{m as FlowGraphIndexOfBlock};
