import"./svelte/svelte_internal_flags_async.js";import*as e from"./svelte/svelte_internal_client.js";import{S as b}from"./StreamingBar-b2qVLPYU.js";var x=e.from_html("<div><!> <!></div>");function S(v,t){e.push(t,!0),e.rest_props(t,["$$slots","$$events","$$legacy"]);let a,u=e.derived(()=>t.scale??null),o=e.derived(()=>t.min_width??0),c=e.derived(()=>t.elem_id??""),m=e.derived(()=>t.elem_classes??[]),_=e.derived(()=>t.visible??!0),d=e.derived(()=>t.variant??"default"),s=e.derived(()=>t.loading_status);e.derived(()=>t.show_progress??!1);var l=x();let r,n;var g=e.child(l);{var f=i=>{{let w=e.derived(()=>e.get(s)?e.get(s).status=="pending"?"generating":e.get(s).status:null);b(i,e.spread_props({get autoscroll(){return t.autoscroll},get i18n(){return t.i18n}},()=>e.get(s),{get status(){return e.get(w)}}))}};e.if(g,i=>{e.get(s)&&e.get(s).show_progress&&i(f)})}var h=e.sibling(g,2);e.slot(h,t,"default",{},null),e.reset(l),e.bind_this(l,i=>a=i,()=>a),e.template_effect(i=>{e.set_attribute(l,"id",e.get(c)),r=e.set_class(l,1,`column ${i??""}`,"svelte-siq5d6",r,{compact:e.get(d)==="compact",panel:e.get(d)==="panel",hide:!e.get(_)}),n=e.set_style(l,"",n,{"flex-grow":e.get(u),"min-width":`calc(min(${e.get(o)??""}px, 100%))`})},[()=>e.get(m).join(" ")]),e.append(v,l),e.pop()}export{S as B};
